import { z } from 'zod';
declare const KosmoLocation: z.ZodObject<z.extendShape<{
    lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}, {
    address: z.ZodString;
    postalCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    country: z.ZodEnum<["SG", "MY", "PH", "TH", "ID"]>;
    /** Unit number, floor, building name etc */
    addressDetails: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    instructions: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}>, "strip", z.ZodTypeAny, {
    lat?: number | null | undefined;
    lng?: number | null | undefined;
    postalCode?: string | null | undefined;
    addressDetails?: string | null | undefined;
    instructions?: string | null | undefined;
    address: string;
    country: "SG" | "MY" | "PH" | "TH" | "ID";
}, {
    lat?: number | null | undefined;
    lng?: number | null | undefined;
    postalCode?: string | null | undefined;
    addressDetails?: string | null | undefined;
    instructions?: string | null | undefined;
    address: string;
    country: "SG" | "MY" | "PH" | "TH" | "ID";
}>;
declare const KosmoPerson: z.ZodObject<{
    fullname: z.ZodString;
    phone: z.ZodString;
}, "strip", z.ZodTypeAny, {
    phone: string;
    fullname: string;
}, {
    phone: string;
    fullname: string;
}>;
declare const KosmoDriver: z.ZodObject<z.extendShape<{
    fullname: z.ZodString;
    phone: z.ZodString;
}, {
    plateNumber: z.ZodString;
    photoURL: z.ZodString;
    location: z.ZodObject<{
        lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }, "strip", z.ZodTypeAny, {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
    }, {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
    }>;
}>, "strip", z.ZodTypeAny, {
    phone: string;
    photoURL: string;
    fullname: string;
    plateNumber: string;
    location: {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
    };
}, {
    phone: string;
    photoURL: string;
    fullname: string;
    plateNumber: string;
    location: {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
    };
}>;
declare const KosmoValue: z.ZodObject<{
    /** in cents */
    amount: z.ZodNumber;
    currency: z.ZodString;
}, "strip", z.ZodTypeAny, {
    amount: number;
    currency: string;
}, {
    amount: number;
    currency: string;
}>;
declare const KosmoHandlingInstructions: z.ZodObject<{
    containsFluids: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    fragile: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    doNotRotate: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    containsHotFood: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
}, "strip", z.ZodTypeAny, {
    fragile?: boolean | null | undefined;
    containsFluids?: boolean | null | undefined;
    doNotRotate?: boolean | null | undefined;
    containsHotFood?: boolean | null | undefined;
}, {
    fragile?: boolean | null | undefined;
    containsFluids?: boolean | null | undefined;
    doNotRotate?: boolean | null | undefined;
    containsHotFood?: boolean | null | undefined;
}>;
declare const KosmoParcel: z.ZodObject<{
    description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    /** in centimeters */
    weight: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    /** in centimeters */
    height: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    /** in centimeters */
    width: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    /** in centimeters */
    length: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    value: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        /** in cents */
        amount: z.ZodNumber;
        currency: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        amount: number;
        currency: string;
    }, {
        amount: number;
        currency: string;
    }>>>;
    reference: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    handlingInstructions: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        containsFluids: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        fragile: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        doNotRotate: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        containsHotFood: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    }, "strip", z.ZodTypeAny, {
        fragile?: boolean | null | undefined;
        containsFluids?: boolean | null | undefined;
        doNotRotate?: boolean | null | undefined;
        containsHotFood?: boolean | null | undefined;
    }, {
        fragile?: boolean | null | undefined;
        containsFluids?: boolean | null | undefined;
        doNotRotate?: boolean | null | undefined;
        containsHotFood?: boolean | null | undefined;
    }>>>;
    waybillURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    length?: number | null | undefined;
    value?: {
        amount: number;
        currency: string;
    } | null | undefined;
    description?: string | null | undefined;
    height?: number | null | undefined;
    width?: number | null | undefined;
    weight?: number | null | undefined;
    reference?: string | null | undefined;
    handlingInstructions?: {
        fragile?: boolean | null | undefined;
        containsFluids?: boolean | null | undefined;
        doNotRotate?: boolean | null | undefined;
        containsHotFood?: boolean | null | undefined;
    } | null | undefined;
    waybillURL?: string | null | undefined;
}, {
    length?: number | null | undefined;
    value?: {
        amount: number;
        currency: string;
    } | null | undefined;
    description?: string | null | undefined;
    height?: number | null | undefined;
    width?: number | null | undefined;
    weight?: number | null | undefined;
    reference?: string | null | undefined;
    handlingInstructions?: {
        fragile?: boolean | null | undefined;
        containsFluids?: boolean | null | undefined;
        doNotRotate?: boolean | null | undefined;
        containsHotFood?: boolean | null | undefined;
    } | null | undefined;
    waybillURL?: string | null | undefined;
}>;
declare const KosmoDropOff: z.ZodObject<{
    location: z.ZodObject<z.extendShape<{
        lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }, {
        address: z.ZodString;
        postalCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        country: z.ZodEnum<["SG", "MY", "PH", "TH", "ID"]>;
        /** Unit number, floor, building name etc */
        addressDetails: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        instructions: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }>, "strip", z.ZodTypeAny, {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
        postalCode?: string | null | undefined;
        addressDetails?: string | null | undefined;
        instructions?: string | null | undefined;
        address: string;
        country: "SG" | "MY" | "PH" | "TH" | "ID";
    }, {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
        postalCode?: string | null | undefined;
        addressDetails?: string | null | undefined;
        instructions?: string | null | undefined;
        address: string;
        country: "SG" | "MY" | "PH" | "TH" | "ID";
    }>;
    receiver: z.ZodObject<{
        fullname: z.ZodString;
        phone: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        phone: string;
        fullname: string;
    }, {
        phone: string;
        fullname: string;
    }>;
    parcels: z.ZodArray<z.ZodObject<{
        description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        /** in centimeters */
        weight: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        /** in centimeters */
        height: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        /** in centimeters */
        width: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        /** in centimeters */
        length: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        value: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            /** in cents */
            amount: z.ZodNumber;
            currency: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            amount: number;
            currency: string;
        }, {
            amount: number;
            currency: string;
        }>>>;
        reference: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        handlingInstructions: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            containsFluids: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            fragile: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            doNotRotate: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            containsHotFood: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            fragile?: boolean | null | undefined;
            containsFluids?: boolean | null | undefined;
            doNotRotate?: boolean | null | undefined;
            containsHotFood?: boolean | null | undefined;
        }, {
            fragile?: boolean | null | undefined;
            containsFluids?: boolean | null | undefined;
            doNotRotate?: boolean | null | undefined;
            containsHotFood?: boolean | null | undefined;
        }>>>;
        waybillURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        length?: number | null | undefined;
        value?: {
            amount: number;
            currency: string;
        } | null | undefined;
        description?: string | null | undefined;
        height?: number | null | undefined;
        width?: number | null | undefined;
        weight?: number | null | undefined;
        reference?: string | null | undefined;
        handlingInstructions?: {
            fragile?: boolean | null | undefined;
            containsFluids?: boolean | null | undefined;
            doNotRotate?: boolean | null | undefined;
            containsHotFood?: boolean | null | undefined;
        } | null | undefined;
        waybillURL?: string | null | undefined;
    }, {
        length?: number | null | undefined;
        value?: {
            amount: number;
            currency: string;
        } | null | undefined;
        description?: string | null | undefined;
        height?: number | null | undefined;
        width?: number | null | undefined;
        weight?: number | null | undefined;
        reference?: string | null | undefined;
        handlingInstructions?: {
            fragile?: boolean | null | undefined;
            containsFluids?: boolean | null | undefined;
            doNotRotate?: boolean | null | undefined;
            containsHotFood?: boolean | null | undefined;
        } | null | undefined;
        waybillURL?: string | null | undefined;
    }>, "many">;
    /** Order Id in FeedMe */
    orderReferenceId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    proofOfDeliveryURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    /**
     * If enable route optimization, can specify
     * before which dropoff this dropoff should be delivered.
     * Need to provide `orderReferenceId`.
     */
    before: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    /**
     * Tracking URL with complete information
     * (payment & all recipients)
     */
    trackingURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    orderReferenceId?: string | null | undefined;
    proofOfDeliveryURL?: string | null | undefined;
    before?: string | null | undefined;
    trackingURL?: string | null | undefined;
    location: {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
        postalCode?: string | null | undefined;
        addressDetails?: string | null | undefined;
        instructions?: string | null | undefined;
        address: string;
        country: "SG" | "MY" | "PH" | "TH" | "ID";
    };
    receiver: {
        phone: string;
        fullname: string;
    };
    parcels: {
        length?: number | null | undefined;
        value?: {
            amount: number;
            currency: string;
        } | null | undefined;
        description?: string | null | undefined;
        height?: number | null | undefined;
        width?: number | null | undefined;
        weight?: number | null | undefined;
        reference?: string | null | undefined;
        handlingInstructions?: {
            fragile?: boolean | null | undefined;
            containsFluids?: boolean | null | undefined;
            doNotRotate?: boolean | null | undefined;
            containsHotFood?: boolean | null | undefined;
        } | null | undefined;
        waybillURL?: string | null | undefined;
    }[];
}, {
    orderReferenceId?: string | null | undefined;
    proofOfDeliveryURL?: string | null | undefined;
    before?: string | null | undefined;
    trackingURL?: string | null | undefined;
    location: {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
        postalCode?: string | null | undefined;
        addressDetails?: string | null | undefined;
        instructions?: string | null | undefined;
        address: string;
        country: "SG" | "MY" | "PH" | "TH" | "ID";
    };
    receiver: {
        phone: string;
        fullname: string;
    };
    parcels: {
        length?: number | null | undefined;
        value?: {
            amount: number;
            currency: string;
        } | null | undefined;
        description?: string | null | undefined;
        height?: number | null | undefined;
        width?: number | null | undefined;
        weight?: number | null | undefined;
        reference?: string | null | undefined;
        handlingInstructions?: {
            fragile?: boolean | null | undefined;
            containsFluids?: boolean | null | undefined;
            doNotRotate?: boolean | null | undefined;
            containsHotFood?: boolean | null | undefined;
        } | null | undefined;
        waybillURL?: string | null | undefined;
    }[];
}>;
declare const KosmoPickUp: z.ZodObject<{
    location_reference_id: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    /** Required if `location_reference_id` is provided */
    name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    productType: z.ZodNullable<z.ZodOptional<z.ZodEnum<["food", "groceries", "flowers", "documents", "medicines", "electronics", "fashion", "fragile", "others"]>>>;
    location: z.ZodObject<z.extendShape<{
        lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }, {
        address: z.ZodString;
        postalCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        country: z.ZodEnum<["SG", "MY", "PH", "TH", "ID"]>;
        /** Unit number, floor, building name etc */
        addressDetails: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        instructions: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }>, "strip", z.ZodTypeAny, {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
        postalCode?: string | null | undefined;
        addressDetails?: string | null | undefined;
        instructions?: string | null | undefined;
        address: string;
        country: "SG" | "MY" | "PH" | "TH" | "ID";
    }, {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
        postalCode?: string | null | undefined;
        addressDetails?: string | null | undefined;
        instructions?: string | null | undefined;
        address: string;
        country: "SG" | "MY" | "PH" | "TH" | "ID";
    }>;
    sender: z.ZodObject<{
        fullname: z.ZodString;
        phone: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        phone: string;
        fullname: string;
    }, {
        phone: string;
        fullname: string;
    }>;
}, "strip", z.ZodTypeAny, {
    name?: string | null | undefined;
    location_reference_id?: string | null | undefined;
    productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
    sender: {
        phone: string;
        fullname: string;
    };
    location: {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
        postalCode?: string | null | undefined;
        addressDetails?: string | null | undefined;
        instructions?: string | null | undefined;
        address: string;
        country: "SG" | "MY" | "PH" | "TH" | "ID";
    };
}, {
    name?: string | null | undefined;
    location_reference_id?: string | null | undefined;
    productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
    sender: {
        phone: string;
        fullname: string;
    };
    location: {
        lat?: number | null | undefined;
        lng?: number | null | undefined;
        postalCode?: string | null | undefined;
        addressDetails?: string | null | undefined;
        instructions?: string | null | undefined;
        address: string;
        country: "SG" | "MY" | "PH" | "TH" | "ID";
    };
}>;
declare const KosmoRules: z.ZodObject<{
    providers: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
    ruleID: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    autoReassign: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
}, "strip", z.ZodTypeAny, {
    providers?: string[] | null | undefined;
    ruleID?: string | null | undefined;
    autoReassign?: boolean | null | undefined;
}, {
    providers?: string[] | null | undefined;
    ruleID?: string | null | undefined;
    autoReassign?: boolean | null | undefined;
}>;
declare const KosmoCreateQuoteReq: z.ZodObject<{
    /** price will be the priority if no value is provided */
    priority: z.ZodNullable<z.ZodOptional<z.ZodEnum<["time", "price"]>>>;
    deliveryType: z.ZodNullable<z.ZodOptional<z.ZodEnum<["ASAP", "2H", "4H", "NEXT_DAY", "NEXT_3_DAYS"]>>>;
    /**
     * Default value is current time.
     * If time is within an hour,
     * it will be ignored
     */
    pickupStartTime: z.ZodNullable<z.ZodOptional<z.ZodDate>>;
    /** Pickup point of delivery */
    pickup: z.ZodObject<{
        location_reference_id: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        /** Required if `location_reference_id` is provided */
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        productType: z.ZodNullable<z.ZodOptional<z.ZodEnum<["food", "groceries", "flowers", "documents", "medicines", "electronics", "fashion", "fragile", "others"]>>>;
        location: z.ZodObject<z.extendShape<{
            lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, {
            address: z.ZodString;
            postalCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            country: z.ZodEnum<["SG", "MY", "PH", "TH", "ID"]>;
            /** Unit number, floor, building name etc */
            addressDetails: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            instructions: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }>, "strip", z.ZodTypeAny, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        }, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        }>;
        sender: z.ZodObject<{
            fullname: z.ZodString;
            phone: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            phone: string;
            fullname: string;
        }, {
            phone: string;
            fullname: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        name?: string | null | undefined;
        location_reference_id?: string | null | undefined;
        productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
        sender: {
            phone: string;
            fullname: string;
        };
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
    }, {
        name?: string | null | undefined;
        location_reference_id?: string | null | undefined;
        productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
        sender: {
            phone: string;
            fullname: string;
        };
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
    }>;
    /** Max 20 stops */
    dropoffs: z.ZodArray<z.ZodObject<{
        location: z.ZodObject<z.extendShape<{
            lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, {
            address: z.ZodString;
            postalCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            country: z.ZodEnum<["SG", "MY", "PH", "TH", "ID"]>;
            /** Unit number, floor, building name etc */
            addressDetails: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            instructions: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }>, "strip", z.ZodTypeAny, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        }, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        }>;
        receiver: z.ZodObject<{
            fullname: z.ZodString;
            phone: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            phone: string;
            fullname: string;
        }, {
            phone: string;
            fullname: string;
        }>;
        parcels: z.ZodArray<z.ZodObject<{
            description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            /** in centimeters */
            weight: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            /** in centimeters */
            height: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            /** in centimeters */
            width: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            /** in centimeters */
            length: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            value: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                /** in cents */
                amount: z.ZodNumber;
                currency: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                amount: number;
                currency: string;
            }, {
                amount: number;
                currency: string;
            }>>>;
            reference: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            handlingInstructions: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                containsFluids: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                fragile: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                doNotRotate: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                containsHotFood: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            }, "strip", z.ZodTypeAny, {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            }, {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            }>>>;
            waybillURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }, {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }>, "many">;
        /** Order Id in FeedMe */
        orderReferenceId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        proofOfDeliveryURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        /**
         * If enable route optimization, can specify
         * before which dropoff this dropoff should be delivered.
         * Need to provide `orderReferenceId`.
         */
        before: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        /**
         * Tracking URL with complete information
         * (payment & all recipients)
         */
        trackingURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        orderReferenceId?: string | null | undefined;
        proofOfDeliveryURL?: string | null | undefined;
        before?: string | null | undefined;
        trackingURL?: string | null | undefined;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
        receiver: {
            phone: string;
            fullname: string;
        };
        parcels: {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }[];
    }, {
        orderReferenceId?: string | null | undefined;
        proofOfDeliveryURL?: string | null | undefined;
        before?: string | null | undefined;
        trackingURL?: string | null | undefined;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
        receiver: {
            phone: string;
            fullname: string;
        };
        parcels: {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }[];
    }>, "many">;
    vehicleType: z.ZodNullable<z.ZodOptional<z.ZodEnum<["motorcycle", "car", "van"]>>>;
    optimizeRoute: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    proofDelivery: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    door2door: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    rules: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        providers: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
        ruleID: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        autoReassign: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    }, "strip", z.ZodTypeAny, {
        providers?: string[] | null | undefined;
        ruleID?: string | null | undefined;
        autoReassign?: boolean | null | undefined;
    }, {
        providers?: string[] | null | undefined;
        ruleID?: string | null | undefined;
        autoReassign?: boolean | null | undefined;
    }>>>;
}, "strip", z.ZodTypeAny, {
    proofDelivery?: boolean | null | undefined;
    door2door?: boolean | null | undefined;
    priority?: "time" | "price" | null | undefined;
    deliveryType?: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS" | null | undefined;
    pickupStartTime?: Date | null | undefined;
    vehicleType?: "motorcycle" | "car" | "van" | null | undefined;
    optimizeRoute?: boolean | null | undefined;
    rules?: {
        providers?: string[] | null | undefined;
        ruleID?: string | null | undefined;
        autoReassign?: boolean | null | undefined;
    } | null | undefined;
    pickup: {
        name?: string | null | undefined;
        location_reference_id?: string | null | undefined;
        productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
        sender: {
            phone: string;
            fullname: string;
        };
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
    };
    dropoffs: {
        orderReferenceId?: string | null | undefined;
        proofOfDeliveryURL?: string | null | undefined;
        before?: string | null | undefined;
        trackingURL?: string | null | undefined;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
        receiver: {
            phone: string;
            fullname: string;
        };
        parcels: {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }[];
    }[];
}, {
    proofDelivery?: boolean | null | undefined;
    door2door?: boolean | null | undefined;
    priority?: "time" | "price" | null | undefined;
    deliveryType?: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS" | null | undefined;
    pickupStartTime?: Date | null | undefined;
    vehicleType?: "motorcycle" | "car" | "van" | null | undefined;
    optimizeRoute?: boolean | null | undefined;
    rules?: {
        providers?: string[] | null | undefined;
        ruleID?: string | null | undefined;
        autoReassign?: boolean | null | undefined;
    } | null | undefined;
    pickup: {
        name?: string | null | undefined;
        location_reference_id?: string | null | undefined;
        productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
        sender: {
            phone: string;
            fullname: string;
        };
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
    };
    dropoffs: {
        orderReferenceId?: string | null | undefined;
        proofOfDeliveryURL?: string | null | undefined;
        before?: string | null | undefined;
        trackingURL?: string | null | undefined;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
        receiver: {
            phone: string;
            fullname: string;
        };
        parcels: {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }[];
    }[];
}>;
declare const KosmoPricing: z.ZodObject<{
    /** in cents */
    base: z.ZodNumber;
    /** in cents */
    discount: z.ZodNumber;
    /** in cents */
    tax1: z.ZodNumber;
    /** in cents */
    platform_fee: z.ZodNumber;
    /** in cents */
    currency: z.ZodString;
    /** in cents */
    partnerFee: z.ZodNumber;
    /** in cents */
    total: z.ZodNumber;
    /** in cents */
    chargeTotal: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    base: number;
    currency: string;
    discount: number;
    tax1: number;
    platform_fee: number;
    partnerFee: number;
    total: number;
    chargeTotal: number;
}, {
    base: number;
    currency: string;
    discount: number;
    tax1: number;
    platform_fee: number;
    partnerFee: number;
    total: number;
    chargeTotal: number;
}>;
declare const KosmoQuote: z.ZodObject<{
    /** KOSMO quote id */
    id: z.ZodString;
    provider: z.ZodEnum<["PANDAGO", "LALAMOVE", "PICKUPP", "ZEEK", "BORZO"]>;
    serviceName: z.ZodString;
    vehicleType: z.ZodEnum<["motorcycle", "car", "van"]>;
    price: z.ZodObject<{
        /** in cents */
        amount: z.ZodNumber;
        currency: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        amount: number;
        currency: string;
    }, {
        amount: number;
        currency: string;
    }>;
    pricing: z.ZodObject<{
        /** in cents */
        base: z.ZodNumber;
        /** in cents */
        discount: z.ZodNumber;
        /** in cents */
        tax1: z.ZodNumber;
        /** in cents */
        platform_fee: z.ZodNumber;
        /** in cents */
        currency: z.ZodString;
        /** in cents */
        partnerFee: z.ZodNumber;
        /** in cents */
        total: z.ZodNumber;
        /** in cents */
        chargeTotal: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        base: number;
        currency: string;
        discount: number;
        tax1: number;
        platform_fee: number;
        partnerFee: number;
        total: number;
        chargeTotal: number;
    }, {
        base: number;
        currency: string;
        discount: number;
        tax1: number;
        platform_fee: number;
        partnerFee: number;
        total: number;
        chargeTotal: number;
    }>;
    /** RFC3339 */
    pickupEta: z.ZodString;
    /** RFC3339 */
    pickupTillEta: z.ZodString;
    /** RFC3339 */
    dropoffEta: z.ZodString;
    deliveryType: z.ZodEnum<["ASAP", "2H", "4H", "NEXT_DAY", "NEXT_3_DAYS"]>;
    services: z.ZodArray<z.ZodEnum<["proofDelivery", "insurance", "door2door"]>, "many">;
    rank: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    id: string;
    price: {
        amount: number;
        currency: string;
    };
    deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
    vehicleType: "motorcycle" | "car" | "van";
    provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
    serviceName: string;
    pricing: {
        base: number;
        currency: string;
        discount: number;
        tax1: number;
        platform_fee: number;
        partnerFee: number;
        total: number;
        chargeTotal: number;
    };
    pickupEta: string;
    pickupTillEta: string;
    dropoffEta: string;
    services: ("proofDelivery" | "insurance" | "door2door")[];
    rank: number;
}, {
    id: string;
    price: {
        amount: number;
        currency: string;
    };
    deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
    vehicleType: "motorcycle" | "car" | "van";
    provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
    serviceName: string;
    pricing: {
        base: number;
        currency: string;
        discount: number;
        tax1: number;
        platform_fee: number;
        partnerFee: number;
        total: number;
        chargeTotal: number;
    };
    pickupEta: string;
    pickupTillEta: string;
    dropoffEta: string;
    services: ("proofDelivery" | "insurance" | "door2door")[];
    rank: number;
}>;
declare const KosmoCreateQuoteRes: z.ZodObject<{
    quoteBatchId: z.ZodString;
    quotes: z.ZodArray<z.ZodObject<{
        /** KOSMO quote id */
        id: z.ZodString;
        provider: z.ZodEnum<["PANDAGO", "LALAMOVE", "PICKUPP", "ZEEK", "BORZO"]>;
        serviceName: z.ZodString;
        vehicleType: z.ZodEnum<["motorcycle", "car", "van"]>;
        price: z.ZodObject<{
            /** in cents */
            amount: z.ZodNumber;
            currency: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            amount: number;
            currency: string;
        }, {
            amount: number;
            currency: string;
        }>;
        pricing: z.ZodObject<{
            /** in cents */
            base: z.ZodNumber;
            /** in cents */
            discount: z.ZodNumber;
            /** in cents */
            tax1: z.ZodNumber;
            /** in cents */
            platform_fee: z.ZodNumber;
            /** in cents */
            currency: z.ZodString;
            /** in cents */
            partnerFee: z.ZodNumber;
            /** in cents */
            total: z.ZodNumber;
            /** in cents */
            chargeTotal: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        }, {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        }>;
        /** RFC3339 */
        pickupEta: z.ZodString;
        /** RFC3339 */
        pickupTillEta: z.ZodString;
        /** RFC3339 */
        dropoffEta: z.ZodString;
        deliveryType: z.ZodEnum<["ASAP", "2H", "4H", "NEXT_DAY", "NEXT_3_DAYS"]>;
        services: z.ZodArray<z.ZodEnum<["proofDelivery", "insurance", "door2door"]>, "many">;
        rank: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        id: string;
        price: {
            amount: number;
            currency: string;
        };
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        serviceName: string;
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        rank: number;
    }, {
        id: string;
        price: {
            amount: number;
            currency: string;
        };
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        serviceName: string;
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        rank: number;
    }>, "many">;
    pickupLocationId: z.ZodString;
}, "strip", z.ZodTypeAny, {
    quoteBatchId: string;
    quotes: {
        id: string;
        price: {
            amount: number;
            currency: string;
        };
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        serviceName: string;
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        rank: number;
    }[];
    pickupLocationId: string;
}, {
    quoteBatchId: string;
    quotes: {
        id: string;
        price: {
            amount: number;
            currency: string;
        };
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        serviceName: string;
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        rank: number;
    }[];
    pickupLocationId: string;
}>;
declare const KosmoAcceptQuoteDto: z.ZodObject<{
    autoReassign: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
}, "strip", z.ZodTypeAny, {
    autoReassign?: boolean | null | undefined;
}, {
    autoReassign?: boolean | null | undefined;
}>;
declare const KosmoOrder: z.ZodObject<{
    /** KOSMO order id */
    id: z.ZodString;
    /** Provider order id */
    deliveryId: z.ZodString;
    status: z.ZodEnum<["submitted", "created", "to_pickup", "picked_up", "delivered", "failed", "cancelled", "returning", "returned", "at_hub", "to_dropoff"]>;
    /** Quote used to create order */
    quoteId: z.ZodString;
    /** RFC3339 format. */
    pickupEta: z.ZodString;
    /** RFC3339 format. Latest time to picked up order. Can be empty. */
    pickupTillEta: z.ZodString;
    /** RFC3339 format. */
    dropoffEta: z.ZodString;
    autoReassign: z.ZodBoolean;
    /** KOSMO tracking URL to track order */
    trackingURL: z.ZodString;
    vehicleType: z.ZodEnum<["motorcycle", "car", "van"]>;
    deliveryType: z.ZodEnum<["ASAP", "2H", "4H", "NEXT_DAY", "NEXT_3_DAYS"]>;
    services: z.ZodArray<z.ZodEnum<["proofDelivery", "insurance", "door2door"]>, "many">;
    driver: z.ZodObject<z.extendShape<{
        fullname: z.ZodString;
        phone: z.ZodString;
    }, {
        plateNumber: z.ZodString;
        photoURL: z.ZodString;
        location: z.ZodObject<{
            lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        }, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        }>;
    }>, "strip", z.ZodTypeAny, {
        phone: string;
        photoURL: string;
        fullname: string;
        plateNumber: string;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        };
    }, {
        phone: string;
        photoURL: string;
        fullname: string;
        plateNumber: string;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        };
    }>;
    pickup: z.ZodObject<{
        location_reference_id: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        /** Required if `location_reference_id` is provided */
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        productType: z.ZodNullable<z.ZodOptional<z.ZodEnum<["food", "groceries", "flowers", "documents", "medicines", "electronics", "fashion", "fragile", "others"]>>>;
        location: z.ZodObject<z.extendShape<{
            lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, {
            address: z.ZodString;
            postalCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            country: z.ZodEnum<["SG", "MY", "PH", "TH", "ID"]>;
            /** Unit number, floor, building name etc */
            addressDetails: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            instructions: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }>, "strip", z.ZodTypeAny, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        }, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        }>;
        sender: z.ZodObject<{
            fullname: z.ZodString;
            phone: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            phone: string;
            fullname: string;
        }, {
            phone: string;
            fullname: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        name?: string | null | undefined;
        location_reference_id?: string | null | undefined;
        productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
        sender: {
            phone: string;
            fullname: string;
        };
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
    }, {
        name?: string | null | undefined;
        location_reference_id?: string | null | undefined;
        productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
        sender: {
            phone: string;
            fullname: string;
        };
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
    }>;
    dropoffs: z.ZodArray<z.ZodObject<{
        location: z.ZodObject<z.extendShape<{
            lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, {
            address: z.ZodString;
            postalCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            country: z.ZodEnum<["SG", "MY", "PH", "TH", "ID"]>;
            /** Unit number, floor, building name etc */
            addressDetails: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            instructions: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }>, "strip", z.ZodTypeAny, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        }, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        }>;
        receiver: z.ZodObject<{
            fullname: z.ZodString;
            phone: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            phone: string;
            fullname: string;
        }, {
            phone: string;
            fullname: string;
        }>;
        parcels: z.ZodArray<z.ZodObject<{
            description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            /** in centimeters */
            weight: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            /** in centimeters */
            height: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            /** in centimeters */
            width: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            /** in centimeters */
            length: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            value: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                /** in cents */
                amount: z.ZodNumber;
                currency: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                amount: number;
                currency: string;
            }, {
                amount: number;
                currency: string;
            }>>>;
            reference: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            handlingInstructions: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                containsFluids: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                fragile: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                doNotRotate: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                containsHotFood: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            }, "strip", z.ZodTypeAny, {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            }, {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            }>>>;
            waybillURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }, {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }>, "many">;
        /** Order Id in FeedMe */
        orderReferenceId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        proofOfDeliveryURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        /**
         * If enable route optimization, can specify
         * before which dropoff this dropoff should be delivered.
         * Need to provide `orderReferenceId`.
         */
        before: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        /**
         * Tracking URL with complete information
         * (payment & all recipients)
         */
        trackingURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        orderReferenceId?: string | null | undefined;
        proofOfDeliveryURL?: string | null | undefined;
        before?: string | null | undefined;
        trackingURL?: string | null | undefined;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
        receiver: {
            phone: string;
            fullname: string;
        };
        parcels: {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }[];
    }, {
        orderReferenceId?: string | null | undefined;
        proofOfDeliveryURL?: string | null | undefined;
        before?: string | null | undefined;
        trackingURL?: string | null | undefined;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
        receiver: {
            phone: string;
            fullname: string;
        };
        parcels: {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }[];
    }>, "many">;
    pricing: z.ZodObject<{
        /** in cents */
        base: z.ZodNumber;
        /** in cents */
        discount: z.ZodNumber;
        /** in cents */
        tax1: z.ZodNumber;
        /** in cents */
        platform_fee: z.ZodNumber;
        /** in cents */
        currency: z.ZodString;
        /** in cents */
        partnerFee: z.ZodNumber;
        /** in cents */
        total: z.ZodNumber;
        /** in cents */
        chargeTotal: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        base: number;
        currency: string;
        discount: number;
        tax1: number;
        platform_fee: number;
        partnerFee: number;
        total: number;
        chargeTotal: number;
    }, {
        base: number;
        currency: string;
        discount: number;
        tax1: number;
        platform_fee: number;
        partnerFee: number;
        total: number;
        chargeTotal: number;
    }>;
    totalAmount: z.ZodObject<{
        /** in cents */
        amount: z.ZodNumber;
        currency: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        amount: number;
        currency: string;
    }, {
        amount: number;
        currency: string;
    }>;
    provider: z.ZodEnum<["PANDAGO", "LALAMOVE", "PICKUPP", "ZEEK", "BORZO"]>;
}, "strip", z.ZodTypeAny, {
    id: string;
    status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
    driver: {
        phone: string;
        photoURL: string;
        fullname: string;
        plateNumber: string;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        };
    };
    trackingURL: string;
    autoReassign: boolean;
    deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
    pickup: {
        name?: string | null | undefined;
        location_reference_id?: string | null | undefined;
        productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
        sender: {
            phone: string;
            fullname: string;
        };
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
    };
    dropoffs: {
        orderReferenceId?: string | null | undefined;
        proofOfDeliveryURL?: string | null | undefined;
        before?: string | null | undefined;
        trackingURL?: string | null | undefined;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
        receiver: {
            phone: string;
            fullname: string;
        };
        parcels: {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }[];
    }[];
    vehicleType: "motorcycle" | "car" | "van";
    provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
    pricing: {
        base: number;
        currency: string;
        discount: number;
        tax1: number;
        platform_fee: number;
        partnerFee: number;
        total: number;
        chargeTotal: number;
    };
    pickupEta: string;
    pickupTillEta: string;
    dropoffEta: string;
    services: ("proofDelivery" | "insurance" | "door2door")[];
    deliveryId: string;
    quoteId: string;
    totalAmount: {
        amount: number;
        currency: string;
    };
}, {
    id: string;
    status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
    driver: {
        phone: string;
        photoURL: string;
        fullname: string;
        plateNumber: string;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        };
    };
    trackingURL: string;
    autoReassign: boolean;
    deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
    pickup: {
        name?: string | null | undefined;
        location_reference_id?: string | null | undefined;
        productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
        sender: {
            phone: string;
            fullname: string;
        };
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
    };
    dropoffs: {
        orderReferenceId?: string | null | undefined;
        proofOfDeliveryURL?: string | null | undefined;
        before?: string | null | undefined;
        trackingURL?: string | null | undefined;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
            postalCode?: string | null | undefined;
            addressDetails?: string | null | undefined;
            instructions?: string | null | undefined;
            address: string;
            country: "SG" | "MY" | "PH" | "TH" | "ID";
        };
        receiver: {
            phone: string;
            fullname: string;
        };
        parcels: {
            length?: number | null | undefined;
            value?: {
                amount: number;
                currency: string;
            } | null | undefined;
            description?: string | null | undefined;
            height?: number | null | undefined;
            width?: number | null | undefined;
            weight?: number | null | undefined;
            reference?: string | null | undefined;
            handlingInstructions?: {
                fragile?: boolean | null | undefined;
                containsFluids?: boolean | null | undefined;
                doNotRotate?: boolean | null | undefined;
                containsHotFood?: boolean | null | undefined;
            } | null | undefined;
            waybillURL?: string | null | undefined;
        }[];
    }[];
    vehicleType: "motorcycle" | "car" | "van";
    provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
    pricing: {
        base: number;
        currency: string;
        discount: number;
        tax1: number;
        platform_fee: number;
        partnerFee: number;
        total: number;
        chargeTotal: number;
    };
    pickupEta: string;
    pickupTillEta: string;
    dropoffEta: string;
    services: ("proofDelivery" | "insurance" | "door2door")[];
    deliveryId: string;
    quoteId: string;
    totalAmount: {
        amount: number;
        currency: string;
    };
}>;
declare const KosmoOrderResponse: z.ZodObject<{
    order: z.ZodObject<{
        /** KOSMO order id */
        id: z.ZodString;
        /** Provider order id */
        deliveryId: z.ZodString;
        status: z.ZodEnum<["submitted", "created", "to_pickup", "picked_up", "delivered", "failed", "cancelled", "returning", "returned", "at_hub", "to_dropoff"]>;
        /** Quote used to create order */
        quoteId: z.ZodString;
        /** RFC3339 format. */
        pickupEta: z.ZodString;
        /** RFC3339 format. Latest time to picked up order. Can be empty. */
        pickupTillEta: z.ZodString;
        /** RFC3339 format. */
        dropoffEta: z.ZodString;
        autoReassign: z.ZodBoolean;
        /** KOSMO tracking URL to track order */
        trackingURL: z.ZodString;
        vehicleType: z.ZodEnum<["motorcycle", "car", "van"]>;
        deliveryType: z.ZodEnum<["ASAP", "2H", "4H", "NEXT_DAY", "NEXT_3_DAYS"]>;
        services: z.ZodArray<z.ZodEnum<["proofDelivery", "insurance", "door2door"]>, "many">;
        driver: z.ZodObject<z.extendShape<{
            fullname: z.ZodString;
            phone: z.ZodString;
        }, {
            plateNumber: z.ZodString;
            photoURL: z.ZodString;
            location: z.ZodObject<{
                lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }, "strip", z.ZodTypeAny, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            }, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        }, {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        }>;
        pickup: z.ZodObject<{
            location_reference_id: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            /** Required if `location_reference_id` is provided */
            name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            productType: z.ZodNullable<z.ZodOptional<z.ZodEnum<["food", "groceries", "flowers", "documents", "medicines", "electronics", "fashion", "fragile", "others"]>>>;
            location: z.ZodObject<z.extendShape<{
                lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }, {
                address: z.ZodString;
                postalCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                country: z.ZodEnum<["SG", "MY", "PH", "TH", "ID"]>;
                /** Unit number, floor, building name etc */
                addressDetails: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                instructions: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            }>, "strip", z.ZodTypeAny, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            }, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            }>;
            sender: z.ZodObject<{
                fullname: z.ZodString;
                phone: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                phone: string;
                fullname: string;
            }, {
                phone: string;
                fullname: string;
            }>;
        }, "strip", z.ZodTypeAny, {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        }, {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        }>;
        dropoffs: z.ZodArray<z.ZodObject<{
            location: z.ZodObject<z.extendShape<{
                lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }, {
                address: z.ZodString;
                postalCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                country: z.ZodEnum<["SG", "MY", "PH", "TH", "ID"]>;
                /** Unit number, floor, building name etc */
                addressDetails: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                instructions: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            }>, "strip", z.ZodTypeAny, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            }, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            }>;
            receiver: z.ZodObject<{
                fullname: z.ZodString;
                phone: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                phone: string;
                fullname: string;
            }, {
                phone: string;
                fullname: string;
            }>;
            parcels: z.ZodArray<z.ZodObject<{
                description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                /** in centimeters */
                weight: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                /** in centimeters */
                height: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                /** in centimeters */
                width: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                /** in centimeters */
                length: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                value: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                    /** in cents */
                    amount: z.ZodNumber;
                    currency: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    amount: number;
                    currency: string;
                }, {
                    amount: number;
                    currency: string;
                }>>>;
                reference: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                handlingInstructions: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                    containsFluids: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                    fragile: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                    doNotRotate: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                    containsHotFood: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                }, {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                }>>>;
                waybillURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            }, "strip", z.ZodTypeAny, {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }, {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }>, "many">;
            /** Order Id in FeedMe */
            orderReferenceId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            proofOfDeliveryURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            /**
             * If enable route optimization, can specify
             * before which dropoff this dropoff should be delivered.
             * Need to provide `orderReferenceId`.
             */
            before: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            /**
             * Tracking URL with complete information
             * (payment & all recipients)
             */
            trackingURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }, {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }>, "many">;
        pricing: z.ZodObject<{
            /** in cents */
            base: z.ZodNumber;
            /** in cents */
            discount: z.ZodNumber;
            /** in cents */
            tax1: z.ZodNumber;
            /** in cents */
            platform_fee: z.ZodNumber;
            /** in cents */
            currency: z.ZodString;
            /** in cents */
            partnerFee: z.ZodNumber;
            /** in cents */
            total: z.ZodNumber;
            /** in cents */
            chargeTotal: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        }, {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        }>;
        totalAmount: z.ZodObject<{
            /** in cents */
            amount: z.ZodNumber;
            currency: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            amount: number;
            currency: string;
        }, {
            amount: number;
            currency: string;
        }>;
        provider: z.ZodEnum<["PANDAGO", "LALAMOVE", "PICKUPP", "ZEEK", "BORZO"]>;
    }, "strip", z.ZodTypeAny, {
        id: string;
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        driver: {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        };
        trackingURL: string;
        autoReassign: boolean;
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        pickup: {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        };
        dropoffs: {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }[];
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        deliveryId: string;
        quoteId: string;
        totalAmount: {
            amount: number;
            currency: string;
        };
    }, {
        id: string;
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        driver: {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        };
        trackingURL: string;
        autoReassign: boolean;
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        pickup: {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        };
        dropoffs: {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }[];
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        deliveryId: string;
        quoteId: string;
        totalAmount: {
            amount: number;
            currency: string;
        };
    }>;
    pickupLocationId: z.ZodString;
}, "strip", z.ZodTypeAny, {
    pickupLocationId: string;
    order: {
        id: string;
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        driver: {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        };
        trackingURL: string;
        autoReassign: boolean;
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        pickup: {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        };
        dropoffs: {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }[];
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        deliveryId: string;
        quoteId: string;
        totalAmount: {
            amount: number;
            currency: string;
        };
    };
}, {
    pickupLocationId: string;
    order: {
        id: string;
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        driver: {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        };
        trackingURL: string;
        autoReassign: boolean;
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        pickup: {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        };
        dropoffs: {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }[];
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        deliveryId: string;
        quoteId: string;
        totalAmount: {
            amount: number;
            currency: string;
        };
    };
}>;
/**
 * Meta data of the list of orders
 */
declare const KosmoMeta: z.ZodObject<{
    /** Total number of orders */
    total: z.ZodNumber;
    /** num of orders created */
    created: z.ZodNumber;
    /** num of orders to pick up */
    toPickup: z.ZodNumber;
    /** num of orders picked up */
    pickedUp: z.ZodNumber;
    /** num of orders delivered */
    delivered: z.ZodNumber;
    /** num of orders cancelled */
    cancelled: z.ZodNumber;
    /** num of orders returning */
    returning: z.ZodNumber;
    /** num of orders returned */
    returned: z.ZodNumber;
    /** num of orders at hub */
    at_hub: z.ZodNumber;
    /** num of orders to drop off */
    to_dropoff: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    created: number;
    delivered: number;
    cancelled: number;
    returning: number;
    returned: number;
    at_hub: number;
    to_dropoff: number;
    total: number;
    toPickup: number;
    pickedUp: number;
}, {
    created: number;
    delivered: number;
    cancelled: number;
    returning: number;
    returned: number;
    at_hub: number;
    to_dropoff: number;
    total: number;
    toPickup: number;
    pickedUp: number;
}>;
export declare const KosmoListOrdersResponse: z.ZodObject<{
    orders: z.ZodArray<z.ZodObject<{
        /** KOSMO order id */
        id: z.ZodString;
        /** Provider order id */
        deliveryId: z.ZodString;
        status: z.ZodEnum<["submitted", "created", "to_pickup", "picked_up", "delivered", "failed", "cancelled", "returning", "returned", "at_hub", "to_dropoff"]>;
        /** Quote used to create order */
        quoteId: z.ZodString;
        /** RFC3339 format. */
        pickupEta: z.ZodString;
        /** RFC3339 format. Latest time to picked up order. Can be empty. */
        pickupTillEta: z.ZodString;
        /** RFC3339 format. */
        dropoffEta: z.ZodString;
        autoReassign: z.ZodBoolean;
        /** KOSMO tracking URL to track order */
        trackingURL: z.ZodString;
        vehicleType: z.ZodEnum<["motorcycle", "car", "van"]>;
        deliveryType: z.ZodEnum<["ASAP", "2H", "4H", "NEXT_DAY", "NEXT_3_DAYS"]>;
        services: z.ZodArray<z.ZodEnum<["proofDelivery", "insurance", "door2door"]>, "many">;
        driver: z.ZodObject<z.extendShape<{
            fullname: z.ZodString;
            phone: z.ZodString;
        }, {
            plateNumber: z.ZodString;
            photoURL: z.ZodString;
            location: z.ZodObject<{
                lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }, "strip", z.ZodTypeAny, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            }, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            }>;
        }>, "strip", z.ZodTypeAny, {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        }, {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        }>;
        pickup: z.ZodObject<{
            location_reference_id: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            /** Required if `location_reference_id` is provided */
            name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            productType: z.ZodNullable<z.ZodOptional<z.ZodEnum<["food", "groceries", "flowers", "documents", "medicines", "electronics", "fashion", "fragile", "others"]>>>;
            location: z.ZodObject<z.extendShape<{
                lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }, {
                address: z.ZodString;
                postalCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                country: z.ZodEnum<["SG", "MY", "PH", "TH", "ID"]>;
                /** Unit number, floor, building name etc */
                addressDetails: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                instructions: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            }>, "strip", z.ZodTypeAny, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            }, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            }>;
            sender: z.ZodObject<{
                fullname: z.ZodString;
                phone: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                phone: string;
                fullname: string;
            }, {
                phone: string;
                fullname: string;
            }>;
        }, "strip", z.ZodTypeAny, {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        }, {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        }>;
        dropoffs: z.ZodArray<z.ZodObject<{
            location: z.ZodObject<z.extendShape<{
                lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }, {
                address: z.ZodString;
                postalCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                country: z.ZodEnum<["SG", "MY", "PH", "TH", "ID"]>;
                /** Unit number, floor, building name etc */
                addressDetails: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                instructions: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            }>, "strip", z.ZodTypeAny, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            }, {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            }>;
            receiver: z.ZodObject<{
                fullname: z.ZodString;
                phone: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                phone: string;
                fullname: string;
            }, {
                phone: string;
                fullname: string;
            }>;
            parcels: z.ZodArray<z.ZodObject<{
                description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                /** in centimeters */
                weight: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                /** in centimeters */
                height: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                /** in centimeters */
                width: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                /** in centimeters */
                length: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                value: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                    /** in cents */
                    amount: z.ZodNumber;
                    currency: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    amount: number;
                    currency: string;
                }, {
                    amount: number;
                    currency: string;
                }>>>;
                reference: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                handlingInstructions: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                    containsFluids: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                    fragile: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                    doNotRotate: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                    containsHotFood: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                }, "strip", z.ZodTypeAny, {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                }, {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                }>>>;
                waybillURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            }, "strip", z.ZodTypeAny, {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }, {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }>, "many">;
            /** Order Id in FeedMe */
            orderReferenceId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            proofOfDeliveryURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            /**
             * If enable route optimization, can specify
             * before which dropoff this dropoff should be delivered.
             * Need to provide `orderReferenceId`.
             */
            before: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            /**
             * Tracking URL with complete information
             * (payment & all recipients)
             */
            trackingURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }, {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }>, "many">;
        pricing: z.ZodObject<{
            /** in cents */
            base: z.ZodNumber;
            /** in cents */
            discount: z.ZodNumber;
            /** in cents */
            tax1: z.ZodNumber;
            /** in cents */
            platform_fee: z.ZodNumber;
            /** in cents */
            currency: z.ZodString;
            /** in cents */
            partnerFee: z.ZodNumber;
            /** in cents */
            total: z.ZodNumber;
            /** in cents */
            chargeTotal: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        }, {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        }>;
        totalAmount: z.ZodObject<{
            /** in cents */
            amount: z.ZodNumber;
            currency: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            amount: number;
            currency: string;
        }, {
            amount: number;
            currency: string;
        }>;
        provider: z.ZodEnum<["PANDAGO", "LALAMOVE", "PICKUPP", "ZEEK", "BORZO"]>;
    }, "strip", z.ZodTypeAny, {
        id: string;
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        driver: {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        };
        trackingURL: string;
        autoReassign: boolean;
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        pickup: {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        };
        dropoffs: {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }[];
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        deliveryId: string;
        quoteId: string;
        totalAmount: {
            amount: number;
            currency: string;
        };
    }, {
        id: string;
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        driver: {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        };
        trackingURL: string;
        autoReassign: boolean;
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        pickup: {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        };
        dropoffs: {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }[];
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        deliveryId: string;
        quoteId: string;
        totalAmount: {
            amount: number;
            currency: string;
        };
    }>, "many">;
    meta: z.ZodObject<{
        /** Total number of orders */
        total: z.ZodNumber;
        /** num of orders created */
        created: z.ZodNumber;
        /** num of orders to pick up */
        toPickup: z.ZodNumber;
        /** num of orders picked up */
        pickedUp: z.ZodNumber;
        /** num of orders delivered */
        delivered: z.ZodNumber;
        /** num of orders cancelled */
        cancelled: z.ZodNumber;
        /** num of orders returning */
        returning: z.ZodNumber;
        /** num of orders returned */
        returned: z.ZodNumber;
        /** num of orders at hub */
        at_hub: z.ZodNumber;
        /** num of orders to drop off */
        to_dropoff: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        created: number;
        delivered: number;
        cancelled: number;
        returning: number;
        returned: number;
        at_hub: number;
        to_dropoff: number;
        total: number;
        toPickup: number;
        pickedUp: number;
    }, {
        created: number;
        delivered: number;
        cancelled: number;
        returning: number;
        returned: number;
        at_hub: number;
        to_dropoff: number;
        total: number;
        toPickup: number;
        pickedUp: number;
    }>;
}, "strip", z.ZodTypeAny, {
    meta: {
        created: number;
        delivered: number;
        cancelled: number;
        returning: number;
        returned: number;
        at_hub: number;
        to_dropoff: number;
        total: number;
        toPickup: number;
        pickedUp: number;
    };
    orders: {
        id: string;
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        driver: {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        };
        trackingURL: string;
        autoReassign: boolean;
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        pickup: {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        };
        dropoffs: {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }[];
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        deliveryId: string;
        quoteId: string;
        totalAmount: {
            amount: number;
            currency: string;
        };
    }[];
}, {
    meta: {
        created: number;
        delivered: number;
        cancelled: number;
        returning: number;
        returned: number;
        at_hub: number;
        to_dropoff: number;
        total: number;
        toPickup: number;
        pickedUp: number;
    };
    orders: {
        id: string;
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        driver: {
            phone: string;
            photoURL: string;
            fullname: string;
            plateNumber: string;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
            };
        };
        trackingURL: string;
        autoReassign: boolean;
        deliveryType: "ASAP" | "2H" | "4H" | "NEXT_DAY" | "NEXT_3_DAYS";
        pickup: {
            name?: string | null | undefined;
            location_reference_id?: string | null | undefined;
            productType?: "food" | "groceries" | "flowers" | "documents" | "medicines" | "electronics" | "fashion" | "fragile" | "others" | null | undefined;
            sender: {
                phone: string;
                fullname: string;
            };
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
        };
        dropoffs: {
            orderReferenceId?: string | null | undefined;
            proofOfDeliveryURL?: string | null | undefined;
            before?: string | null | undefined;
            trackingURL?: string | null | undefined;
            location: {
                lat?: number | null | undefined;
                lng?: number | null | undefined;
                postalCode?: string | null | undefined;
                addressDetails?: string | null | undefined;
                instructions?: string | null | undefined;
                address: string;
                country: "SG" | "MY" | "PH" | "TH" | "ID";
            };
            receiver: {
                phone: string;
                fullname: string;
            };
            parcels: {
                length?: number | null | undefined;
                value?: {
                    amount: number;
                    currency: string;
                } | null | undefined;
                description?: string | null | undefined;
                height?: number | null | undefined;
                width?: number | null | undefined;
                weight?: number | null | undefined;
                reference?: string | null | undefined;
                handlingInstructions?: {
                    fragile?: boolean | null | undefined;
                    containsFluids?: boolean | null | undefined;
                    doNotRotate?: boolean | null | undefined;
                    containsHotFood?: boolean | null | undefined;
                } | null | undefined;
                waybillURL?: string | null | undefined;
            }[];
        }[];
        vehicleType: "motorcycle" | "car" | "van";
        provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
        pricing: {
            base: number;
            currency: string;
            discount: number;
            tax1: number;
            platform_fee: number;
            partnerFee: number;
            total: number;
            chargeTotal: number;
        };
        pickupEta: string;
        pickupTillEta: string;
        dropoffEta: string;
        services: ("proofDelivery" | "insurance" | "door2door")[];
        deliveryId: string;
        quoteId: string;
        totalAmount: {
            amount: number;
            currency: string;
        };
    }[];
}>;
export declare const KosmoCancelOrderReq: z.ZodObject<{
    cancellationReason: z.ZodEnum<["no_longer_need_service", "waited_too_long_for_driver", "need_to_change_order_details", "others"]>;
}, "strip", z.ZodTypeAny, {
    cancellationReason: "others" | "no_longer_need_service" | "waited_too_long_for_driver" | "need_to_change_order_details";
}, {
    cancellationReason: "others" | "no_longer_need_service" | "waited_too_long_for_driver" | "need_to_change_order_details";
}>;
export declare const KosmoCancelOrderRes: z.ZodObject<{
    status: z.ZodString;
}, "strip", z.ZodTypeAny, {
    status: string;
}, {
    status: string;
}>;
export declare const KosmoWebhooks: z.ZodObject<{
    /** unique webhook event id */
    eventId: z.ZodString;
    /** KOSMO order id */
    orderId: z.ZodString;
    /** Provider order id */
    deliveryId: z.ZodString;
    /** Provider name */
    provider: z.ZodEnum<["PANDAGO", "LALAMOVE", "PICKUPP", "ZEEK", "BORZO"]>;
    orderStatus: z.ZodEnum<["submitted", "created", "to_pickup", "picked_up", "delivered", "failed", "cancelled", "returning", "returned", "at_hub", "to_dropoff"]>;
    timestamp: z.ZodString;
    /**
     * Signature of payload. Used to check request validity
     *
     * 1. Concatenate eventId, orderId, timestamp
     * 2. Use HMAC SHA256
     * 3. Encode via base64
     */
    signature: z.ZodString;
    driver: z.ZodNullable<z.ZodOptional<z.ZodObject<z.extendShape<{
        fullname: z.ZodString;
        phone: z.ZodString;
    }, {
        plateNumber: z.ZodString;
        photoURL: z.ZodString;
        location: z.ZodObject<{
            lat: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            lng: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        }, {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        }>;
    }>, "strip", z.ZodTypeAny, {
        phone: string;
        photoURL: string;
        fullname: string;
        plateNumber: string;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        };
    }, {
        phone: string;
        photoURL: string;
        fullname: string;
        plateNumber: string;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        };
    }>>>;
    pickupEta: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    pickupTillEta: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    dropoffEta: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    statusHistory: z.ZodArray<z.ZodObject<{
        status: z.ZodEnum<["submitted", "created", "to_pickup", "picked_up", "delivered", "failed", "cancelled", "returning", "returned", "at_hub", "to_dropoff"]>;
        timestamp: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        timestamp: string;
    }, {
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        timestamp: string;
    }>, "many">;
    /**
     * Tracking URL with complete information
     * (payment & all recipients)
     */
    trackingURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    /**
     * Tracking URL with complete information
     * (payment & all recipients)
     */
    providerTrackingURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    /**
     * Proof of delivery URL for each `orderReferenceId` created in order
     *
     * { `[orderReferenceId]`: `[Proof of delivery URL]` }
     */
    proofOfDeliveryURLs: z.ZodNullable<z.ZodOptional<z.ZodAny>>;
    waybillURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    cancellationReason: z.ZodString;
    /**
     * Order status for each `orderReferenceId` created in order
     *
     * { `[orderReferenceId]`: `[KOSMO_DELIVERY_STATUS]` }
     */
    orderReferenceStatus: z.ZodNullable<z.ZodOptional<z.ZodAny>>;
    /**
     * Tracking URL for each `orderReferenceId` created in order
     *
     * { `[orderReferenceId]`: `[tracking url]` }
     */
    trackingIdRef: z.ZodNullable<z.ZodOptional<z.ZodAny>>;
    totalAmount: z.ZodObject<{
        /** in cents */
        amount: z.ZodNumber;
        currency: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        amount: number;
        currency: string;
    }, {
        amount: number;
        currency: string;
    }>;
}, "strip", z.ZodTypeAny, {
    driver?: {
        phone: string;
        photoURL: string;
        fullname: string;
        plateNumber: string;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        };
    } | null | undefined;
    waybillURL?: string | null | undefined;
    trackingURL?: string | null | undefined;
    pickupEta?: string | null | undefined;
    pickupTillEta?: string | null | undefined;
    dropoffEta?: string | null | undefined;
    providerTrackingURL?: string | null | undefined;
    proofOfDeliveryURLs?: any;
    orderReferenceStatus?: any;
    trackingIdRef?: any;
    timestamp: string;
    provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
    deliveryId: string;
    totalAmount: {
        amount: number;
        currency: string;
    };
    cancellationReason: string;
    eventId: string;
    orderId: string;
    orderStatus: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
    signature: string;
    statusHistory: {
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        timestamp: string;
    }[];
}, {
    driver?: {
        phone: string;
        photoURL: string;
        fullname: string;
        plateNumber: string;
        location: {
            lat?: number | null | undefined;
            lng?: number | null | undefined;
        };
    } | null | undefined;
    waybillURL?: string | null | undefined;
    trackingURL?: string | null | undefined;
    pickupEta?: string | null | undefined;
    pickupTillEta?: string | null | undefined;
    dropoffEta?: string | null | undefined;
    providerTrackingURL?: string | null | undefined;
    proofOfDeliveryURLs?: any;
    orderReferenceStatus?: any;
    trackingIdRef?: any;
    timestamp: string;
    provider: "PANDAGO" | "LALAMOVE" | "PICKUPP" | "ZEEK" | "BORZO";
    deliveryId: string;
    totalAmount: {
        amount: number;
        currency: string;
    };
    cancellationReason: string;
    eventId: string;
    orderId: string;
    orderStatus: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
    signature: string;
    statusHistory: {
        status: "created" | "submitted" | "to_pickup" | "picked_up" | "delivered" | "failed" | "cancelled" | "returning" | "returned" | "at_hub" | "to_dropoff";
        timestamp: string;
    }[];
}>;
export type KosmoLocation = z.infer<typeof KosmoLocation>;
export type KosmoPerson = z.infer<typeof KosmoPerson>;
export type KosmoDriver = z.infer<typeof KosmoDriver>;
export type KosmoValue = z.infer<typeof KosmoValue>;
export type KosmoHandlingInstructions = z.infer<typeof KosmoHandlingInstructions>;
export type KosmoParcel = z.infer<typeof KosmoParcel>;
export type KosmoDropOff = z.infer<typeof KosmoDropOff>;
export type KosmoPickUp = z.infer<typeof KosmoPickUp>;
export type KosmoRules = z.infer<typeof KosmoRules>;
export type KosmoCreateQuoteReq = z.infer<typeof KosmoCreateQuoteReq>;
export type KosmoPricing = z.infer<typeof KosmoPricing>;
export type KosmoQuote = z.infer<typeof KosmoQuote>;
export type KosmoCreateQuoteRes = z.infer<typeof KosmoCreateQuoteRes>;
export type KosmoAcceptQuoteDto = z.infer<typeof KosmoAcceptQuoteDto>;
export type KosmoOrder = z.infer<typeof KosmoOrder>;
export type KosmoOrderResponse = z.infer<typeof KosmoOrderResponse>;
export type KosmoMeta = z.infer<typeof KosmoMeta>;
export type KosmoListOrdersResponse = z.infer<typeof KosmoListOrdersResponse>;
export type KosmoCancelOrderReq = z.infer<typeof KosmoCancelOrderReq>;
export type KosmoCancelOrderRes = z.infer<typeof KosmoCancelOrderRes>;
export type KosmoWebhooks = z.infer<typeof KosmoWebhooks>;
export {};
