import { z } from 'zod';
/**
 * \[ISO 639-1 lang. code]: z.string();
 *
 * e.g.: `en`: "Biscuit"
 */
export declare const FPLocaleString: z.ZodIntersection<z.ZodObject<{
    default: z.ZodString;
}, "strip", z.ZodTypeAny, {
    default: string;
}, {
    default: string;
}>, z.ZodRecord<z.ZodString, z.ZodString>>;
export declare const FPBaseItemV2: z.ZodObject<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, "strip", z.ZodTypeAny, {
    id: string;
    type: "ScheduleEntry" | "Menu" | "Product" | "Category" | "Topping" | "Image";
}, {
    id: string;
    type: "ScheduleEntry" | "Menu" | "Product" | "Category" | "Topping" | "Image";
}>;
export declare const FPProductRef: z.ZodObject<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    type: z.ZodLiteral<"Product">;
}>, "strip", z.ZodTypeAny, {
    id: string;
    type: "Product";
}, {
    id: string;
    type: "Product";
}>;
/**
 * Used to set the arrangement order sequence
 * of particular item
 */
export declare const FPBaseOrderedItem: z.ZodObject<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}>, "strip", z.ZodTypeAny, {
    order?: number | null | undefined;
    id: string;
    type: "ScheduleEntry" | "Menu" | "Product" | "Category" | "Topping" | "Image";
}, {
    order?: number | null | undefined;
    id: string;
    type: "ScheduleEntry" | "Menu" | "Product" | "Category" | "Topping" | "Image";
}>;
export declare const FPOrderedImageRef: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}>, {
    type: z.ZodLiteral<"Image">;
}>, "strip", z.ZodTypeAny, {
    order?: number | null | undefined;
    id: string;
    type: "Image";
}, {
    order?: number | null | undefined;
    id: string;
    type: "Image";
}>>;
export declare const FPOrderedProductRef: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}>, z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    type: z.ZodLiteral<"Product">;
}>>, "strip", z.ZodTypeAny, {
    order?: number | null | undefined;
    id: string;
    type: "Product";
}, {
    order?: number | null | undefined;
    id: string;
    type: "Product";
}>>;
export declare const FPOrderedToppingRef: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}>, {
    type: z.ZodLiteral<"Topping">;
}>, "strip", z.ZodTypeAny, {
    order?: number | null | undefined;
    id: string;
    type: "Topping";
}, {
    order?: number | null | undefined;
    id: string;
    type: "Topping";
}>>;
export declare const FPOrderedScheduleEntryRef: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}>, {
    type: z.ZodLiteral<"ScheduleEntry">;
}>, "strip", z.ZodTypeAny, {
    order?: number | null | undefined;
    id: string;
    type: "ScheduleEntry";
}, {
    order?: number | null | undefined;
    id: string;
    type: "ScheduleEntry";
}>>;
export declare const FPCatalogMenuV2: z.ZodObject<z.extendShape<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}>, {
    title: z.ZodIntersection<z.ZodObject<{
        default: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        default: string;
    }, {
        default: string;
    }>, z.ZodRecord<z.ZodString, z.ZodString>>;
    description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
        default: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        default: string;
    }, {
        default: string;
    }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
    images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, {
        type: z.ZodLiteral<"Image">;
    }>, "strip", z.ZodTypeAny, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }>>>>;
    type: z.ZodLiteral<"Menu">;
    menuType: z.ZodEnum<["DELIVERY", "DINE_IN", "PICK_UP"]>;
    products: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        type: z.ZodLiteral<"Product">;
    }>, "strip", z.ZodTypeAny, {
        id: string;
        type: "Product";
    }, {
        id: string;
        type: "Product";
    }>>;
    schedule: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, {
        type: z.ZodLiteral<"ScheduleEntry">;
    }>, "strip", z.ZodTypeAny, {
        order?: number | null | undefined;
        id: string;
        type: "ScheduleEntry";
    }, {
        order?: number | null | undefined;
        id: string;
        type: "ScheduleEntry";
    }>>>>;
}>, "strip", z.ZodTypeAny, {
    description?: ({
        default: string;
    } & Record<string, string>) | null | undefined;
    schedule?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "ScheduleEntry";
    }> | null | undefined;
    order?: number | null | undefined;
    images?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }> | null | undefined;
    title: {
        default: string;
    } & Record<string, string>;
    id: string;
    type: "Menu";
    products: Record<string, {
        id: string;
        type: "Product";
    }>;
    menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
}, {
    description?: ({
        default: string;
    } & Record<string, string>) | null | undefined;
    schedule?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "ScheduleEntry";
    }> | null | undefined;
    order?: number | null | undefined;
    images?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }> | null | undefined;
    title: {
        default: string;
    } & Record<string, string>;
    id: string;
    type: "Menu";
    products: Record<string, {
        id: string;
        type: "Product";
    }>;
    menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
}>;
export declare const FPCatalogProductV2: z.ZodObject<z.extendShape<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    type: z.ZodLiteral<"Product">;
}>, {
    title: z.ZodIntersection<z.ZodObject<{
        default: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        default: string;
    }, {
        default: string;
    }>, z.ZodRecord<z.ZodString, z.ZodString>>;
    description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
        default: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        default: string;
    }, {
        default: string;
    }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
    images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, {
        type: z.ZodLiteral<"Image">;
    }>, "strip", z.ZodTypeAny, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }>>>>;
    parent: z.ZodNullable<z.ZodOptional<z.ZodObject<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        type: z.ZodLiteral<"Product">;
    }>, "strip", z.ZodTypeAny, {
        id: string;
        type: "Product";
    }, {
        id: string;
        type: "Product";
    }>>>;
    active: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
    isPrepackedItem: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
    isExpressItem: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
    excludeDishInformation: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
    /** in format of int32 */
    calories: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    containerPrice: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    price: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    variants: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        type: z.ZodLiteral<"Product">;
    }>>, "strip", z.ZodTypeAny, {
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }, {
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }>>>>;
    toppings: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, {
        type: z.ZodLiteral<"Topping">;
    }>, "strip", z.ZodTypeAny, {
        order?: number | null | undefined;
        id: string;
        type: "Topping";
    }, {
        order?: number | null | undefined;
        id: string;
        type: "Topping";
    }>>>>;
}>, "strip", z.ZodTypeAny, {
    description?: ({
        default: string;
    } & Record<string, string>) | null | undefined;
    price?: string | null | undefined;
    active?: boolean | null | undefined;
    images?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }> | null | undefined;
    parent?: {
        id: string;
        type: "Product";
    } | null | undefined;
    isPrepackedItem?: boolean | null | undefined;
    isExpressItem?: boolean | null | undefined;
    excludeDishInformation?: boolean | null | undefined;
    calories?: number | null | undefined;
    containerPrice?: string | null | undefined;
    variants?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }> | null | undefined;
    toppings?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Topping";
    }> | null | undefined;
    title: {
        default: string;
    } & Record<string, string>;
    id: string;
    type: "Product";
}, {
    description?: ({
        default: string;
    } & Record<string, string>) | null | undefined;
    price?: string | null | undefined;
    active?: boolean | null | undefined;
    images?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }> | null | undefined;
    parent?: {
        id: string;
        type: "Product";
    } | null | undefined;
    isPrepackedItem?: boolean | null | undefined;
    isExpressItem?: boolean | null | undefined;
    excludeDishInformation?: boolean | null | undefined;
    calories?: number | null | undefined;
    containerPrice?: string | null | undefined;
    variants?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }> | null | undefined;
    toppings?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Topping";
    }> | null | undefined;
    title: {
        default: string;
    } & Record<string, string>;
    id: string;
    type: "Product";
}>;
export declare const FPCatalogCategoryV2: z.ZodObject<z.extendShape<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}>, {
    title: z.ZodIntersection<z.ZodObject<{
        default: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        default: string;
    }, {
        default: string;
    }>, z.ZodRecord<z.ZodString, z.ZodString>>;
    description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
        default: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        default: string;
    }, {
        default: string;
    }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
    images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, {
        type: z.ZodLiteral<"Image">;
    }>, "strip", z.ZodTypeAny, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }>>>>;
    type: z.ZodLiteral<"Category">;
    products: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        type: z.ZodLiteral<"Product">;
    }>>, "strip", z.ZodTypeAny, {
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }, {
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }>>;
}>, "strip", z.ZodTypeAny, {
    description?: ({
        default: string;
    } & Record<string, string>) | null | undefined;
    order?: number | null | undefined;
    images?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }> | null | undefined;
    title: {
        default: string;
    } & Record<string, string>;
    id: string;
    type: "Category";
    products: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }>;
}, {
    description?: ({
        default: string;
    } & Record<string, string>) | null | undefined;
    order?: number | null | undefined;
    images?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }> | null | undefined;
    title: {
        default: string;
    } & Record<string, string>;
    id: string;
    type: "Category";
    products: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }>;
}>;
export declare const FPCatalogToppingV2: z.ZodObject<z.extendShape<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}>, {
    title: z.ZodIntersection<z.ZodObject<{
        default: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        default: string;
    }, {
        default: string;
    }>, z.ZodRecord<z.ZodString, z.ZodString>>;
    description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
        default: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        default: string;
    }, {
        default: string;
    }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
    images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, {
        type: z.ZodLiteral<"Image">;
    }>, "strip", z.ZodTypeAny, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }>>>>;
    type: z.ZodLiteral<"Topping">;
    quantity: z.ZodObject<{
        minimum: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        maximum: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        minimum?: number | null | undefined;
        maximum: number;
    }, {
        minimum?: number | null | undefined;
        maximum: number;
    }>;
    products: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, {
        type: z.ZodLiteral<"Product">;
        price: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }>, "strip", z.ZodTypeAny, {
        price?: string | null | undefined;
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }, {
        price?: string | null | undefined;
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }>>;
}>, "strip", z.ZodTypeAny, {
    description?: ({
        default: string;
    } & Record<string, string>) | null | undefined;
    order?: number | null | undefined;
    images?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }> | null | undefined;
    title: {
        default: string;
    } & Record<string, string>;
    id: string;
    type: "Topping";
    quantity: {
        minimum?: number | null | undefined;
        maximum: number;
    };
    products: Record<string, {
        price?: string | null | undefined;
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }>;
}, {
    description?: ({
        default: string;
    } & Record<string, string>) | null | undefined;
    order?: number | null | undefined;
    images?: Record<string, {
        order?: number | null | undefined;
        id: string;
        type: "Image";
    }> | null | undefined;
    title: {
        default: string;
    } & Record<string, string>;
    id: string;
    type: "Topping";
    quantity: {
        minimum?: number | null | undefined;
        maximum: number;
    };
    products: Record<string, {
        price?: string | null | undefined;
        order?: number | null | undefined;
        id: string;
        type: "Product";
    }>;
}>;
export declare const FPCatalogImageV2: z.ZodObject<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    type: z.ZodLiteral<"Image">;
    url: z.ZodString;
    alt: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
        default: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        default: string;
    }, {
        default: string;
    }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
}>, "strip", z.ZodTypeAny, {
    alt?: ({
        default: string;
    } & Record<string, string>) | null | undefined;
    id: string;
    type: "Image";
    url: string;
}, {
    alt?: ({
        default: string;
    } & Record<string, string>) | null | undefined;
    id: string;
    type: "Image";
    url: string;
}>;
export declare const FPCatalogScheduleEntryV2: z.ZodObject<z.extendShape<{
    id: z.ZodString;
    type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
}, {
    type: z.ZodLiteral<"ScheduleEntry">;
    startTime: z.ZodString;
    endTime: z.ZodString;
    startDate: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    endDate: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    weekDays: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodEnum<["MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"]>, "many">>>;
}>, "strip", z.ZodTypeAny, {
    startDate?: string | null | undefined;
    endDate?: string | null | undefined;
    weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
    id: string;
    type: "ScheduleEntry";
    startTime: string;
    endTime: string;
}, {
    startDate?: string | null | undefined;
    endDate?: string | null | undefined;
    weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
    id: string;
    type: "ScheduleEntry";
    startTime: string;
    endTime: string;
}>;
declare const FPCatalogV2: z.ZodObject<{
    items: z.ZodRecord<z.ZodString, z.ZodDiscriminatedUnion<"type", z.Primitive, z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, {
        title: z.ZodIntersection<z.ZodObject<{
            default: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            default: string;
        }, {
            default: string;
        }>, z.ZodRecord<z.ZodString, z.ZodString>>;
        description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
            default: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            default: string;
        }, {
            default: string;
        }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
        images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, {
            type: z.ZodLiteral<"Image">;
        }>, "strip", z.ZodTypeAny, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }>>>>;
        type: z.ZodLiteral<"Menu">;
        menuType: z.ZodEnum<["DELIVERY", "DINE_IN", "PICK_UP"]>;
        products: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            type: z.ZodLiteral<"Product">;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            type: "Product";
        }, {
            id: string;
            type: "Product";
        }>>;
        schedule: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, {
            type: z.ZodLiteral<"ScheduleEntry">;
        }>, "strip", z.ZodTypeAny, {
            order?: number | null | undefined;
            id: string;
            type: "ScheduleEntry";
        }, {
            order?: number | null | undefined;
            id: string;
            type: "ScheduleEntry";
        }>>>>;
    }>, "strip", z.ZodTypeAny, {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        schedule?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "ScheduleEntry";
        }> | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Menu";
        products: Record<string, {
            id: string;
            type: "Product";
        }>;
        menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
    }, {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        schedule?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "ScheduleEntry";
        }> | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Menu";
        products: Record<string, {
            id: string;
            type: "Product";
        }>;
        menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
    }> | z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        type: z.ZodLiteral<"Product">;
    }>, {
        title: z.ZodIntersection<z.ZodObject<{
            default: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            default: string;
        }, {
            default: string;
        }>, z.ZodRecord<z.ZodString, z.ZodString>>;
        description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
            default: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            default: string;
        }, {
            default: string;
        }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
        images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, {
            type: z.ZodLiteral<"Image">;
        }>, "strip", z.ZodTypeAny, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }>>>>;
        parent: z.ZodNullable<z.ZodOptional<z.ZodObject<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            type: z.ZodLiteral<"Product">;
        }>, "strip", z.ZodTypeAny, {
            id: string;
            type: "Product";
        }, {
            id: string;
            type: "Product";
        }>>>;
        active: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
        isPrepackedItem: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
        isExpressItem: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
        excludeDishInformation: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
        /** in format of int32 */
        calories: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        containerPrice: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        price: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        variants: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            type: z.ZodLiteral<"Product">;
        }>>, "strip", z.ZodTypeAny, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }>>>>;
        toppings: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, {
            type: z.ZodLiteral<"Topping">;
        }>, "strip", z.ZodTypeAny, {
            order?: number | null | undefined;
            id: string;
            type: "Topping";
        }, {
            order?: number | null | undefined;
            id: string;
            type: "Topping";
        }>>>>;
    }>, "strip", z.ZodTypeAny, {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        price?: string | null | undefined;
        active?: boolean | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        parent?: {
            id: string;
            type: "Product";
        } | null | undefined;
        isPrepackedItem?: boolean | null | undefined;
        isExpressItem?: boolean | null | undefined;
        excludeDishInformation?: boolean | null | undefined;
        calories?: number | null | undefined;
        containerPrice?: string | null | undefined;
        variants?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }> | null | undefined;
        toppings?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Topping";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Product";
    }, {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        price?: string | null | undefined;
        active?: boolean | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        parent?: {
            id: string;
            type: "Product";
        } | null | undefined;
        isPrepackedItem?: boolean | null | undefined;
        isExpressItem?: boolean | null | undefined;
        excludeDishInformation?: boolean | null | undefined;
        calories?: number | null | undefined;
        containerPrice?: string | null | undefined;
        variants?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }> | null | undefined;
        toppings?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Topping";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Product";
    }> | z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, {
        title: z.ZodIntersection<z.ZodObject<{
            default: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            default: string;
        }, {
            default: string;
        }>, z.ZodRecord<z.ZodString, z.ZodString>>;
        description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
            default: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            default: string;
        }, {
            default: string;
        }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
        images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, {
            type: z.ZodLiteral<"Image">;
        }>, "strip", z.ZodTypeAny, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }>>>>;
        type: z.ZodLiteral<"Category">;
        products: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            type: z.ZodLiteral<"Product">;
        }>>, "strip", z.ZodTypeAny, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }>>;
    }>, "strip", z.ZodTypeAny, {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Category";
        products: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }>;
    }, {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Category";
        products: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }>;
    }> | z.ZodObject<z.extendShape<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }>, {
        title: z.ZodIntersection<z.ZodObject<{
            default: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            default: string;
        }, {
            default: string;
        }>, z.ZodRecord<z.ZodString, z.ZodString>>;
        description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
            default: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            default: string;
        }, {
            default: string;
        }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
        images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, {
            type: z.ZodLiteral<"Image">;
        }>, "strip", z.ZodTypeAny, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }>>>>;
        type: z.ZodLiteral<"Topping">;
        quantity: z.ZodObject<{
            minimum: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            maximum: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            minimum?: number | null | undefined;
            maximum: number;
        }, {
            minimum?: number | null | undefined;
            maximum: number;
        }>;
        products: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, {
            type: z.ZodLiteral<"Product">;
            price: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }>, "strip", z.ZodTypeAny, {
            price?: string | null | undefined;
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }, {
            price?: string | null | undefined;
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }>>;
    }>, "strip", z.ZodTypeAny, {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Topping";
        quantity: {
            minimum?: number | null | undefined;
            maximum: number;
        };
        products: Record<string, {
            price?: string | null | undefined;
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }>;
    }, {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Topping";
        quantity: {
            minimum?: number | null | undefined;
            maximum: number;
        };
        products: Record<string, {
            price?: string | null | undefined;
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }>;
    }> | z.ZodObject<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        type: z.ZodLiteral<"Image">;
        url: z.ZodString;
        alt: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
            default: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            default: string;
        }, {
            default: string;
        }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
    }>, "strip", z.ZodTypeAny, {
        alt?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        id: string;
        type: "Image";
        url: string;
    }, {
        alt?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        id: string;
        type: "Image";
        url: string;
    }> | z.ZodObject<z.extendShape<{
        id: z.ZodString;
        type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
    }, {
        type: z.ZodLiteral<"ScheduleEntry">;
        startTime: z.ZodString;
        endTime: z.ZodString;
        startDate: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        endDate: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        weekDays: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodEnum<["MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"]>, "many">>>;
    }>, "strip", z.ZodTypeAny, {
        startDate?: string | null | undefined;
        endDate?: string | null | undefined;
        weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
        id: string;
        type: "ScheduleEntry";
        startTime: string;
        endTime: string;
    }, {
        startDate?: string | null | undefined;
        endDate?: string | null | undefined;
        weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
        id: string;
        type: "ScheduleEntry";
        startTime: string;
        endTime: string;
    }>>>;
}, "strip", z.ZodTypeAny, {
    items: Record<string, {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        schedule?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "ScheduleEntry";
        }> | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Menu";
        products: Record<string, {
            id: string;
            type: "Product";
        }>;
        menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
    } | {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        price?: string | null | undefined;
        active?: boolean | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        parent?: {
            id: string;
            type: "Product";
        } | null | undefined;
        isPrepackedItem?: boolean | null | undefined;
        isExpressItem?: boolean | null | undefined;
        excludeDishInformation?: boolean | null | undefined;
        calories?: number | null | undefined;
        containerPrice?: string | null | undefined;
        variants?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }> | null | undefined;
        toppings?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Topping";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Product";
    } | {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Category";
        products: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }>;
    } | {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Topping";
        quantity: {
            minimum?: number | null | undefined;
            maximum: number;
        };
        products: Record<string, {
            price?: string | null | undefined;
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }>;
    } | {
        alt?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        id: string;
        type: "Image";
        url: string;
    } | {
        startDate?: string | null | undefined;
        endDate?: string | null | undefined;
        weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
        id: string;
        type: "ScheduleEntry";
        startTime: string;
        endTime: string;
    }>;
}, {
    items: Record<string, {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        schedule?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "ScheduleEntry";
        }> | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Menu";
        products: Record<string, {
            id: string;
            type: "Product";
        }>;
        menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
    } | {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        price?: string | null | undefined;
        active?: boolean | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        parent?: {
            id: string;
            type: "Product";
        } | null | undefined;
        isPrepackedItem?: boolean | null | undefined;
        isExpressItem?: boolean | null | undefined;
        excludeDishInformation?: boolean | null | undefined;
        calories?: number | null | undefined;
        containerPrice?: string | null | undefined;
        variants?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }> | null | undefined;
        toppings?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Topping";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Product";
    } | {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Category";
        products: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }>;
    } | {
        description?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        order?: number | null | undefined;
        images?: Record<string, {
            order?: number | null | undefined;
            id: string;
            type: "Image";
        }> | null | undefined;
        title: {
            default: string;
        } & Record<string, string>;
        id: string;
        type: "Topping";
        quantity: {
            minimum?: number | null | undefined;
            maximum: number;
        };
        products: Record<string, {
            price?: string | null | undefined;
            order?: number | null | undefined;
            id: string;
            type: "Product";
        }>;
    } | {
        alt?: ({
            default: string;
        } & Record<string, string>) | null | undefined;
        id: string;
        type: "Image";
        url: string;
    } | {
        startDate?: string | null | undefined;
        endDate?: string | null | undefined;
        weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
        id: string;
        type: "ScheduleEntry";
        startTime: string;
        endTime: string;
    }>;
}>;
declare const FPMenuV2: z.ZodObject<{
    vendors: z.ZodArray<z.ZodString, "many">;
    callbackUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    catalog: z.ZodObject<{
        items: z.ZodRecord<z.ZodString, z.ZodDiscriminatedUnion<"type", z.Primitive, z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, {
            title: z.ZodIntersection<z.ZodObject<{
                default: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                default: string;
            }, {
                default: string;
            }>, z.ZodRecord<z.ZodString, z.ZodString>>;
            description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
                default: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                default: string;
            }, {
                default: string;
            }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
            images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }>, {
                type: z.ZodLiteral<"Image">;
            }>, "strip", z.ZodTypeAny, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }>>>>;
            type: z.ZodLiteral<"Menu">;
            menuType: z.ZodEnum<["DELIVERY", "DINE_IN", "PICK_UP"]>;
            products: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                type: z.ZodLiteral<"Product">;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                type: "Product";
            }, {
                id: string;
                type: "Product";
            }>>;
            schedule: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }>, {
                type: z.ZodLiteral<"ScheduleEntry">;
            }>, "strip", z.ZodTypeAny, {
                order?: number | null | undefined;
                id: string;
                type: "ScheduleEntry";
            }, {
                order?: number | null | undefined;
                id: string;
                type: "ScheduleEntry";
            }>>>>;
        }>, "strip", z.ZodTypeAny, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            schedule?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "ScheduleEntry";
            }> | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Menu";
            products: Record<string, {
                id: string;
                type: "Product";
            }>;
            menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
        }, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            schedule?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "ScheduleEntry";
            }> | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Menu";
            products: Record<string, {
                id: string;
                type: "Product";
            }>;
            menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
        }> | z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            type: z.ZodLiteral<"Product">;
        }>, {
            title: z.ZodIntersection<z.ZodObject<{
                default: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                default: string;
            }, {
                default: string;
            }>, z.ZodRecord<z.ZodString, z.ZodString>>;
            description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
                default: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                default: string;
            }, {
                default: string;
            }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
            images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }>, {
                type: z.ZodLiteral<"Image">;
            }>, "strip", z.ZodTypeAny, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }>>>>;
            parent: z.ZodNullable<z.ZodOptional<z.ZodObject<z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                type: z.ZodLiteral<"Product">;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                type: "Product";
            }, {
                id: string;
                type: "Product";
            }>>>;
            active: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
            isPrepackedItem: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
            isExpressItem: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
            excludeDishInformation: z.ZodNullable<z.ZodOptional<z.ZodDefault<z.ZodBoolean>>>;
            /** in format of int32 */
            calories: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            containerPrice: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            price: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            variants: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }>, z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                type: z.ZodLiteral<"Product">;
            }>>, "strip", z.ZodTypeAny, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>>>>;
            toppings: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }>, {
                type: z.ZodLiteral<"Topping">;
            }>, "strip", z.ZodTypeAny, {
                order?: number | null | undefined;
                id: string;
                type: "Topping";
            }, {
                order?: number | null | undefined;
                id: string;
                type: "Topping";
            }>>>>;
        }>, "strip", z.ZodTypeAny, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            price?: string | null | undefined;
            active?: boolean | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            parent?: {
                id: string;
                type: "Product";
            } | null | undefined;
            isPrepackedItem?: boolean | null | undefined;
            isExpressItem?: boolean | null | undefined;
            excludeDishInformation?: boolean | null | undefined;
            calories?: number | null | undefined;
            containerPrice?: string | null | undefined;
            variants?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }> | null | undefined;
            toppings?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Topping";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Product";
        }, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            price?: string | null | undefined;
            active?: boolean | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            parent?: {
                id: string;
                type: "Product";
            } | null | undefined;
            isPrepackedItem?: boolean | null | undefined;
            isExpressItem?: boolean | null | undefined;
            excludeDishInformation?: boolean | null | undefined;
            calories?: number | null | undefined;
            containerPrice?: string | null | undefined;
            variants?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }> | null | undefined;
            toppings?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Topping";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Product";
        }> | z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, {
            title: z.ZodIntersection<z.ZodObject<{
                default: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                default: string;
            }, {
                default: string;
            }>, z.ZodRecord<z.ZodString, z.ZodString>>;
            description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
                default: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                default: string;
            }, {
                default: string;
            }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
            images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }>, {
                type: z.ZodLiteral<"Image">;
            }>, "strip", z.ZodTypeAny, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }>>>>;
            type: z.ZodLiteral<"Category">;
            products: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }>, z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                type: z.ZodLiteral<"Product">;
            }>>, "strip", z.ZodTypeAny, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>>;
        }>, "strip", z.ZodTypeAny, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Category";
            products: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        }, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Category";
            products: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        }> | z.ZodObject<z.extendShape<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }>, {
            title: z.ZodIntersection<z.ZodObject<{
                default: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                default: string;
            }, {
                default: string;
            }>, z.ZodRecord<z.ZodString, z.ZodString>>;
            description: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
                default: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                default: string;
            }, {
                default: string;
            }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
            images: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }>, {
                type: z.ZodLiteral<"Image">;
            }>, "strip", z.ZodTypeAny, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }>>>>;
            type: z.ZodLiteral<"Topping">;
            quantity: z.ZodObject<{
                minimum: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                maximum: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                minimum?: number | null | undefined;
                maximum: number;
            }, {
                minimum?: number | null | undefined;
                maximum: number;
            }>;
            products: z.ZodRecord<z.ZodString, z.ZodObject<z.extendShape<z.extendShape<{
                id: z.ZodString;
                type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
            }, {
                order: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }>, {
                type: z.ZodLiteral<"Product">;
                price: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            }>, "strip", z.ZodTypeAny, {
                price?: string | null | undefined;
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }, {
                price?: string | null | undefined;
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>>;
        }>, "strip", z.ZodTypeAny, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Topping";
            quantity: {
                minimum?: number | null | undefined;
                maximum: number;
            };
            products: Record<string, {
                price?: string | null | undefined;
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        }, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Topping";
            quantity: {
                minimum?: number | null | undefined;
                maximum: number;
            };
            products: Record<string, {
                price?: string | null | undefined;
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        }> | z.ZodObject<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            type: z.ZodLiteral<"Image">;
            url: z.ZodString;
            alt: z.ZodNullable<z.ZodOptional<z.ZodIntersection<z.ZodObject<{
                default: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                default: string;
            }, {
                default: string;
            }>, z.ZodRecord<z.ZodString, z.ZodString>>>>;
        }>, "strip", z.ZodTypeAny, {
            alt?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            id: string;
            type: "Image";
            url: string;
        }, {
            alt?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            id: string;
            type: "Image";
            url: string;
        }> | z.ZodObject<z.extendShape<{
            id: z.ZodString;
            type: z.ZodEnum<["ScheduleEntry", "Menu", "Product", "Category", "Topping", "Image"]>;
        }, {
            type: z.ZodLiteral<"ScheduleEntry">;
            startTime: z.ZodString;
            endTime: z.ZodString;
            startDate: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            endDate: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            weekDays: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodEnum<["MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"]>, "many">>>;
        }>, "strip", z.ZodTypeAny, {
            startDate?: string | null | undefined;
            endDate?: string | null | undefined;
            weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
            id: string;
            type: "ScheduleEntry";
            startTime: string;
            endTime: string;
        }, {
            startDate?: string | null | undefined;
            endDate?: string | null | undefined;
            weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
            id: string;
            type: "ScheduleEntry";
            startTime: string;
            endTime: string;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        items: Record<string, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            schedule?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "ScheduleEntry";
            }> | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Menu";
            products: Record<string, {
                id: string;
                type: "Product";
            }>;
            menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            price?: string | null | undefined;
            active?: boolean | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            parent?: {
                id: string;
                type: "Product";
            } | null | undefined;
            isPrepackedItem?: boolean | null | undefined;
            isExpressItem?: boolean | null | undefined;
            excludeDishInformation?: boolean | null | undefined;
            calories?: number | null | undefined;
            containerPrice?: string | null | undefined;
            variants?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }> | null | undefined;
            toppings?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Topping";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Product";
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Category";
            products: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Topping";
            quantity: {
                minimum?: number | null | undefined;
                maximum: number;
            };
            products: Record<string, {
                price?: string | null | undefined;
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        } | {
            alt?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            id: string;
            type: "Image";
            url: string;
        } | {
            startDate?: string | null | undefined;
            endDate?: string | null | undefined;
            weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
            id: string;
            type: "ScheduleEntry";
            startTime: string;
            endTime: string;
        }>;
    }, {
        items: Record<string, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            schedule?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "ScheduleEntry";
            }> | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Menu";
            products: Record<string, {
                id: string;
                type: "Product";
            }>;
            menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            price?: string | null | undefined;
            active?: boolean | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            parent?: {
                id: string;
                type: "Product";
            } | null | undefined;
            isPrepackedItem?: boolean | null | undefined;
            isExpressItem?: boolean | null | undefined;
            excludeDishInformation?: boolean | null | undefined;
            calories?: number | null | undefined;
            containerPrice?: string | null | undefined;
            variants?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }> | null | undefined;
            toppings?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Topping";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Product";
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Category";
            products: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Topping";
            quantity: {
                minimum?: number | null | undefined;
                maximum: number;
            };
            products: Record<string, {
                price?: string | null | undefined;
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        } | {
            alt?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            id: string;
            type: "Image";
            url: string;
        } | {
            startDate?: string | null | undefined;
            endDate?: string | null | undefined;
            weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
            id: string;
            type: "ScheduleEntry";
            startTime: string;
            endTime: string;
        }>;
    }>;
}, "strip", z.ZodTypeAny, {
    callbackUrl?: string | null | undefined;
    vendors: string[];
    catalog: {
        items: Record<string, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            schedule?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "ScheduleEntry";
            }> | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Menu";
            products: Record<string, {
                id: string;
                type: "Product";
            }>;
            menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            price?: string | null | undefined;
            active?: boolean | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            parent?: {
                id: string;
                type: "Product";
            } | null | undefined;
            isPrepackedItem?: boolean | null | undefined;
            isExpressItem?: boolean | null | undefined;
            excludeDishInformation?: boolean | null | undefined;
            calories?: number | null | undefined;
            containerPrice?: string | null | undefined;
            variants?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }> | null | undefined;
            toppings?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Topping";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Product";
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Category";
            products: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Topping";
            quantity: {
                minimum?: number | null | undefined;
                maximum: number;
            };
            products: Record<string, {
                price?: string | null | undefined;
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        } | {
            alt?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            id: string;
            type: "Image";
            url: string;
        } | {
            startDate?: string | null | undefined;
            endDate?: string | null | undefined;
            weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
            id: string;
            type: "ScheduleEntry";
            startTime: string;
            endTime: string;
        }>;
    };
}, {
    callbackUrl?: string | null | undefined;
    vendors: string[];
    catalog: {
        items: Record<string, {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            schedule?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "ScheduleEntry";
            }> | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Menu";
            products: Record<string, {
                id: string;
                type: "Product";
            }>;
            menuType: "DINE_IN" | "DELIVERY" | "PICK_UP";
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            price?: string | null | undefined;
            active?: boolean | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            parent?: {
                id: string;
                type: "Product";
            } | null | undefined;
            isPrepackedItem?: boolean | null | undefined;
            isExpressItem?: boolean | null | undefined;
            excludeDishInformation?: boolean | null | undefined;
            calories?: number | null | undefined;
            containerPrice?: string | null | undefined;
            variants?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }> | null | undefined;
            toppings?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Topping";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Product";
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Category";
            products: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        } | {
            description?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            order?: number | null | undefined;
            images?: Record<string, {
                order?: number | null | undefined;
                id: string;
                type: "Image";
            }> | null | undefined;
            title: {
                default: string;
            } & Record<string, string>;
            id: string;
            type: "Topping";
            quantity: {
                minimum?: number | null | undefined;
                maximum: number;
            };
            products: Record<string, {
                price?: string | null | undefined;
                order?: number | null | undefined;
                id: string;
                type: "Product";
            }>;
        } | {
            alt?: ({
                default: string;
            } & Record<string, string>) | null | undefined;
            id: string;
            type: "Image";
            url: string;
        } | {
            startDate?: string | null | undefined;
            endDate?: string | null | undefined;
            weekDays?: ("MONDAY" | "TUESDAY" | "WEDNESDAY" | "THURSDAY" | "FRIDAY" | "SATURDAY" | "SUNDAY")[] | null | undefined;
            id: string;
            type: "ScheduleEntry";
            startTime: string;
            endTime: string;
        }>;
    };
}>;
export type FPMenuV2 = z.infer<typeof FPMenuV2>;
export type FPLocaleString = z.infer<typeof FPLocaleString>;
export type FPProductRef = z.infer<typeof FPProductRef>;
export type FPOrderedImageRef = z.infer<typeof FPOrderedImageRef>;
export type FPOrderedProductRef = z.infer<typeof FPOrderedProductRef>;
export type FPOrderedToppingRef = z.infer<typeof FPOrderedToppingRef>;
export type FPOrderedScheduleEntryRef = z.infer<typeof FPOrderedScheduleEntryRef>;
export type FPCatalogMenuV2 = z.infer<typeof FPCatalogMenuV2>;
export type FPCatalogProductV2 = z.infer<typeof FPCatalogProductV2>;
export type FPCatalogCategoryV2 = z.infer<typeof FPCatalogCategoryV2>;
export type FPCatalogToppingV2 = z.infer<typeof FPCatalogToppingV2>;
export type FPCatalogImageV2 = z.infer<typeof FPCatalogImageV2>;
export type FPCatalogV2 = z.infer<typeof FPCatalogV2>;
export type FPCatalogScheduleEntryV2 = z.infer<typeof FPCatalogScheduleEntryV2>;
export {};
