import { z } from 'zod';
export declare const FdtoBaseIntegration: z.ZodObject<{
    platform: z.ZodString;
    action: z.ZodEnum<["SYNC_MENU", "UPDATE_ORDER", "GET_OR_UPDATE_SETTING"]>;
}, "strip", z.ZodTypeAny, {
    action: "SYNC_MENU" | "UPDATE_ORDER" | "GET_OR_UPDATE_SETTING";
    platform: string;
}, {
    action: "SYNC_MENU" | "UPDATE_ORDER" | "GET_OR_UPDATE_SETTING";
    platform: string;
}>;
export declare const FdtoIntegrationUpdateOrderReq: z.ZodObject<z.extendShape<{
    platform: z.ZodString;
    action: z.ZodEnum<["SYNC_MENU", "UPDATE_ORDER", "GET_OR_UPDATE_SETTING"]>;
}, {
    status: z.ZodEnum<["REJECT", "DONE_PREPARED", "ACCEPT", "COLLECTED"]>;
    orderId: z.ZodString;
    billId: z.ZodString;
    reason: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    billRev: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}>, "strip", z.ZodTypeAny, {
    reason?: string | null | undefined;
    billRev?: string | null | undefined;
    status: "ACCEPT" | "REJECT" | "DONE_PREPARED" | "COLLECTED";
    orderId: string;
    action: "SYNC_MENU" | "UPDATE_ORDER" | "GET_OR_UPDATE_SETTING";
    platform: string;
    billId: string;
}, {
    reason?: string | null | undefined;
    billRev?: string | null | undefined;
    status: "ACCEPT" | "REJECT" | "DONE_PREPARED" | "COLLECTED";
    orderId: string;
    action: "SYNC_MENU" | "UPDATE_ORDER" | "GET_OR_UPDATE_SETTING";
    platform: string;
    billId: string;
}>;
export declare const FdtoUpdateOrderPlatformSettingReq: z.ZodObject<z.extendShape<{
    platform: z.ZodString;
    action: z.ZodEnum<["SYNC_MENU", "UPDATE_ORDER", "GET_OR_UPDATE_SETTING"]>;
}, {
    /**
     * enable = null -> GET
     * enable = true/false -> UPDATE
     */
    enable: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
}>, "strip", z.ZodTypeAny, {
    enable?: boolean | null | undefined;
    action: "SYNC_MENU" | "UPDATE_ORDER" | "GET_OR_UPDATE_SETTING";
    platform: string;
}, {
    enable?: boolean | null | undefined;
    action: "SYNC_MENU" | "UPDATE_ORDER" | "GET_OR_UPDATE_SETTING";
    platform: string;
}>;
export declare const FdtoUpdateOrderPlatformItemReq: z.ZodObject<{
    /**
     * enable = null -> GET
     * enable = true/false -> UPDATE
     */
    enable: z.ZodBoolean;
    itemId: z.ZodString;
    itemName: z.ZodString;
    groupId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    groupId?: string | null | undefined;
    enable: boolean;
    itemId: string;
    itemName: string;
}, {
    groupId?: string | null | undefined;
    enable: boolean;
    itemId: string;
    itemName: string;
}>;
export declare const FdtoGetOrderDateRange: z.ZodObject<{
    start: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    end: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    start?: string | null | undefined;
    end?: string | null | undefined;
}, {
    start?: string | null | undefined;
    end?: string | null | undefined;
}>;
export declare const FdtoGetOrderReq: z.ZodObject<{
    skip: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    limit: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    date: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        start: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        end: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        start?: string | null | undefined;
        end?: string | null | undefined;
    }, {
        start?: string | null | undefined;
        end?: string | null | undefined;
    }>>>;
    restaurantId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    date?: {
        start?: string | null | undefined;
        end?: string | null | undefined;
    } | null | undefined;
    limit?: number | null | undefined;
    skip?: number | null | undefined;
    restaurantId?: string | null | undefined;
}, {
    date?: {
        start?: string | null | undefined;
        end?: string | null | undefined;
    } | null | undefined;
    limit?: number | null | undefined;
    skip?: number | null | undefined;
    restaurantId?: string | null | undefined;
}>;
export declare const FdtoIntegrationUpdateItem: z.ZodObject<{
    itemId: z.ZodString;
    enable: z.ZodBoolean;
    itemName: z.ZodString;
}, "strip", z.ZodTypeAny, {
    enable: boolean;
    itemId: string;
    itemName: string;
}, {
    enable: boolean;
    itemId: string;
    itemName: string;
}>;
export type FdtoIntegrationUpdateItem = z.infer<typeof FdtoIntegrationUpdateItem>;
export type FdtoGetOrderDateRange = z.infer<typeof FdtoGetOrderDateRange>;
export type FdtoGetOrderReq = z.infer<typeof FdtoGetOrderReq>;
export type FdtoBaseIntegration = z.infer<typeof FdtoBaseIntegration>;
export type FdtoIntegrationUpdateOrderReq = z.infer<typeof FdtoIntegrationUpdateOrderReq>;
export type FdtoUpdateOrderPlatformSettingReq = z.infer<typeof FdtoUpdateOrderPlatformSettingReq>;
