import { z } from 'zod';
export declare const SFConfig: z.ZodObject<{
    vendor_id: z.ZodString;
    vendor_secret: z.ZodString;
    grant_type: z.ZodString;
    scope: z.ZodString;
}, "strip", z.ZodTypeAny, {
    scope: string;
    grant_type: string;
    vendor_id: string;
    vendor_secret: string;
}, {
    scope: string;
    grant_type: string;
    vendor_id: string;
    vendor_secret: string;
}>;
export declare const SFLoginResData: z.ZodObject<{
    access_token: z.ZodString;
    expires_in: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    access_token: string;
    expires_in: number;
}, {
    access_token: string;
    expires_in: number;
}>;
export declare const SFLoginRes: z.ZodObject<{
    code: z.ZodNumber;
    msg: z.ZodString;
    data: z.ZodObject<{
        access_token: z.ZodString;
        expires_in: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        access_token: string;
        expires_in: number;
    }, {
        access_token: string;
        expires_in: number;
    }>;
}, "strip", z.ZodTypeAny, {
    data: {
        access_token: string;
        expires_in: number;
    };
    code: number;
    msg: string;
}, {
    data: {
        access_token: string;
        expires_in: number;
    };
    code: number;
    msg: string;
}>;
export declare const SFLoginReq: z.ZodObject<{
    client_id: z.ZodString;
    client_secret: z.ZodString;
    scope: z.ZodString;
}, "strip", z.ZodTypeAny, {
    client_id: string;
    scope: string;
    client_secret: string;
}, {
    client_id: string;
    scope: string;
    client_secret: string;
}>;
export declare const FdtoShopeefoodGetOrderRes: z.ZodObject<{
    code: z.ZodNumber;
    msg: z.ZodString;
    data: z.ZodObject<{
        currency: z.ZodEnum<["MYR"]>;
        region: z.ZodEnum<["MY"]>;
        status: z.ZodEnum<["DELIVERY_ACCEPTED", "DELIVERY_ARRIVED_STORE", "DELIVERY_PICKED_UP", "DELIVERED", "COMPLETED", "CANCELING", "CANCELED"]>;
        payment_method: z.ZodEnum<["CASH_ON_DELIVERY", "ONLINE_PAYMENT"]>;
        id: z.ZodString;
        store_id: z.ZodString;
        order_short_code: z.ZodString;
        create_time: z.ZodNumber;
        update_time: z.ZodNumber;
        amount: z.ZodObject<{
            merchant_service_fee: z.ZodNumber;
            platform_service_fee: z.ZodNumber;
            shipping_fee: z.ZodNumber;
            shipping_basic_fee: z.ZodNumber;
            shipping_surge_fee: z.ZodNumber;
            small_order_fee: z.ZodNumber;
            promotion: z.ZodObject<{
                shipping_discount_amount: z.ZodNumber;
                shipping_voucher_amount: z.ZodNumber;
                item_discount_amount: z.ZodNumber;
                item_voucher_amount: z.ZodNumber;
                merchant_voucher_subsidy_amount: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            }, {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            }>;
            subtotal: z.ZodNumber;
            tax_amount: z.ZodNumber;
            total_amount: z.ZodNumber;
            merchant_surcharge_fee: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        }, {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        }>;
        items: z.ZodArray<z.ZodObject<{
            detail: z.ZodObject<{
                dish: z.ZodObject<{
                    id: z.ZodString;
                    external_id: z.ZodString;
                    name: z.ZodString;
                    unit_list_price: z.ZodNumber;
                    unit_price: z.ZodNumber;
                    merchant_item_subsidy_amount: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                }, "strip", z.ZodTypeAny, {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                }, {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                }>;
                option_groups: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    external_id: z.ZodString;
                    name: z.ZodString;
                    options: z.ZodArray<z.ZodObject<{
                        id: z.ZodString;
                        external_id: z.ZodString;
                        name: z.ZodString;
                        price: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }, {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }, {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }>, "many">>>;
            }, "strip", z.ZodTypeAny, {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            }, {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            }>;
            subtotal: z.ZodNumber;
            unit_list_price: z.ZodNumber;
            unit_price: z.ZodNumber;
            quantity: z.ZodNumber;
            remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }, {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }>, "many">;
        cancel: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            cancel_reason: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_source: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cencel_proposer: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_time: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        }, {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        }>>>;
        remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        delivery_mode: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        buyer: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            buyer_name: z.ZodString;
            buyer_phone: z.ZodString;
            buyer_address: z.ZodString;
            buyer_latitude: z.ZodNumber;
            buyer_longitude: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        }, {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    }, {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    }>;
}, "strip", z.ZodTypeAny, {
    data: {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    };
    code: number;
    msg: string;
}, {
    data: {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    };
    code: number;
    msg: string;
}>;
export declare const SFGetOrderDto: z.ZodObject<{
    order_id: z.ZodString;
    store_id: z.ZodString;
}, "strip", z.ZodTypeAny, {
    order_id: string;
    store_id: string;
}, {
    order_id: string;
    store_id: string;
}>;
export declare const SFNotifyMenuRes: z.ZodObject<{
    code: z.ZodNumber;
    msg: z.ZodString;
    data: z.ZodNull;
}, "strip", z.ZodTypeAny, {
    data: null;
    code: number;
    msg: string;
}, {
    data: null;
    code: number;
    msg: string;
}>;
export declare const SFGetOrderRes: z.ZodObject<{
    code: z.ZodNumber;
    msg: z.ZodString;
    data: z.ZodObject<{
        currency: z.ZodEnum<["MYR"]>;
        region: z.ZodEnum<["MY"]>;
        status: z.ZodEnum<["DELIVERY_ACCEPTED", "DELIVERY_ARRIVED_STORE", "DELIVERY_PICKED_UP", "DELIVERED", "COMPLETED", "CANCELING", "CANCELED"]>;
        payment_method: z.ZodEnum<["CASH_ON_DELIVERY", "ONLINE_PAYMENT"]>;
        id: z.ZodString;
        store_id: z.ZodString;
        order_short_code: z.ZodString;
        create_time: z.ZodNumber;
        update_time: z.ZodNumber;
        amount: z.ZodObject<{
            merchant_service_fee: z.ZodNumber;
            platform_service_fee: z.ZodNumber;
            shipping_fee: z.ZodNumber;
            shipping_basic_fee: z.ZodNumber;
            shipping_surge_fee: z.ZodNumber;
            small_order_fee: z.ZodNumber;
            promotion: z.ZodObject<{
                shipping_discount_amount: z.ZodNumber;
                shipping_voucher_amount: z.ZodNumber;
                item_discount_amount: z.ZodNumber;
                item_voucher_amount: z.ZodNumber;
                merchant_voucher_subsidy_amount: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            }, {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            }>;
            subtotal: z.ZodNumber;
            tax_amount: z.ZodNumber;
            total_amount: z.ZodNumber;
            merchant_surcharge_fee: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        }, {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        }>;
        items: z.ZodArray<z.ZodObject<{
            detail: z.ZodObject<{
                dish: z.ZodObject<{
                    id: z.ZodString;
                    external_id: z.ZodString;
                    name: z.ZodString;
                    unit_list_price: z.ZodNumber;
                    unit_price: z.ZodNumber;
                    merchant_item_subsidy_amount: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                }, "strip", z.ZodTypeAny, {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                }, {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                }>;
                option_groups: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    external_id: z.ZodString;
                    name: z.ZodString;
                    options: z.ZodArray<z.ZodObject<{
                        id: z.ZodString;
                        external_id: z.ZodString;
                        name: z.ZodString;
                        price: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }, {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }, {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }>, "many">>>;
            }, "strip", z.ZodTypeAny, {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            }, {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            }>;
            subtotal: z.ZodNumber;
            unit_list_price: z.ZodNumber;
            unit_price: z.ZodNumber;
            quantity: z.ZodNumber;
            remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }, {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }>, "many">;
        cancel: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            cancel_reason: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_source: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cencel_proposer: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_time: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        }, {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        }>>>;
        remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        delivery_mode: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        buyer: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            buyer_name: z.ZodString;
            buyer_phone: z.ZodString;
            buyer_address: z.ZodString;
            buyer_latitude: z.ZodNumber;
            buyer_longitude: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        }, {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    }, {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    }>;
}, "strip", z.ZodTypeAny, {
    data: {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    };
    code: number;
    msg: string;
}, {
    data: {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    };
    code: number;
    msg: string;
}>;
export declare const SFRejectMessage: z.ZodObject<{
    reason: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    reason?: string | null | undefined;
}, {
    reason?: string | null | undefined;
}>;
export declare const SFRejectedOrderDto: z.ZodObject<{
    id: z.ZodString;
    store_id: z.ZodString;
    pickup_seq: z.ZodString;
    status: z.ZodEnum<["DELIVERY_ACCEPTED", "DELIVERY_ARRIVED_STORE", "DELIVERY_PICKED_UP", "DELIVERED", "COMPLETED", "CANCELING", "CANCELED"]>;
    message: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        reason: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        reason?: string | null | undefined;
    }, {
        reason?: string | null | undefined;
    }>>>;
}, "strip", z.ZodTypeAny, {
    message?: {
        reason?: string | null | undefined;
    } | null | undefined;
    id: string;
    status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
    store_id: string;
    pickup_seq: string;
}, {
    message?: {
        reason?: string | null | undefined;
    } | null | undefined;
    id: string;
    status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
    store_id: string;
    pickup_seq: string;
}>;
export type SFRejectedOrderDto = z.infer<typeof SFRejectedOrderDto>;
export type SFNotifyMenuRes = z.infer<typeof SFNotifyMenuRes>;
export type SFGetOrderDto = z.infer<typeof SFGetOrderDto>;
export type SFConfig = z.infer<typeof SFConfig>;
export type SFLoginResData = z.infer<typeof SFLoginResData>;
export type SFLoginRes = z.infer<typeof SFLoginRes>;
export type SFLoginReq = z.infer<typeof SFLoginReq>;
export type SFGetOrderRes = z.infer<typeof SFGetOrderRes>;
