import { getData, restaurantClientInstance } from '@/api';
import { KioskOtpDto, KioskDeviceDto } from '@entity';

async function requestOtp(): Promise<KioskOtpDto> {
    const result = await restaurantClientInstance().get('/kiosk/otp');
    return getData<KioskOtpDto>(result);
}

async function getDevices(): Promise<KioskDeviceDto[]> {
    const result = await restaurantClientInstance().get('/kiosk/devices');
    return getData<KioskDeviceDto[]>(result);
}

async function unbind(machineId: string): Promise<void> {
    await restaurantClientInstance().delete(`/kiosk/unbind/${machineId}`);
}

async function updateDevicePin(pinInfo: string, machineId: string): Promise<void> {
    await restaurantClientInstance().put(`/kiosk/updateDevicePin/${machineId}`, { pinInfo });
}

export const KioskApi = {
    requestOtp,
    getDevices,
    unbind,
    updateDevicePin
};