import {
  getData,
  restaurantClientInstance
} from '@/api'
import type { OrderSettingsDto } from '@entity'
import {
  FdoRestaurantDineIn,
  FdoRestaurantPickup,
  FdoRestaurantSetting,
  FdoServiceChargeSetting
} from '@feedmepos/core/entity'
import { baseClientInstance } from '../index'

interface EntityDocument {
  _rev: string
  _id: string
  _deleted?: boolean
}
export type RestaurantSettingDoc = EntityDocument & FdoRestaurantSetting

export const restaurantApi = {
  async readRestaurantSetting(restaurantId: string): Promise<RestaurantSettingDoc> {
    const result = await baseClientInstance().get(`/restaurants/${restaurantId}/restaurant-setting`)
    return getData<RestaurantSettingDoc>(result)
  },
  async updateDineInSetting(setting: FdoRestaurantDineIn) {
    const result = await restaurantClientInstance().put('/dine-in', setting)
    return getData(result)
  },

  async updatePickupSetting(setting: FdoRestaurantPickup) {
    const result = await restaurantClientInstance().put('/pickup', setting)
    return getData(result)
  },

  async updateServiceCharge(setting: FdoServiceChargeSetting) {
    const result = await restaurantClientInstance().put('/service-charge-setting', setting)
    return getData(result)
  },

  async getMobileOrderSetting(): Promise<OrderSettingsDto> {
    return await getData(await restaurantClientInstance().get('/order-settings'))
  }
}
