import type { FdoLayout, FdoLayoutSetting, FdoTable } from '@feedmepos/core/entity';
import { getData, restaurantClientInstance } from '..';

const tableClientInstance = () => restaurantClientInstance('/table');
export const tableSettingApi = {
  async readTables(): Promise<FdoTable[]> {
    return getData(await tableClientInstance().get('/slots'));
  },
  async createTables(tables: { name: string }[]): Promise<FdoTable[]> {
    return getData(await tableClientInstance().post('/slots', tables));
  },
  async updateTable(table: FdoTable): Promise<FdoTable> {
    return getData(await tableClientInstance().put(`/slots/${table._id}`, table));
  },
  async deleteTables(tableIds: string[]): Promise<FdoTable[]> {
    return getData(await tableClientInstance().post('/slots/delete', tableIds));
  },
  async readLayouts(): Promise<FdoLayoutSetting> {
    return getData(await tableClientInstance().get('/layouts'));
  },
  async createLayout(dto: { payload: FdoLayout; layoutSetting: FdoLayoutSetting; }): Promise<FdoLayoutSetting> {
    return getData(await tableClientInstance().post('/layouts', dto));
  },
  async updateLayout(layout: FdoLayoutSetting): Promise<FdoLayoutSetting> {
    return getData(await tableClientInstance().put('/layouts', layout));
  },
  async updateSetting(is: boolean) {
    return getData(await tableClientInstance().put('/layouts/setting', { is }));
  },
};
