import { type SnackbarId, type SnackbarPosition, useSnackbar } from '@feedmepos/ui-library';

export function useSnackbarFunctions() {
  const Snackbar = useSnackbar();

  function showSuccess(message: string) {
    Snackbar.open({
      type: 'success',
      message,
      position: 'bottom' as SnackbarPosition,
    });
  }

  function showError(message: string) {
    Snackbar.open({
      type: 'error',
      message,
      position: 'bottom' as SnackbarPosition,
    });
  }

  let snackbarId: SnackbarId | null = null;

  function showLoading(message: string): SnackbarId {
    snackbarId = Snackbar.open({
      type: 'neutral',
      spinner: true,
      message,
      position: 'bottom' as SnackbarPosition,
      persistent: true  // Ensure the snackbar stays visible until manually closed
    });
    return snackbarId;
  }
  
  function closeLoadingSnackbar() {
    if (snackbarId) {
      Snackbar.close(snackbarId);
      snackbarId = null;  // Reset the snackbar ID after closing
    }
  }
  

  return { showSuccess, showError, showLoading, closeLoadingSnackbar };
}
