import { FdoProfile, FdoAddress } from '@feedmepos/core/entity';

export interface Address extends FdoAddress {
  formatted: string;
  isValidPostcode: boolean;
  isValid: boolean;
  isValidCoordinate: boolean;
}

export interface Profile extends FdoProfile {
  address: Address;
}

export function initAddress(): Address {
  const v = {
    line1: '',
    line2: '',
    city: '',
    postcode: '',
    state: '',
    country: '',
    coordinates: [],
  };
  return formatAddress(v);
}

export function formatAddress(address: any): Address {
  return {
    ...address,

    get formatted(): string {
      const { line1, line2, postcode, city, state, country } = address;
      return [line1, (line2 || ''), postcode, city, state, country]
        .map(v => v.replace(/,\s*$/, ''))
        .filter(v => !!v.trim())
        .join(', ');
    },
    get isValidPostcode(): boolean {
      const res = Number.parseInt(address.postcode);
      return !isNaN(res);
    },
    get isValid(): boolean {
      const optionalFields: (keyof FdoAddress)[] = ['line2'];
      return Object.keys(address)
        .filter((key) => !optionalFields.includes(key as keyof FdoAddress))
        .every(key => !!address[key as keyof FdoAddress]);
    },
    get isValidCoordinate(): boolean {
      return (address.coordinates || []).length === 2;
    },
  };
}