import type { App } from 'vue';
import i18next from 'i18next';
import I18NextVue from 'i18next-vue';

export const appLocale = Object.freeze({
  defaultLocale: 'en',
  supportedLocales: [
    {
      label: 'English',
      value: 'en',
    },
    {
      label: '中文',
      value: 'zh',
    },
  ],
});

export const i18nPromise = i18next
  .init({
    // debug: true,
    ns: ['bill', 'business', 'common', 'device', 'inventory', 'kitchen', 'mall', 'marketing', 'menu', 'order', 'payment', 'printer', 'report', 'restaurant', 'system', 'table', 'transaction', 'user'],
    backend: {
      loadPath: '/locales/{{lng}}/{{ns}}.json',
    },
    fallbackLng: appLocale.defaultLocale,
    i18nFormat: {
      'capitalize': (value: string) => {
        return value.charAt(0).toUpperCase() + value.slice(1);
      },
      'uppercase': (value: string) => {
        return value.toUpperCase();
      },
      'lowercase': (value: string) => {
        return value.toLowerCase();
      },
    }
  });

export default function (app: App) {
  app.use(I18NextVue, { i18next });
  return app;
}