import { defineStore } from 'pinia';

import { FdoCountry, FdoPublicSetting } from '@feedmepos/core/entity';
import { Country, } from '@feedmepos/core';
import { defaultCountry } from '@/api';
import { publicSettingApi } from '@/api/public-setting';


interface AppState {
  country: FdoCountry;
  publicSetting: FdoPublicSetting;
}


function initAppState(): AppState {
  return {
    country: Country.getCountry(defaultCountry) as FdoCountry,
    publicSetting: {
      delivery: {
        feedMe: {
          areas: [],
          enable: false,
          maxDistance: 0,
        },
      },
      sms: {
        firebase: false,
      },
      assets: {
        groups: [],
      },
      aiSettings: {
        remy: { enable: false, }
      }
    } as FdoPublicSetting
  };
}

export const useAppStore = defineStore('app', {
  state: () => {
    return initAppState();
  },
  actions: {
    async getPublicSetting() {
      this.publicSetting = await publicSettingApi.read();
      return this.publicSetting;
    },
    async updatePublicSetting(setting: Partial<FdoPublicSetting>) {
      this.publicSetting = await publicSettingApi.update({
        ...this.publicSetting,
        ...setting
      });
      return this.publicSetting;
    }
  },
});