import { defineStore } from 'pinia'
import { FdtoDiscountRuleRes, FdoDiscountRule } from '@feedmepos/core/entity'
import { useCoreStore } from '@feedmepos/mf-common'
import { ref } from 'vue'
import { businessApi } from '@/api/business'

interface BusinessState {
  discountRule?: FdtoDiscountRuleRes
}

function initBusinessState(): BusinessState {
  return {
    discountRule: undefined
  }
}

export const useBusinessStore = defineStore('business', () => {
  const coreStore = useCoreStore()
  const state = ref(initBusinessState())

  async function readDiscountRule(): Promise<FdtoDiscountRuleRes> {
    if (!coreStore.currentBusiness.value?._id) {
      throw new Error('No business selected.')
    }
    const discountRule = await businessApi.readDiscountRule(coreStore.currentBusiness.value._id)
    state.value.discountRule = discountRule
    return discountRule
  }
  async function updateDiscountRule(discountRule: FdoDiscountRule): Promise<FdtoDiscountRuleRes> {
    if (!coreStore.currentBusiness.value?._id) {
      throw new Error('No business selected.')
    }
    const updatedRule = await businessApi.updateDiscountRule(
      coreStore.currentBusiness.value._id,
      discountRule
    )
    state.value.discountRule = updatedRule
    return updatedRule
  }
  return {
    state: state.value,
    readDiscountRule,
    updateDiscountRule
  }
})
