import { defineStore } from "pinia";
import { KioskApi } from "@/api/kiosk";
import { ref } from 'vue';
import { type MfKioskDevice } from "../../modules/kiosk/interface";
import { KioskMapper } from "./mapper";

interface State {
    otp: string;
    devices: MfKioskDevice[];
}

export const useKioskStore = defineStore('kiosk', () => {

    const state = ref<State>({
        otp: '',
        devices: [],
    });

    async function requestOtp() {
        const result = await KioskApi.requestOtp();
        state.value.otp = result.otp;
    }

    async function getDevices() {
        const result = await KioskApi.getDevices();
        state.value.devices = result.map((r) => KioskMapper.toMfKioskDevice(r));
    }

    async function unbind(machineId: string) {
        await KioskApi.unbind(machineId);
        await getDevices();
    }

    async function updateDevicePin(pinInfo: string, machineId: string) {
        await KioskApi.updateDevicePin(pinInfo, machineId);
    }

    return {
        state: state.value,
        requestOtp,
        getDevices,
        unbind,
        updateDevicePin
    }
});