import { defineStore } from 'pinia';
import { OrderSettingApi } from '@/api/order-setting';
import type { MfKioskOrderSetting } from '@/modules/order-setting/kiosk/interface'
import { OrderSettingMapper } from './mapper';
import { ref } from 'vue';
import { OrderSettingsDto, OrderSettingUpdateDto } from '@entity';


interface State {
    kiosk?: MfKioskOrderSetting,
    orderSetting?: OrderSettingsDto,
}

export const useOrderSettings = defineStore('orderSetting', () => {
    const state = ref<State>({});

    async function getSetting(): Promise<void> {
        const result = await OrderSettingApi.getOrderSetting();
        setStateFromDto(result);
    }

    async function updateKioskSetting() {
        if (state.value.orderSetting && state.value.kiosk) {
            const { _id, ...updateDto } = state.value.orderSetting;
            const kioskUpdate = OrderSettingMapper.toOrderKioskSettingsDto(state.value.kiosk);
            // ^ sequence number will not updated from portal
            const update: OrderSettingUpdateDto = {
                ...updateDto,
                kioskSettings: kioskUpdate.kioskSettings,
            }
            const result = await OrderSettingApi.updateOrderSetting(update);
            setStateFromDto(result);
        }
    }

    function setStateFromDto(dto: OrderSettingsDto) {
        state.value.orderSetting = dto;
        state.value.kiosk = OrderSettingMapper.convertOrderSettingDto(dto).kiosk;
    }

    function setKioskOrderSetting(kioskOrderSetting: MfKioskOrderSetting) {
        state.value.kiosk = kioskOrderSetting;
    }

    return {
        state: state.value,
        getSetting,
        updateKioskSetting,
        setKioskOrderSetting,
    };
});