import { OrderSettingsDto, OrderKioskDineIn, OrderKioskDineInSequenceDto, FdoOrderKioskDineInSequence, FdoEPaymentMethod } from "@entity";
import type { MfKioskOrderSetting, MfKioskDineInSetting, MfDisplayStandSetting, KioskTakeawaySettingForm, MfKioskOrderSettingForm, MfKioskPaymentSetting, MfKioskSubmitOrderInstruction, KioskPickAtCounterSettingForm } from '@/modules/order-setting/kiosk/interface';
import type { MfOrderSetting } from "@/modules/order-setting/interface";
import type { OrderKioskSettings, OrderKioskPaymentSetting } from "@entity";

export const defaultDisplayStand: MfDisplayStandSetting = {
    enabled: false,
    prefix: null,
    padDigit: 0,
    standSlotRange: {
        min: 1,
        max: 10,
    },
    enablePaxDialog: false,
    submitOrderInstruction: {
        payAtCounter: null,
        paid: null,
    },
}

export const defaultTakeaway: KioskTakeawaySettingForm = {
    enabled: false,
    submitOrderInstruction: {
        payAtCounter: null,
        paid: null,
    },
}

export const defaultPickUp: KioskPickAtCounterSettingForm = {
    enabled: false,
    submitOrderInstruction: {
        payAtCounter: null,
        paid: null,
    },
    enablePaxDialog: false,
}

export const defaultKioskOrderSetting: MfKioskOrderSettingForm = {
    dineIn: {
        enabled: false,
        pickUp: defaultPickUp,
        sequenceNumber: FdoOrderKioskDineInSequence.parse({}),
        displayStand: defaultDisplayStand,
    },
    takeaway: defaultTakeaway,
    paymentSetting: {
        paymentTypes: [],
        offlinePaymentTypes: [],
        ePaymentTypes: {
            card: {
                terminal: false,
                nfc: false
            },
            eWallet: {
                qrPay: false,
                scanPay: false
            }
        },
    },
    menuItem: {
        showAllOnly: false,
    }
}

export const defaultSubmitOrderInstruction: MfKioskSubmitOrderInstruction = {
    payAtCounter: null,
    paid: null,
}

const convertOrderSettingDto = (dto: OrderSettingsDto): MfOrderSetting => {
    return {
        kiosk: toKiosk(dto.kioskSettings, dto.sequenceSettings?.kioskDineIn),
    };
}

const toKiosk = (kioskOrderSettings: OrderKioskSettings, kioskDineInSeq?: OrderKioskDineInSequenceDto): MfKioskOrderSetting => {
    return {
        dineIn: toKioskDineInSetting(kioskDineInSeq ?? {
            current: 0,
            prefix: '#K',
        }, kioskOrderSettings.dineIn ?? undefined),
        takeaway: {
            enabled: kioskOrderSettings?.canTakeaway ?? false,
            submitOrderInstruction: kioskOrderSettings?.takeaway?.submitOrderInstruction ? {
                payAtCounter: kioskOrderSettings.takeaway.submitOrderInstruction?.payAtCounter?.['en'] ?? null,
                paid: kioskOrderSettings.takeaway.submitOrderInstruction?.paid?.['en'] ?? null,
            } : defaultSubmitOrderInstruction,
        },
        paymentSetting: {
            paymentTypes: kioskOrderSettings?.paymentSetting?.paymentTypes ?? [],
            offlinePaymentTypes: kioskOrderSettings?.paymentSetting?.offlinePaymentTypes ?? [],
            ePaymentTypes: kioskOrderSettings?.paymentSetting?.ePaymentTypes ?? FdoEPaymentMethod.parse({
                card: {
                    terminal: false,
                    nfc: false
                },
                eWallet: {
                    qrPay: false,
                    scanPay: false
                }
            }),
        },
        menuItem: {
            showAllOnly: kioskOrderSettings.menuItem?.showAllOnly ?? false,
        }
    }
}

const toKioskDineInSetting = (kioskDineInSeq: OrderKioskDineInSequenceDto, kioskDineInSetting?: OrderKioskDineIn): MfKioskDineInSetting => {
    return {
        enabled: !!kioskDineInSetting,
        sequenceNumber: kioskDineInSeq,
        pickUp: kioskDineInSetting?.pickUp ? {
            ...kioskDineInSetting.pickUp,
            submitOrderInstruction: kioskDineInSetting.pickUp.submitOrderInstruction ? {
                payAtCounter: kioskDineInSetting.pickUp.submitOrderInstruction?.payAtCounter?.['en'] ?? null,
                paid: kioskDineInSetting.pickUp.submitOrderInstruction?.paid?.['en'] ?? null,
            } : defaultSubmitOrderInstruction,
            enablePaxDialog: kioskDineInSetting.pickUp.enablePaxDialog ? kioskDineInSetting.pickUp.enablePaxDialog : false,
        } : defaultPickUp,
        displayStand: kioskDineInSetting?.displayStand ? {
            enabled: kioskDineInSetting.displayStand.enabled,
            standSlotRange: kioskDineInSetting.displayStand.standSlotRange,
            prefix: kioskDineInSetting.displayStand.prefix,
            padDigit: kioskDineInSetting.displayStand.padDigit,
            enablePaxDialog: kioskDineInSetting.displayStand.enablePaxDialog ?? false,
            submitOrderInstruction: kioskDineInSetting.displayStand.submitOrderInstruction ? {
                payAtCounter: kioskDineInSetting.displayStand.submitOrderInstruction?.payAtCounter?.['en'] ?? null,
                paid: kioskDineInSetting.displayStand.submitOrderInstruction?.paid?.['en'] ?? null,
            } : defaultSubmitOrderInstruction,
        } : defaultDisplayStand
    }
}
const toOrderKioskSettingsDto = (kioskSetting: MfKioskOrderSetting): {
    kioskSettings: OrderKioskSettings,
    kioskDineIn?: OrderKioskDineInSequenceDto
} => {
    const createDineInSettings = (dineInSetting: MfKioskDineInSetting): OrderKioskDineIn => ({
        requiredSlot: !!dineInSetting.displayStand,
        displayStand: {
            ...dineInSetting.displayStand,
            submitOrderInstruction: {
                payAtCounter: dineInSetting.displayStand.submitOrderInstruction?.payAtCounter ? {
                    en: dineInSetting.displayStand.submitOrderInstruction.payAtCounter,
                } : null,
                paid: dineInSetting.displayStand.submitOrderInstruction?.paid ? {
                    en: dineInSetting.displayStand.submitOrderInstruction.paid,
                } : null,
            }
        },
        pickUp: {
            ...dineInSetting.pickUp,
            submitOrderInstruction: {
                payAtCounter: dineInSetting.pickUp.submitOrderInstruction?.payAtCounter ? {
                    en: dineInSetting.pickUp.submitOrderInstruction.payAtCounter,
                } : null,
                paid: dineInSetting.pickUp.submitOrderInstruction?.paid ? {
                    en: dineInSetting.pickUp.submitOrderInstruction.paid,
                } : null,
            }
        }
    })

    const createKioskSettings = (dineIn?: OrderKioskDineIn): OrderKioskSettings => ({
        canTakeaway: kioskSetting.takeaway.enabled,
        dineIn,
        menuItem: kioskSetting.menuItem,
        paymentSetting: createPaymentSettings(kioskSetting.paymentSetting),
        takeaway: kioskSetting.takeaway.submitOrderInstruction ? {
            submitOrderInstruction: {
                payAtCounter: kioskSetting.takeaway.submitOrderInstruction.payAtCounter ? {
                    en: kioskSetting.takeaway.submitOrderInstruction.payAtCounter,
                } : null,
                paid: kioskSetting.takeaway.submitOrderInstruction.paid ? {
                    en: kioskSetting.takeaway.submitOrderInstruction.paid,
                } : null,
            }
        } : undefined
    })

    const createPaymentSettings = (paymentSetting: MfKioskPaymentSetting): OrderKioskPaymentSetting | undefined => {
        return {
            paymentTypes: paymentSetting.paymentTypes,
            offlinePaymentTypes: paymentSetting.offlinePaymentTypes,
            ePaymentTypes: paymentSetting.ePaymentTypes,
        }
    }

    if (!kioskSetting.dineIn.enabled) {
        return {
            kioskSettings: createKioskSettings()
        }
    }

    return {
        kioskSettings: createKioskSettings(createDineInSettings(kioskSetting.dineIn)),
        kioskDineIn: kioskSetting.dineIn.sequenceNumber,
    }
}



export const OrderSettingMapper = {
    convertOrderSettingDto,
    toOrderKioskSettingsDto,
};