import { F_PAYMENT_NAME, FdoLinkedDelivery } from "@feedmepos/core/entity";

export type LinkedDeliveryDoc = FdoLinkedDelivery & {  _rev: string };

export enum AUTO_INTEGRATION_CLIENT {
  foodpanda = 'foodpanda',
  grabfood = 'grabfood',
  shopeefood = 'shopeefood',
  external = 'external'
}

export interface DeliveryCompany {
    id: string;
    name: string;
    slotPrefix: string;
    paymentTypeKey: string;
    key: string;
  }

function formatDeliveryCompanyKey(key: string) {
  return key.toLowerCase().replace('_', '').toLowerCase();
}

export function useDelivery() {
  function getLinkedDeliveryDoc(docs: LinkedDeliveryDoc[], key: string) {
    return docs.find((doc) => formatDeliveryCompanyKey(doc.key) === formatDeliveryCompanyKey(key));
  }

  function filterLocalDeliveryCompanies(companies: DeliveryCompany[]) {
    return companies.filter(({ key }) => !Object.keys(AUTO_INTEGRATION_CLIENT).includes(formatDeliveryCompanyKey(key)));
  }

  function getPaymentType(paymentTypeKey?: string) {
    return paymentTypeKey === F_PAYMENT_NAME.enum.CASH ? 'Cash' : 'Default';
  }

  function equalKey(key: string, targetKey: string) {
    return formatDeliveryCompanyKey(key) === formatDeliveryCompanyKey(targetKey);
  }

  return { getLinkedDeliveryDoc, filterLocalDeliveryCompanies, getPaymentType, equalKey };
}