import { z } from 'zod';
export declare const FdoShopeeFoodOrderStatus: z.ZodObject<{
    status: z.ZodEnum<["pending", "accepted", "rejected"]>;
    message: z.ZodString;
}, "strip", z.ZodTypeAny, {
    message: string;
    status: "pending" | "accepted" | "rejected";
}, {
    message: string;
    status: "pending" | "accepted" | "rejected";
}>;
export declare const SFPromotion: z.ZodObject<{
    shipping_discount_amount: z.ZodNumber;
    shipping_voucher_amount: z.ZodNumber;
    item_discount_amount: z.ZodNumber;
    item_voucher_amount: z.ZodNumber;
    merchant_voucher_subsidy_amount: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    shipping_discount_amount: number;
    shipping_voucher_amount: number;
    item_discount_amount: number;
    item_voucher_amount: number;
    merchant_voucher_subsidy_amount: number;
}, {
    shipping_discount_amount: number;
    shipping_voucher_amount: number;
    item_discount_amount: number;
    item_voucher_amount: number;
    merchant_voucher_subsidy_amount: number;
}>;
export declare const SFOrderAmount: z.ZodObject<{
    merchant_service_fee: z.ZodNumber;
    platform_service_fee: z.ZodNumber;
    shipping_fee: z.ZodNumber;
    shipping_basic_fee: z.ZodNumber;
    shipping_surge_fee: z.ZodNumber;
    small_order_fee: z.ZodNumber;
    promotion: z.ZodObject<{
        shipping_discount_amount: z.ZodNumber;
        shipping_voucher_amount: z.ZodNumber;
        item_discount_amount: z.ZodNumber;
        item_voucher_amount: z.ZodNumber;
        merchant_voucher_subsidy_amount: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        shipping_discount_amount: number;
        shipping_voucher_amount: number;
        item_discount_amount: number;
        item_voucher_amount: number;
        merchant_voucher_subsidy_amount: number;
    }, {
        shipping_discount_amount: number;
        shipping_voucher_amount: number;
        item_discount_amount: number;
        item_voucher_amount: number;
        merchant_voucher_subsidy_amount: number;
    }>;
    subtotal: z.ZodNumber;
    tax_amount: z.ZodNumber;
    total_amount: z.ZodNumber;
    merchant_surcharge_fee: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    subtotal: number;
    merchant_service_fee: number;
    platform_service_fee: number;
    shipping_fee: number;
    shipping_basic_fee: number;
    shipping_surge_fee: number;
    small_order_fee: number;
    promotion: {
        shipping_discount_amount: number;
        shipping_voucher_amount: number;
        item_discount_amount: number;
        item_voucher_amount: number;
        merchant_voucher_subsidy_amount: number;
    };
    tax_amount: number;
    total_amount: number;
    merchant_surcharge_fee: number;
}, {
    subtotal: number;
    merchant_service_fee: number;
    platform_service_fee: number;
    shipping_fee: number;
    shipping_basic_fee: number;
    shipping_surge_fee: number;
    small_order_fee: number;
    promotion: {
        shipping_discount_amount: number;
        shipping_voucher_amount: number;
        item_discount_amount: number;
        item_voucher_amount: number;
        merchant_voucher_subsidy_amount: number;
    };
    tax_amount: number;
    total_amount: number;
    merchant_surcharge_fee: number;
}>;
export declare const SFOrderDish: z.ZodObject<{
    id: z.ZodString;
    external_id: z.ZodString;
    name: z.ZodString;
    unit_list_price: z.ZodNumber;
    unit_price: z.ZodNumber;
    merchant_item_subsidy_amount: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}, "strip", z.ZodTypeAny, {
    merchant_item_subsidy_amount?: number | null | undefined;
    name: string;
    id: string;
    external_id: string;
    unit_list_price: number;
    unit_price: number;
}, {
    merchant_item_subsidy_amount?: number | null | undefined;
    name: string;
    id: string;
    external_id: string;
    unit_list_price: number;
    unit_price: number;
}>;
export declare const SFItemOption: z.ZodObject<{
    id: z.ZodString;
    external_id: z.ZodString;
    name: z.ZodString;
    price: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    name: string;
    id: string;
    price: number;
    external_id: string;
}, {
    name: string;
    id: string;
    price: number;
    external_id: string;
}>;
export declare const SFItemOptionGroup: z.ZodObject<{
    id: z.ZodString;
    external_id: z.ZodString;
    name: z.ZodString;
    options: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        external_id: z.ZodString;
        name: z.ZodString;
        price: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        name: string;
        id: string;
        price: number;
        external_id: string;
    }, {
        name: string;
        id: string;
        price: number;
        external_id: string;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    name: string;
    id: string;
    options: {
        name: string;
        id: string;
        price: number;
        external_id: string;
    }[];
    external_id: string;
}, {
    name: string;
    id: string;
    options: {
        name: string;
        id: string;
        price: number;
        external_id: string;
    }[];
    external_id: string;
}>;
export declare const SFItemDetail: z.ZodObject<{
    dish: z.ZodObject<{
        id: z.ZodString;
        external_id: z.ZodString;
        name: z.ZodString;
        unit_list_price: z.ZodNumber;
        unit_price: z.ZodNumber;
        merchant_item_subsidy_amount: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }, "strip", z.ZodTypeAny, {
        merchant_item_subsidy_amount?: number | null | undefined;
        name: string;
        id: string;
        external_id: string;
        unit_list_price: number;
        unit_price: number;
    }, {
        merchant_item_subsidy_amount?: number | null | undefined;
        name: string;
        id: string;
        external_id: string;
        unit_list_price: number;
        unit_price: number;
    }>;
    option_groups: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        external_id: z.ZodString;
        name: z.ZodString;
        options: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            external_id: z.ZodString;
            name: z.ZodString;
            price: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            name: string;
            id: string;
            price: number;
            external_id: string;
        }, {
            name: string;
            id: string;
            price: number;
            external_id: string;
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        name: string;
        id: string;
        options: {
            name: string;
            id: string;
            price: number;
            external_id: string;
        }[];
        external_id: string;
    }, {
        name: string;
        id: string;
        options: {
            name: string;
            id: string;
            price: number;
            external_id: string;
        }[];
        external_id: string;
    }>, "many">>>;
}, "strip", z.ZodTypeAny, {
    option_groups?: {
        name: string;
        id: string;
        options: {
            name: string;
            id: string;
            price: number;
            external_id: string;
        }[];
        external_id: string;
    }[] | null | undefined;
    dish: {
        merchant_item_subsidy_amount?: number | null | undefined;
        name: string;
        id: string;
        external_id: string;
        unit_list_price: number;
        unit_price: number;
    };
}, {
    option_groups?: {
        name: string;
        id: string;
        options: {
            name: string;
            id: string;
            price: number;
            external_id: string;
        }[];
        external_id: string;
    }[] | null | undefined;
    dish: {
        merchant_item_subsidy_amount?: number | null | undefined;
        name: string;
        id: string;
        external_id: string;
        unit_list_price: number;
        unit_price: number;
    };
}>;
export declare const SFOrderItem: z.ZodObject<{
    detail: z.ZodObject<{
        dish: z.ZodObject<{
            id: z.ZodString;
            external_id: z.ZodString;
            name: z.ZodString;
            unit_list_price: z.ZodNumber;
            unit_price: z.ZodNumber;
            merchant_item_subsidy_amount: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            merchant_item_subsidy_amount?: number | null | undefined;
            name: string;
            id: string;
            external_id: string;
            unit_list_price: number;
            unit_price: number;
        }, {
            merchant_item_subsidy_amount?: number | null | undefined;
            name: string;
            id: string;
            external_id: string;
            unit_list_price: number;
            unit_price: number;
        }>;
        option_groups: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            external_id: z.ZodString;
            name: z.ZodString;
            options: z.ZodArray<z.ZodObject<{
                id: z.ZodString;
                external_id: z.ZodString;
                name: z.ZodString;
                price: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                name: string;
                id: string;
                price: number;
                external_id: string;
            }, {
                name: string;
                id: string;
                price: number;
                external_id: string;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            name: string;
            id: string;
            options: {
                name: string;
                id: string;
                price: number;
                external_id: string;
            }[];
            external_id: string;
        }, {
            name: string;
            id: string;
            options: {
                name: string;
                id: string;
                price: number;
                external_id: string;
            }[];
            external_id: string;
        }>, "many">>>;
    }, "strip", z.ZodTypeAny, {
        option_groups?: {
            name: string;
            id: string;
            options: {
                name: string;
                id: string;
                price: number;
                external_id: string;
            }[];
            external_id: string;
        }[] | null | undefined;
        dish: {
            merchant_item_subsidy_amount?: number | null | undefined;
            name: string;
            id: string;
            external_id: string;
            unit_list_price: number;
            unit_price: number;
        };
    }, {
        option_groups?: {
            name: string;
            id: string;
            options: {
                name: string;
                id: string;
                price: number;
                external_id: string;
            }[];
            external_id: string;
        }[] | null | undefined;
        dish: {
            merchant_item_subsidy_amount?: number | null | undefined;
            name: string;
            id: string;
            external_id: string;
            unit_list_price: number;
            unit_price: number;
        };
    }>;
    subtotal: z.ZodNumber;
    unit_list_price: z.ZodNumber;
    unit_price: z.ZodNumber;
    quantity: z.ZodNumber;
    remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    remark?: string | null | undefined;
    quantity: number;
    subtotal: number;
    unit_list_price: number;
    unit_price: number;
    detail: {
        option_groups?: {
            name: string;
            id: string;
            options: {
                name: string;
                id: string;
                price: number;
                external_id: string;
            }[];
            external_id: string;
        }[] | null | undefined;
        dish: {
            merchant_item_subsidy_amount?: number | null | undefined;
            name: string;
            id: string;
            external_id: string;
            unit_list_price: number;
            unit_price: number;
        };
    };
}, {
    remark?: string | null | undefined;
    quantity: number;
    subtotal: number;
    unit_list_price: number;
    unit_price: number;
    detail: {
        option_groups?: {
            name: string;
            id: string;
            options: {
                name: string;
                id: string;
                price: number;
                external_id: string;
            }[];
            external_id: string;
        }[] | null | undefined;
        dish: {
            merchant_item_subsidy_amount?: number | null | undefined;
            name: string;
            id: string;
            external_id: string;
            unit_list_price: number;
            unit_price: number;
        };
    };
}>;
export declare const SFOrderCancelInfo: z.ZodObject<{
    cancel_reason: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    cancel_source: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    cencel_proposer: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    cancel_remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    cancel_time: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}, "strip", z.ZodTypeAny, {
    cancel_reason?: string | null | undefined;
    cancel_source?: string | null | undefined;
    cencel_proposer?: string | null | undefined;
    cancel_remark?: string | null | undefined;
    cancel_time?: number | null | undefined;
}, {
    cancel_reason?: string | null | undefined;
    cancel_source?: string | null | undefined;
    cencel_proposer?: string | null | undefined;
    cancel_remark?: string | null | undefined;
    cancel_time?: number | null | undefined;
}>;
export declare const SFBuyer: z.ZodObject<{
    buyer_name: z.ZodString;
    buyer_phone: z.ZodString;
    buyer_address: z.ZodString;
    buyer_latitude: z.ZodNumber;
    buyer_longitude: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    buyer_name: string;
    buyer_phone: string;
    buyer_address: string;
    buyer_latitude: number;
    buyer_longitude: number;
}, {
    buyer_name: string;
    buyer_phone: string;
    buyer_address: string;
    buyer_latitude: number;
    buyer_longitude: number;
}>;
export declare const SFOrder: z.ZodObject<{
    currency: z.ZodEnum<["MYR"]>;
    region: z.ZodEnum<["MY"]>;
    status: z.ZodEnum<["DELIVERY_ACCEPTED", "DELIVERY_ARRIVED_STORE", "DELIVERY_PICKED_UP", "DELIVERED", "COMPLETED", "CANCELING", "CANCELED"]>;
    payment_method: z.ZodEnum<["CASH_ON_DELIVERY", "ONLINE_PAYMENT"]>;
    id: z.ZodString;
    store_id: z.ZodString;
    order_short_code: z.ZodString;
    create_time: z.ZodNumber;
    update_time: z.ZodNumber;
    amount: z.ZodObject<{
        merchant_service_fee: z.ZodNumber;
        platform_service_fee: z.ZodNumber;
        shipping_fee: z.ZodNumber;
        shipping_basic_fee: z.ZodNumber;
        shipping_surge_fee: z.ZodNumber;
        small_order_fee: z.ZodNumber;
        promotion: z.ZodObject<{
            shipping_discount_amount: z.ZodNumber;
            shipping_voucher_amount: z.ZodNumber;
            item_discount_amount: z.ZodNumber;
            item_voucher_amount: z.ZodNumber;
            merchant_voucher_subsidy_amount: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            shipping_discount_amount: number;
            shipping_voucher_amount: number;
            item_discount_amount: number;
            item_voucher_amount: number;
            merchant_voucher_subsidy_amount: number;
        }, {
            shipping_discount_amount: number;
            shipping_voucher_amount: number;
            item_discount_amount: number;
            item_voucher_amount: number;
            merchant_voucher_subsidy_amount: number;
        }>;
        subtotal: z.ZodNumber;
        tax_amount: z.ZodNumber;
        total_amount: z.ZodNumber;
        merchant_surcharge_fee: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        subtotal: number;
        merchant_service_fee: number;
        platform_service_fee: number;
        shipping_fee: number;
        shipping_basic_fee: number;
        shipping_surge_fee: number;
        small_order_fee: number;
        promotion: {
            shipping_discount_amount: number;
            shipping_voucher_amount: number;
            item_discount_amount: number;
            item_voucher_amount: number;
            merchant_voucher_subsidy_amount: number;
        };
        tax_amount: number;
        total_amount: number;
        merchant_surcharge_fee: number;
    }, {
        subtotal: number;
        merchant_service_fee: number;
        platform_service_fee: number;
        shipping_fee: number;
        shipping_basic_fee: number;
        shipping_surge_fee: number;
        small_order_fee: number;
        promotion: {
            shipping_discount_amount: number;
            shipping_voucher_amount: number;
            item_discount_amount: number;
            item_voucher_amount: number;
            merchant_voucher_subsidy_amount: number;
        };
        tax_amount: number;
        total_amount: number;
        merchant_surcharge_fee: number;
    }>;
    items: z.ZodArray<z.ZodObject<{
        detail: z.ZodObject<{
            dish: z.ZodObject<{
                id: z.ZodString;
                external_id: z.ZodString;
                name: z.ZodString;
                unit_list_price: z.ZodNumber;
                unit_price: z.ZodNumber;
                merchant_item_subsidy_amount: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            }, "strip", z.ZodTypeAny, {
                merchant_item_subsidy_amount?: number | null | undefined;
                name: string;
                id: string;
                external_id: string;
                unit_list_price: number;
                unit_price: number;
            }, {
                merchant_item_subsidy_amount?: number | null | undefined;
                name: string;
                id: string;
                external_id: string;
                unit_list_price: number;
                unit_price: number;
            }>;
            option_groups: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                id: z.ZodString;
                external_id: z.ZodString;
                name: z.ZodString;
                options: z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    external_id: z.ZodString;
                    name: z.ZodString;
                    price: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    id: string;
                    price: number;
                    external_id: string;
                }, {
                    name: string;
                    id: string;
                    price: number;
                    external_id: string;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                name: string;
                id: string;
                options: {
                    name: string;
                    id: string;
                    price: number;
                    external_id: string;
                }[];
                external_id: string;
            }, {
                name: string;
                id: string;
                options: {
                    name: string;
                    id: string;
                    price: number;
                    external_id: string;
                }[];
                external_id: string;
            }>, "many">>>;
        }, "strip", z.ZodTypeAny, {
            option_groups?: {
                name: string;
                id: string;
                options: {
                    name: string;
                    id: string;
                    price: number;
                    external_id: string;
                }[];
                external_id: string;
            }[] | null | undefined;
            dish: {
                merchant_item_subsidy_amount?: number | null | undefined;
                name: string;
                id: string;
                external_id: string;
                unit_list_price: number;
                unit_price: number;
            };
        }, {
            option_groups?: {
                name: string;
                id: string;
                options: {
                    name: string;
                    id: string;
                    price: number;
                    external_id: string;
                }[];
                external_id: string;
            }[] | null | undefined;
            dish: {
                merchant_item_subsidy_amount?: number | null | undefined;
                name: string;
                id: string;
                external_id: string;
                unit_list_price: number;
                unit_price: number;
            };
        }>;
        subtotal: z.ZodNumber;
        unit_list_price: z.ZodNumber;
        unit_price: z.ZodNumber;
        quantity: z.ZodNumber;
        remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        remark?: string | null | undefined;
        quantity: number;
        subtotal: number;
        unit_list_price: number;
        unit_price: number;
        detail: {
            option_groups?: {
                name: string;
                id: string;
                options: {
                    name: string;
                    id: string;
                    price: number;
                    external_id: string;
                }[];
                external_id: string;
            }[] | null | undefined;
            dish: {
                merchant_item_subsidy_amount?: number | null | undefined;
                name: string;
                id: string;
                external_id: string;
                unit_list_price: number;
                unit_price: number;
            };
        };
    }, {
        remark?: string | null | undefined;
        quantity: number;
        subtotal: number;
        unit_list_price: number;
        unit_price: number;
        detail: {
            option_groups?: {
                name: string;
                id: string;
                options: {
                    name: string;
                    id: string;
                    price: number;
                    external_id: string;
                }[];
                external_id: string;
            }[] | null | undefined;
            dish: {
                merchant_item_subsidy_amount?: number | null | undefined;
                name: string;
                id: string;
                external_id: string;
                unit_list_price: number;
                unit_price: number;
            };
        };
    }>, "many">;
    cancel: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        cancel_reason: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        cancel_source: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        cencel_proposer: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        cancel_remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        cancel_time: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    }, "strip", z.ZodTypeAny, {
        cancel_reason?: string | null | undefined;
        cancel_source?: string | null | undefined;
        cencel_proposer?: string | null | undefined;
        cancel_remark?: string | null | undefined;
        cancel_time?: number | null | undefined;
    }, {
        cancel_reason?: string | null | undefined;
        cancel_source?: string | null | undefined;
        cencel_proposer?: string | null | undefined;
        cancel_remark?: string | null | undefined;
        cancel_time?: number | null | undefined;
    }>>>;
    remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    delivery_mode: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    buyer: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        buyer_name: z.ZodString;
        buyer_phone: z.ZodString;
        buyer_address: z.ZodString;
        buyer_latitude: z.ZodNumber;
        buyer_longitude: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        buyer_name: string;
        buyer_phone: string;
        buyer_address: string;
        buyer_latitude: number;
        buyer_longitude: number;
    }, {
        buyer_name: string;
        buyer_phone: string;
        buyer_address: string;
        buyer_latitude: number;
        buyer_longitude: number;
    }>>>;
}, "strip", z.ZodTypeAny, {
    cancel?: {
        cancel_reason?: string | null | undefined;
        cancel_source?: string | null | undefined;
        cencel_proposer?: string | null | undefined;
        cancel_remark?: string | null | undefined;
        cancel_time?: number | null | undefined;
    } | null | undefined;
    remark?: string | null | undefined;
    delivery_mode?: number | null | undefined;
    buyer?: {
        buyer_name: string;
        buyer_phone: string;
        buyer_address: string;
        buyer_latitude: number;
        buyer_longitude: number;
    } | null | undefined;
    id: string;
    status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
    amount: {
        subtotal: number;
        merchant_service_fee: number;
        platform_service_fee: number;
        shipping_fee: number;
        shipping_basic_fee: number;
        shipping_surge_fee: number;
        small_order_fee: number;
        promotion: {
            shipping_discount_amount: number;
            shipping_voucher_amount: number;
            item_discount_amount: number;
            item_voucher_amount: number;
            merchant_voucher_subsidy_amount: number;
        };
        tax_amount: number;
        total_amount: number;
        merchant_surcharge_fee: number;
    };
    currency: "MYR";
    payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
    items: {
        remark?: string | null | undefined;
        quantity: number;
        subtotal: number;
        unit_list_price: number;
        unit_price: number;
        detail: {
            option_groups?: {
                name: string;
                id: string;
                options: {
                    name: string;
                    id: string;
                    price: number;
                    external_id: string;
                }[];
                external_id: string;
            }[] | null | undefined;
            dish: {
                merchant_item_subsidy_amount?: number | null | undefined;
                name: string;
                id: string;
                external_id: string;
                unit_list_price: number;
                unit_price: number;
            };
        };
    }[];
    store_id: string;
    region: "MY";
    order_short_code: string;
    create_time: number;
    update_time: number;
}, {
    cancel?: {
        cancel_reason?: string | null | undefined;
        cancel_source?: string | null | undefined;
        cencel_proposer?: string | null | undefined;
        cancel_remark?: string | null | undefined;
        cancel_time?: number | null | undefined;
    } | null | undefined;
    remark?: string | null | undefined;
    delivery_mode?: number | null | undefined;
    buyer?: {
        buyer_name: string;
        buyer_phone: string;
        buyer_address: string;
        buyer_latitude: number;
        buyer_longitude: number;
    } | null | undefined;
    id: string;
    status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
    amount: {
        subtotal: number;
        merchant_service_fee: number;
        platform_service_fee: number;
        shipping_fee: number;
        shipping_basic_fee: number;
        shipping_surge_fee: number;
        small_order_fee: number;
        promotion: {
            shipping_discount_amount: number;
            shipping_voucher_amount: number;
            item_discount_amount: number;
            item_voucher_amount: number;
            merchant_voucher_subsidy_amount: number;
        };
        tax_amount: number;
        total_amount: number;
        merchant_surcharge_fee: number;
    };
    currency: "MYR";
    payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
    items: {
        remark?: string | null | undefined;
        quantity: number;
        subtotal: number;
        unit_list_price: number;
        unit_price: number;
        detail: {
            option_groups?: {
                name: string;
                id: string;
                options: {
                    name: string;
                    id: string;
                    price: number;
                    external_id: string;
                }[];
                external_id: string;
            }[] | null | undefined;
            dish: {
                merchant_item_subsidy_amount?: number | null | undefined;
                name: string;
                id: string;
                external_id: string;
                unit_list_price: number;
                unit_price: number;
            };
        };
    }[];
    store_id: string;
    region: "MY";
    order_short_code: string;
    create_time: number;
    update_time: number;
}>;
export declare const FdoShopeeFoodOrder: z.ZodObject<{
    _id: z.ZodEffects<z.ZodString, string, string>;
    orderStatus: z.ZodObject<{
        status: z.ZodEnum<["pending", "accepted", "rejected"]>;
        message: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        message: string;
        status: "pending" | "accepted" | "rejected";
    }, {
        message: string;
        status: "pending" | "accepted" | "rejected";
    }>;
    raw: z.ZodObject<{
        currency: z.ZodEnum<["MYR"]>;
        region: z.ZodEnum<["MY"]>;
        status: z.ZodEnum<["DELIVERY_ACCEPTED", "DELIVERY_ARRIVED_STORE", "DELIVERY_PICKED_UP", "DELIVERED", "COMPLETED", "CANCELING", "CANCELED"]>;
        payment_method: z.ZodEnum<["CASH_ON_DELIVERY", "ONLINE_PAYMENT"]>;
        id: z.ZodString;
        store_id: z.ZodString;
        order_short_code: z.ZodString;
        create_time: z.ZodNumber;
        update_time: z.ZodNumber;
        amount: z.ZodObject<{
            merchant_service_fee: z.ZodNumber;
            platform_service_fee: z.ZodNumber;
            shipping_fee: z.ZodNumber;
            shipping_basic_fee: z.ZodNumber;
            shipping_surge_fee: z.ZodNumber;
            small_order_fee: z.ZodNumber;
            promotion: z.ZodObject<{
                shipping_discount_amount: z.ZodNumber;
                shipping_voucher_amount: z.ZodNumber;
                item_discount_amount: z.ZodNumber;
                item_voucher_amount: z.ZodNumber;
                merchant_voucher_subsidy_amount: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            }, {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            }>;
            subtotal: z.ZodNumber;
            tax_amount: z.ZodNumber;
            total_amount: z.ZodNumber;
            merchant_surcharge_fee: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        }, {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        }>;
        items: z.ZodArray<z.ZodObject<{
            detail: z.ZodObject<{
                dish: z.ZodObject<{
                    id: z.ZodString;
                    external_id: z.ZodString;
                    name: z.ZodString;
                    unit_list_price: z.ZodNumber;
                    unit_price: z.ZodNumber;
                    merchant_item_subsidy_amount: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                }, "strip", z.ZodTypeAny, {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                }, {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                }>;
                option_groups: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    external_id: z.ZodString;
                    name: z.ZodString;
                    options: z.ZodArray<z.ZodObject<{
                        id: z.ZodString;
                        external_id: z.ZodString;
                        name: z.ZodString;
                        price: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }, {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }, {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }>, "many">>>;
            }, "strip", z.ZodTypeAny, {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            }, {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            }>;
            subtotal: z.ZodNumber;
            unit_list_price: z.ZodNumber;
            unit_price: z.ZodNumber;
            quantity: z.ZodNumber;
            remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }, {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }>, "many">;
        cancel: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            cancel_reason: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_source: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cencel_proposer: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_time: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        }, {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        }>>>;
        remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        delivery_mode: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        buyer: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            buyer_name: z.ZodString;
            buyer_phone: z.ZodString;
            buyer_address: z.ZodString;
            buyer_latitude: z.ZodNumber;
            buyer_longitude: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        }, {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    }, {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    }>;
}, "strip", z.ZodTypeAny, {
    _id: string;
    orderStatus: {
        message: string;
        status: "pending" | "accepted" | "rejected";
    };
    raw: {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    };
}, {
    _id: string;
    orderStatus: {
        message: string;
        status: "pending" | "accepted" | "rejected";
    };
    raw: {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    };
}>;
export declare const FdoShopeeFoodOrderOutput: z.ZodObject<z.extendShape<{
    _id: z.ZodEffects<z.ZodString, string, string>;
    orderStatus: z.ZodObject<{
        status: z.ZodEnum<["pending", "accepted", "rejected"]>;
        message: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        message: string;
        status: "pending" | "accepted" | "rejected";
    }, {
        message: string;
        status: "pending" | "accepted" | "rejected";
    }>;
    raw: z.ZodObject<{
        currency: z.ZodEnum<["MYR"]>;
        region: z.ZodEnum<["MY"]>;
        status: z.ZodEnum<["DELIVERY_ACCEPTED", "DELIVERY_ARRIVED_STORE", "DELIVERY_PICKED_UP", "DELIVERED", "COMPLETED", "CANCELING", "CANCELED"]>;
        payment_method: z.ZodEnum<["CASH_ON_DELIVERY", "ONLINE_PAYMENT"]>;
        id: z.ZodString;
        store_id: z.ZodString;
        order_short_code: z.ZodString;
        create_time: z.ZodNumber;
        update_time: z.ZodNumber;
        amount: z.ZodObject<{
            merchant_service_fee: z.ZodNumber;
            platform_service_fee: z.ZodNumber;
            shipping_fee: z.ZodNumber;
            shipping_basic_fee: z.ZodNumber;
            shipping_surge_fee: z.ZodNumber;
            small_order_fee: z.ZodNumber;
            promotion: z.ZodObject<{
                shipping_discount_amount: z.ZodNumber;
                shipping_voucher_amount: z.ZodNumber;
                item_discount_amount: z.ZodNumber;
                item_voucher_amount: z.ZodNumber;
                merchant_voucher_subsidy_amount: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            }, {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            }>;
            subtotal: z.ZodNumber;
            tax_amount: z.ZodNumber;
            total_amount: z.ZodNumber;
            merchant_surcharge_fee: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        }, {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        }>;
        items: z.ZodArray<z.ZodObject<{
            detail: z.ZodObject<{
                dish: z.ZodObject<{
                    id: z.ZodString;
                    external_id: z.ZodString;
                    name: z.ZodString;
                    unit_list_price: z.ZodNumber;
                    unit_price: z.ZodNumber;
                    merchant_item_subsidy_amount: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
                }, "strip", z.ZodTypeAny, {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                }, {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                }>;
                option_groups: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    external_id: z.ZodString;
                    name: z.ZodString;
                    options: z.ZodArray<z.ZodObject<{
                        id: z.ZodString;
                        external_id: z.ZodString;
                        name: z.ZodString;
                        price: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }, {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }, {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }>, "many">>>;
            }, "strip", z.ZodTypeAny, {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            }, {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            }>;
            subtotal: z.ZodNumber;
            unit_list_price: z.ZodNumber;
            unit_price: z.ZodNumber;
            quantity: z.ZodNumber;
            remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }, {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }>, "many">;
        cancel: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            cancel_reason: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_source: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cencel_proposer: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            cancel_time: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        }, {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        }>>>;
        remark: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        delivery_mode: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        buyer: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            buyer_name: z.ZodString;
            buyer_phone: z.ZodString;
            buyer_address: z.ZodString;
            buyer_latitude: z.ZodNumber;
            buyer_longitude: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        }, {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    }, {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    }>;
}, {
    pf_restaurant: z.ZodNullable<z.ZodOptional<z.ZodObject<{
        _id: z.ZodEffects<z.ZodString, string, string>;
        businessId: z.ZodString;
        pf_business: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            _id: z.ZodEffects<z.ZodString, string, string>;
            ownerId: z.ZodString;
            name: z.ZodString;
            restaurantQuota: z.ZodNumber;
            warehouseQuota: z.ZodNumber;
            menuVersion: z.ZodString;
            internal: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            expiredAt: z.ZodNullable<z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>>;
            url: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            agentId: z.ZodNullable<z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>>;
            attributeSettings: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                key: z.ZodString;
                type: z.ZodUnion<[z.ZodLiteral<"string">, z.ZodLiteral<"number">, z.ZodLiteral<"date">, z.ZodLiteral<"boolean">]>;
                entity: z.ZodUnion<[z.ZodLiteral<"restaurant">, z.ZodLiteral<"item">, z.ZodLiteral<"group">, z.ZodLiteral<"inventorySku">, z.ZodLiteral<"inventoryRecipe">, z.ZodLiteral<"warehouse">]>;
                options: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodAny, "many">>>;
            }, "strip", z.ZodTypeAny, {
                options?: any[] | null | undefined;
                type: "string" | "number" | "boolean" | "date";
                key: string;
                entity: "restaurant" | "item" | "group" | "inventorySku" | "inventoryRecipe" | "warehouse";
            }, {
                options?: any[] | null | undefined;
                type: "string" | "number" | "boolean" | "date";
                key: string;
                entity: "restaurant" | "item" | "group" | "inventorySku" | "inventoryRecipe" | "warehouse";
            }>, "many">>>;
            pf_agent: z.ZodNullable<z.ZodOptional<z.ZodLazy<z.ZodObject<{
                _id: z.ZodEffects<z.ZodString, string, string>;
                name: z.ZodString;
                code: z.ZodString;
                isReseller: z.ZodBoolean;
                clickupId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                members: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                    userId: z.ZodString;
                    pf_user: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                        _id: z.ZodString;
                        birthday: z.ZodNullable<z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>>;
                        gender: z.ZodNullable<z.ZodOptional<z.ZodEnum<["MALE", "FEMALE"]>>>;
                        addresses: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                            name: z.ZodString;
                            address: z.ZodString;
                            coordinates: z.ZodArray<z.ZodNumber, "many">;
                        }, "strip", z.ZodTypeAny, {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }, {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }>, "many">>>;
                        email: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                        photoURL: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                        displayName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                        phoneNumber: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                        imported: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                            source: z.ZodEnum<["FEEDME", "CITY_POS", "STOREHUB", "KERUYUn", "QISOFT", "WECHAT", "TEABAR", "NULL_MEMBER", "UMAI_POS", "QASHIER", "XILNET", "GENIUSPOS", "YHOFOODIE"]>;
                            raw: z.ZodRecord<z.ZodString, z.ZodAny>;
                        }, "strip", z.ZodTypeAny, {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        }, {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        }>>>;
                    }, "strip", z.ZodTypeAny, {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    }, {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    }>>>;
                    role: z.ZodEnum<["ADMIN"]>;
                }, "strip", z.ZodTypeAny, {
                    pf_user?: {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    } | null | undefined;
                    role: "ADMIN";
                    userId: string;
                }, {
                    pf_user?: {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    } | null | undefined;
                    role: "ADMIN";
                    userId: string;
                }>, "many">>>;
            }, "strip", z.ZodTypeAny, {
                clickupId?: string | null | undefined;
                members?: {
                    pf_user?: {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    } | null | undefined;
                    role: "ADMIN";
                    userId: string;
                }[] | null | undefined;
                code: string;
                name: string;
                _id: string;
                isReseller: boolean;
            }, {
                clickupId?: string | null | undefined;
                members?: {
                    pf_user?: {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    } | null | undefined;
                    role: "ADMIN";
                    userId: string;
                }[] | null | undefined;
                code: string;
                name: string;
                _id: string;
                isReseller: boolean;
            }>>>>;
            thumbnail: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            billingInfos: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                _id: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                companyName: z.ZodString;
                name: z.ZodString;
                email: z.ZodString;
                contact: z.ZodString;
                address: z.ZodObject<{
                    line1: z.ZodString;
                    line2: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                    state: z.ZodString;
                    city: z.ZodString;
                    postcode: z.ZodString;
                    country: z.ZodString;
                    coordinates: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodNumber, "many">>>;
                }, "strip", z.ZodTypeAny, {
                    coordinates?: number[] | null | undefined;
                    line2?: string | null | undefined;
                    state: string;
                    country: string;
                    line1: string;
                    city: string;
                    postcode: string;
                }, {
                    coordinates?: number[] | null | undefined;
                    line2?: string | null | undefined;
                    state: string;
                    country: string;
                    line1: string;
                    city: string;
                    postcode: string;
                }>;
            }, "strip", z.ZodTypeAny, {
                _id?: string | null | undefined;
                name: string;
                address: {
                    coordinates?: number[] | null | undefined;
                    line2?: string | null | undefined;
                    state: string;
                    country: string;
                    line1: string;
                    city: string;
                    postcode: string;
                };
                email: string;
                companyName: string;
                contact: string;
            }, {
                _id?: string | null | undefined;
                name: string;
                address: {
                    coordinates?: number[] | null | undefined;
                    line2?: string | null | undefined;
                    state: string;
                    country: string;
                    line1: string;
                    city: string;
                    postcode: string;
                };
                email: string;
                companyName: string;
                contact: string;
            }>, "many">>>;
            customerDisplayImages: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                url: z.ZodString;
                restaurantIds: z.ZodArray<z.ZodString, "many">;
            }, "strip", z.ZodTypeAny, {
                url: string;
                restaurantIds: string[];
            }, {
                url: string;
                restaurantIds: string[];
            }>, "many">>>;
        }, "strip", z.ZodTypeAny, {
            internal?: boolean | null | undefined;
            url?: string | null | undefined;
            expiredAt?: string | null | undefined;
            agentId?: string | null | undefined;
            attributeSettings?: {
                options?: any[] | null | undefined;
                type: "string" | "number" | "boolean" | "date";
                key: string;
                entity: "restaurant" | "item" | "group" | "inventorySku" | "inventoryRecipe" | "warehouse";
            }[] | null | undefined;
            pf_agent?: {
                clickupId?: string | null | undefined;
                members?: {
                    pf_user?: {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    } | null | undefined;
                    role: "ADMIN";
                    userId: string;
                }[] | null | undefined;
                code: string;
                name: string;
                _id: string;
                isReseller: boolean;
            } | null | undefined;
            thumbnail?: string | null | undefined;
            billingInfos?: {
                _id?: string | null | undefined;
                name: string;
                address: {
                    coordinates?: number[] | null | undefined;
                    line2?: string | null | undefined;
                    state: string;
                    country: string;
                    line1: string;
                    city: string;
                    postcode: string;
                };
                email: string;
                companyName: string;
                contact: string;
            }[] | null | undefined;
            customerDisplayImages?: {
                url: string;
                restaurantIds: string[];
            }[] | null | undefined;
            name: string;
            _id: string;
            ownerId: string;
            restaurantQuota: number;
            warehouseQuota: number;
            menuVersion: string;
        }, {
            internal?: boolean | null | undefined;
            url?: string | null | undefined;
            expiredAt?: string | null | undefined;
            agentId?: string | null | undefined;
            attributeSettings?: {
                options?: any[] | null | undefined;
                type: "string" | "number" | "boolean" | "date";
                key: string;
                entity: "restaurant" | "item" | "group" | "inventorySku" | "inventoryRecipe" | "warehouse";
            }[] | null | undefined;
            pf_agent?: {
                clickupId?: string | null | undefined;
                members?: {
                    pf_user?: {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    } | null | undefined;
                    role: "ADMIN";
                    userId: string;
                }[] | null | undefined;
                code: string;
                name: string;
                _id: string;
                isReseller: boolean;
            } | null | undefined;
            thumbnail?: string | null | undefined;
            billingInfos?: {
                _id?: string | null | undefined;
                name: string;
                address: {
                    coordinates?: number[] | null | undefined;
                    line2?: string | null | undefined;
                    state: string;
                    country: string;
                    line1: string;
                    city: string;
                    postcode: string;
                };
                email: string;
                companyName: string;
                contact: string;
            }[] | null | undefined;
            customerDisplayImages?: {
                url: string;
                restaurantIds: string[];
            }[] | null | undefined;
            name: string;
            _id: string;
            ownerId: string;
            restaurantQuota: number;
            warehouseQuota: number;
            menuVersion: string;
        }>>>;
        features: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodNativeEnum<{
            stock: string;
            discovery: string;
            pickup: string;
            delivery: string;
            foodpanda: string;
            deliveryIntegration: string;
            kds: string;
            ods: string;
        }>, "many">>>;
        expiredAt: z.ZodEffects<z.ZodString, string, string>;
        machineOtp: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        machineOtpExpiredAt: z.ZodNullable<z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>>;
        machineId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        channel: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        posVersion: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        posHeartbeat: z.ZodNullable<z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>>;
        posVersionHistory: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>>;
        profile: z.ZodObject<{
            _id: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            name: z.ZodString;
            address: z.ZodObject<{
                line1: z.ZodString;
                line2: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                state: z.ZodString;
                city: z.ZodString;
                postcode: z.ZodString;
                country: z.ZodString;
                coordinates: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodNumber, "many">>>;
            }, "strip", z.ZodTypeAny, {
                coordinates?: number[] | null | undefined;
                line2?: string | null | undefined;
                state: string;
                country: string;
                line1: string;
                city: string;
                postcode: string;
            }, {
                coordinates?: number[] | null | undefined;
                line2?: string | null | undefined;
                state: string;
                country: string;
                line1: string;
                city: string;
                postcode: string;
            }>;
            phoneNo: z.ZodString;
            email: z.ZodString;
            regNo: z.ZodString;
            legalName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            sstRegNo: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            discovery: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            coverPhoto: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            thumbnailPhoto: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            photos: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
            operatingHours: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                0: z.ZodObject<{
                    enable: z.ZodBoolean;
                    hours: z.ZodArray<z.ZodObject<{
                        start: z.ZodString;
                        end: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        end: string;
                        start: string;
                    }, {
                        end: string;
                        start: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }>;
                1: z.ZodObject<{
                    enable: z.ZodBoolean;
                    hours: z.ZodArray<z.ZodObject<{
                        start: z.ZodString;
                        end: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        end: string;
                        start: string;
                    }, {
                        end: string;
                        start: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }>;
                2: z.ZodObject<{
                    enable: z.ZodBoolean;
                    hours: z.ZodArray<z.ZodObject<{
                        start: z.ZodString;
                        end: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        end: string;
                        start: string;
                    }, {
                        end: string;
                        start: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }>;
                3: z.ZodObject<{
                    enable: z.ZodBoolean;
                    hours: z.ZodArray<z.ZodObject<{
                        start: z.ZodString;
                        end: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        end: string;
                        start: string;
                    }, {
                        end: string;
                        start: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }>;
                4: z.ZodObject<{
                    enable: z.ZodBoolean;
                    hours: z.ZodArray<z.ZodObject<{
                        start: z.ZodString;
                        end: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        end: string;
                        start: string;
                    }, {
                        end: string;
                        start: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }>;
                5: z.ZodObject<{
                    enable: z.ZodBoolean;
                    hours: z.ZodArray<z.ZodObject<{
                        start: z.ZodString;
                        end: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        end: string;
                        start: string;
                    }, {
                        end: string;
                        start: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }>;
                6: z.ZodObject<{
                    enable: z.ZodBoolean;
                    hours: z.ZodArray<z.ZodObject<{
                        start: z.ZodString;
                        end: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        end: string;
                        start: string;
                    }, {
                        end: string;
                        start: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }, {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                }>;
            }, "strip", z.ZodTypeAny, {
                0: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                2: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                1: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                3: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                4: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                5: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                6: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
            }, {
                0: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                2: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                1: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                3: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                4: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                5: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                6: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
            }>>>;
            tags: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
            url: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            code?: string | null | undefined;
            url?: string | null | undefined;
            description?: string | null | undefined;
            _id?: string | null | undefined;
            legalName?: string | null | undefined;
            sstRegNo?: string | null | undefined;
            discovery?: boolean | null | undefined;
            coverPhoto?: string | null | undefined;
            thumbnailPhoto?: string | null | undefined;
            photos?: string[] | null | undefined;
            operatingHours?: {
                0: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                2: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                1: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                3: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                4: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                5: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                6: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
            } | null | undefined;
            tags?: string[] | null | undefined;
            name: string;
            address: {
                coordinates?: number[] | null | undefined;
                line2?: string | null | undefined;
                state: string;
                country: string;
                line1: string;
                city: string;
                postcode: string;
            };
            email: string;
            phoneNo: string;
            regNo: string;
        }, {
            code?: string | null | undefined;
            url?: string | null | undefined;
            description?: string | null | undefined;
            _id?: string | null | undefined;
            legalName?: string | null | undefined;
            sstRegNo?: string | null | undefined;
            discovery?: boolean | null | undefined;
            coverPhoto?: string | null | undefined;
            thumbnailPhoto?: string | null | undefined;
            photos?: string[] | null | undefined;
            operatingHours?: {
                0: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                2: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                1: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                3: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                4: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                5: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                6: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
            } | null | undefined;
            tags?: string[] | null | undefined;
            name: string;
            address: {
                coordinates?: number[] | null | undefined;
                line2?: string | null | undefined;
                state: string;
                country: string;
                line1: string;
                city: string;
                postcode: string;
            };
            email: string;
            phoneNo: string;
            regNo: string;
        }>;
        catalogId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        additionalCatalogs: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
        inHouseDelivery: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            enable: z.ZodBoolean;
            areas: z.ZodArray<z.ZodObject<{
                polygon: z.ZodArray<z.ZodArray<z.ZodNumber, "many">, "many">;
                deliveryFee: z.ZodObject<{
                    currency: z.ZodIntersection<z.ZodString, z.ZodUnion<[z.ZodLiteral<"AED">, z.ZodLiteral<"AFN">, z.ZodLiteral<"ALL">, z.ZodLiteral<"AMD">, z.ZodLiteral<"ANG">, z.ZodLiteral<"AOA">, z.ZodLiteral<"ARS">, z.ZodLiteral<"AUD">, z.ZodLiteral<"AWG">, z.ZodLiteral<"AZN">, z.ZodLiteral<"BAM">, z.ZodLiteral<"BBD">, z.ZodLiteral<"BDT">, z.ZodLiteral<"BGN">, z.ZodLiteral<"BHD">, z.ZodLiteral<"BIF">, z.ZodLiteral<"BMD">, z.ZodLiteral<"BND">, z.ZodLiteral<"BOB">, z.ZodLiteral<"BOV">, z.ZodLiteral<"BRL">, z.ZodLiteral<"BSD">, z.ZodLiteral<"BTN">, z.ZodLiteral<"BWP">, z.ZodLiteral<"BYN">, z.ZodLiteral<"BZD">, z.ZodLiteral<"CAD">, z.ZodLiteral<"CDF">, z.ZodLiteral<"CHE">, z.ZodLiteral<"CHF">, z.ZodLiteral<"CHW">, z.ZodLiteral<"CLF">, z.ZodLiteral<"CLP">, z.ZodLiteral<"CNY">, z.ZodLiteral<"COP">, z.ZodLiteral<"COU">, z.ZodLiteral<"CRC">, z.ZodLiteral<"CUC">, z.ZodLiteral<"CUP">, z.ZodLiteral<"CVE">, z.ZodLiteral<"CZK">, z.ZodLiteral<"DJF">, z.ZodLiteral<"DKK">, z.ZodLiteral<"DOP">, z.ZodLiteral<"DZD">, z.ZodLiteral<"EGP">, z.ZodLiteral<"ERN">, z.ZodLiteral<"ETB">, z.ZodLiteral<"EUR">, z.ZodLiteral<"FJD">, z.ZodLiteral<"FKP">, z.ZodLiteral<"GBP">, z.ZodLiteral<"GEL">, z.ZodLiteral<"GHS">, z.ZodLiteral<"GIP">, z.ZodLiteral<"GMD">, z.ZodLiteral<"GNF">, z.ZodLiteral<"GTQ">, z.ZodLiteral<"GYD">, z.ZodLiteral<"HKD">, z.ZodLiteral<"HNL">, z.ZodLiteral<"HRK">, z.ZodLiteral<"HTG">, z.ZodLiteral<"HUF">, z.ZodLiteral<"IDR">, z.ZodLiteral<"ILS">, z.ZodLiteral<"INR">, z.ZodLiteral<"IQD">, z.ZodLiteral<"IRR">, z.ZodLiteral<"ISK">, z.ZodLiteral<"JMD">, z.ZodLiteral<"JOD">, z.ZodLiteral<"JPY">, z.ZodLiteral<"KES">, z.ZodLiteral<"KGS">, z.ZodLiteral<"KHR">, z.ZodLiteral<"KMF">, z.ZodLiteral<"KPW">, z.ZodLiteral<"KRW">, z.ZodLiteral<"KWD">, z.ZodLiteral<"KYD">, z.ZodLiteral<"KZT">, z.ZodLiteral<"LAK">, z.ZodLiteral<"LBP">, z.ZodLiteral<"LKR">, z.ZodLiteral<"LRD">, z.ZodLiteral<"LSL">, z.ZodLiteral<"LYD">, z.ZodLiteral<"MAD">, z.ZodLiteral<"MDL">, z.ZodLiteral<"MGA">, z.ZodLiteral<"MKD">, z.ZodLiteral<"MMK">, z.ZodLiteral<"MNT">, z.ZodLiteral<"MOP">, z.ZodLiteral<"MRU">, z.ZodLiteral<"MUR">, z.ZodLiteral<"MVR">, z.ZodLiteral<"MWK">, z.ZodLiteral<"MXN">, z.ZodLiteral<"MXV">, z.ZodLiteral<"MYR">, z.ZodLiteral<"MZN">, z.ZodLiteral<"NAD">, z.ZodLiteral<"NGN">, z.ZodLiteral<"NIO">, z.ZodLiteral<"NOK">, z.ZodLiteral<"NPR">, z.ZodLiteral<"NZD">, z.ZodLiteral<"OMR">, z.ZodLiteral<"PAB">, z.ZodLiteral<"PEN">, z.ZodLiteral<"PGK">, z.ZodLiteral<"PHP">, z.ZodLiteral<"PKR">, z.ZodLiteral<"PLN">, z.ZodLiteral<"PYG">, z.ZodLiteral<"QAR">, z.ZodLiteral<"RON">, z.ZodLiteral<"RSD">, z.ZodLiteral<"RUB">, z.ZodLiteral<"RWF">, z.ZodLiteral<"SAR">, z.ZodLiteral<"SBD">, z.ZodLiteral<"SCR">, z.ZodLiteral<"SDG">, z.ZodLiteral<"SEK">, z.ZodLiteral<"SGD">, z.ZodLiteral<"SHP">, z.ZodLiteral<"SLL">, z.ZodLiteral<"SOS">, z.ZodLiteral<"SRD">, z.ZodLiteral<"SSP">, z.ZodLiteral<"STN">, z.ZodLiteral<"SVC">, z.ZodLiteral<"SYP">, z.ZodLiteral<"SZL">, z.ZodLiteral<"THB">, z.ZodLiteral<"TJS">, z.ZodLiteral<"TMT">, z.ZodLiteral<"TND">, z.ZodLiteral<"TOP">, z.ZodLiteral<"TRY">, z.ZodLiteral<"TTD">, z.ZodLiteral<"TWD">, z.ZodLiteral<"TZS">, z.ZodLiteral<"UAH">, z.ZodLiteral<"UGX">, z.ZodLiteral<"USD">, z.ZodLiteral<"USN">, z.ZodLiteral<"UYI">, z.ZodLiteral<"UYU">, z.ZodLiteral<"UYW">, z.ZodLiteral<"UZS">, z.ZodLiteral<"VES">, z.ZodLiteral<"VND">, z.ZodLiteral<"VUV">, z.ZodLiteral<"WST">, z.ZodLiteral<"XAF">, z.ZodLiteral<"XAG">, z.ZodLiteral<"XAU">, z.ZodLiteral<"XBA">, z.ZodLiteral<"XBB">, z.ZodLiteral<"XBC">, z.ZodLiteral<"XBD">, z.ZodLiteral<"XCD">, z.ZodLiteral<"XDR">, z.ZodLiteral<"XOF">, z.ZodLiteral<"XPD">, z.ZodLiteral<"XPF">, z.ZodLiteral<"XPT">, z.ZodLiteral<"XSU">, z.ZodLiteral<"XTS">, z.ZodLiteral<"XUA">, z.ZodLiteral<"XXX">, z.ZodLiteral<"YER">, z.ZodLiteral<"ZAR">, z.ZodLiteral<"ZMW">, z.ZodLiteral<"ZWL">]>>;
                    amount: z.ZodNumber;
                    precision: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                }, {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                }>;
                freeAfterTotal: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                    currency: z.ZodIntersection<z.ZodString, z.ZodUnion<[z.ZodLiteral<"AED">, z.ZodLiteral<"AFN">, z.ZodLiteral<"ALL">, z.ZodLiteral<"AMD">, z.ZodLiteral<"ANG">, z.ZodLiteral<"AOA">, z.ZodLiteral<"ARS">, z.ZodLiteral<"AUD">, z.ZodLiteral<"AWG">, z.ZodLiteral<"AZN">, z.ZodLiteral<"BAM">, z.ZodLiteral<"BBD">, z.ZodLiteral<"BDT">, z.ZodLiteral<"BGN">, z.ZodLiteral<"BHD">, z.ZodLiteral<"BIF">, z.ZodLiteral<"BMD">, z.ZodLiteral<"BND">, z.ZodLiteral<"BOB">, z.ZodLiteral<"BOV">, z.ZodLiteral<"BRL">, z.ZodLiteral<"BSD">, z.ZodLiteral<"BTN">, z.ZodLiteral<"BWP">, z.ZodLiteral<"BYN">, z.ZodLiteral<"BZD">, z.ZodLiteral<"CAD">, z.ZodLiteral<"CDF">, z.ZodLiteral<"CHE">, z.ZodLiteral<"CHF">, z.ZodLiteral<"CHW">, z.ZodLiteral<"CLF">, z.ZodLiteral<"CLP">, z.ZodLiteral<"CNY">, z.ZodLiteral<"COP">, z.ZodLiteral<"COU">, z.ZodLiteral<"CRC">, z.ZodLiteral<"CUC">, z.ZodLiteral<"CUP">, z.ZodLiteral<"CVE">, z.ZodLiteral<"CZK">, z.ZodLiteral<"DJF">, z.ZodLiteral<"DKK">, z.ZodLiteral<"DOP">, z.ZodLiteral<"DZD">, z.ZodLiteral<"EGP">, z.ZodLiteral<"ERN">, z.ZodLiteral<"ETB">, z.ZodLiteral<"EUR">, z.ZodLiteral<"FJD">, z.ZodLiteral<"FKP">, z.ZodLiteral<"GBP">, z.ZodLiteral<"GEL">, z.ZodLiteral<"GHS">, z.ZodLiteral<"GIP">, z.ZodLiteral<"GMD">, z.ZodLiteral<"GNF">, z.ZodLiteral<"GTQ">, z.ZodLiteral<"GYD">, z.ZodLiteral<"HKD">, z.ZodLiteral<"HNL">, z.ZodLiteral<"HRK">, z.ZodLiteral<"HTG">, z.ZodLiteral<"HUF">, z.ZodLiteral<"IDR">, z.ZodLiteral<"ILS">, z.ZodLiteral<"INR">, z.ZodLiteral<"IQD">, z.ZodLiteral<"IRR">, z.ZodLiteral<"ISK">, z.ZodLiteral<"JMD">, z.ZodLiteral<"JOD">, z.ZodLiteral<"JPY">, z.ZodLiteral<"KES">, z.ZodLiteral<"KGS">, z.ZodLiteral<"KHR">, z.ZodLiteral<"KMF">, z.ZodLiteral<"KPW">, z.ZodLiteral<"KRW">, z.ZodLiteral<"KWD">, z.ZodLiteral<"KYD">, z.ZodLiteral<"KZT">, z.ZodLiteral<"LAK">, z.ZodLiteral<"LBP">, z.ZodLiteral<"LKR">, z.ZodLiteral<"LRD">, z.ZodLiteral<"LSL">, z.ZodLiteral<"LYD">, z.ZodLiteral<"MAD">, z.ZodLiteral<"MDL">, z.ZodLiteral<"MGA">, z.ZodLiteral<"MKD">, z.ZodLiteral<"MMK">, z.ZodLiteral<"MNT">, z.ZodLiteral<"MOP">, z.ZodLiteral<"MRU">, z.ZodLiteral<"MUR">, z.ZodLiteral<"MVR">, z.ZodLiteral<"MWK">, z.ZodLiteral<"MXN">, z.ZodLiteral<"MXV">, z.ZodLiteral<"MYR">, z.ZodLiteral<"MZN">, z.ZodLiteral<"NAD">, z.ZodLiteral<"NGN">, z.ZodLiteral<"NIO">, z.ZodLiteral<"NOK">, z.ZodLiteral<"NPR">, z.ZodLiteral<"NZD">, z.ZodLiteral<"OMR">, z.ZodLiteral<"PAB">, z.ZodLiteral<"PEN">, z.ZodLiteral<"PGK">, z.ZodLiteral<"PHP">, z.ZodLiteral<"PKR">, z.ZodLiteral<"PLN">, z.ZodLiteral<"PYG">, z.ZodLiteral<"QAR">, z.ZodLiteral<"RON">, z.ZodLiteral<"RSD">, z.ZodLiteral<"RUB">, z.ZodLiteral<"RWF">, z.ZodLiteral<"SAR">, z.ZodLiteral<"SBD">, z.ZodLiteral<"SCR">, z.ZodLiteral<"SDG">, z.ZodLiteral<"SEK">, z.ZodLiteral<"SGD">, z.ZodLiteral<"SHP">, z.ZodLiteral<"SLL">, z.ZodLiteral<"SOS">, z.ZodLiteral<"SRD">, z.ZodLiteral<"SSP">, z.ZodLiteral<"STN">, z.ZodLiteral<"SVC">, z.ZodLiteral<"SYP">, z.ZodLiteral<"SZL">, z.ZodLiteral<"THB">, z.ZodLiteral<"TJS">, z.ZodLiteral<"TMT">, z.ZodLiteral<"TND">, z.ZodLiteral<"TOP">, z.ZodLiteral<"TRY">, z.ZodLiteral<"TTD">, z.ZodLiteral<"TWD">, z.ZodLiteral<"TZS">, z.ZodLiteral<"UAH">, z.ZodLiteral<"UGX">, z.ZodLiteral<"USD">, z.ZodLiteral<"USN">, z.ZodLiteral<"UYI">, z.ZodLiteral<"UYU">, z.ZodLiteral<"UYW">, z.ZodLiteral<"UZS">, z.ZodLiteral<"VES">, z.ZodLiteral<"VND">, z.ZodLiteral<"VUV">, z.ZodLiteral<"WST">, z.ZodLiteral<"XAF">, z.ZodLiteral<"XAG">, z.ZodLiteral<"XAU">, z.ZodLiteral<"XBA">, z.ZodLiteral<"XBB">, z.ZodLiteral<"XBC">, z.ZodLiteral<"XBD">, z.ZodLiteral<"XCD">, z.ZodLiteral<"XDR">, z.ZodLiteral<"XOF">, z.ZodLiteral<"XPD">, z.ZodLiteral<"XPF">, z.ZodLiteral<"XPT">, z.ZodLiteral<"XSU">, z.ZodLiteral<"XTS">, z.ZodLiteral<"XUA">, z.ZodLiteral<"XXX">, z.ZodLiteral<"YER">, z.ZodLiteral<"ZAR">, z.ZodLiteral<"ZMW">, z.ZodLiteral<"ZWL">]>>;
                    amount: z.ZodNumber;
                    precision: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                }, {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                }>>>;
                minPurchase: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                    currency: z.ZodIntersection<z.ZodString, z.ZodUnion<[z.ZodLiteral<"AED">, z.ZodLiteral<"AFN">, z.ZodLiteral<"ALL">, z.ZodLiteral<"AMD">, z.ZodLiteral<"ANG">, z.ZodLiteral<"AOA">, z.ZodLiteral<"ARS">, z.ZodLiteral<"AUD">, z.ZodLiteral<"AWG">, z.ZodLiteral<"AZN">, z.ZodLiteral<"BAM">, z.ZodLiteral<"BBD">, z.ZodLiteral<"BDT">, z.ZodLiteral<"BGN">, z.ZodLiteral<"BHD">, z.ZodLiteral<"BIF">, z.ZodLiteral<"BMD">, z.ZodLiteral<"BND">, z.ZodLiteral<"BOB">, z.ZodLiteral<"BOV">, z.ZodLiteral<"BRL">, z.ZodLiteral<"BSD">, z.ZodLiteral<"BTN">, z.ZodLiteral<"BWP">, z.ZodLiteral<"BYN">, z.ZodLiteral<"BZD">, z.ZodLiteral<"CAD">, z.ZodLiteral<"CDF">, z.ZodLiteral<"CHE">, z.ZodLiteral<"CHF">, z.ZodLiteral<"CHW">, z.ZodLiteral<"CLF">, z.ZodLiteral<"CLP">, z.ZodLiteral<"CNY">, z.ZodLiteral<"COP">, z.ZodLiteral<"COU">, z.ZodLiteral<"CRC">, z.ZodLiteral<"CUC">, z.ZodLiteral<"CUP">, z.ZodLiteral<"CVE">, z.ZodLiteral<"CZK">, z.ZodLiteral<"DJF">, z.ZodLiteral<"DKK">, z.ZodLiteral<"DOP">, z.ZodLiteral<"DZD">, z.ZodLiteral<"EGP">, z.ZodLiteral<"ERN">, z.ZodLiteral<"ETB">, z.ZodLiteral<"EUR">, z.ZodLiteral<"FJD">, z.ZodLiteral<"FKP">, z.ZodLiteral<"GBP">, z.ZodLiteral<"GEL">, z.ZodLiteral<"GHS">, z.ZodLiteral<"GIP">, z.ZodLiteral<"GMD">, z.ZodLiteral<"GNF">, z.ZodLiteral<"GTQ">, z.ZodLiteral<"GYD">, z.ZodLiteral<"HKD">, z.ZodLiteral<"HNL">, z.ZodLiteral<"HRK">, z.ZodLiteral<"HTG">, z.ZodLiteral<"HUF">, z.ZodLiteral<"IDR">, z.ZodLiteral<"ILS">, z.ZodLiteral<"INR">, z.ZodLiteral<"IQD">, z.ZodLiteral<"IRR">, z.ZodLiteral<"ISK">, z.ZodLiteral<"JMD">, z.ZodLiteral<"JOD">, z.ZodLiteral<"JPY">, z.ZodLiteral<"KES">, z.ZodLiteral<"KGS">, z.ZodLiteral<"KHR">, z.ZodLiteral<"KMF">, z.ZodLiteral<"KPW">, z.ZodLiteral<"KRW">, z.ZodLiteral<"KWD">, z.ZodLiteral<"KYD">, z.ZodLiteral<"KZT">, z.ZodLiteral<"LAK">, z.ZodLiteral<"LBP">, z.ZodLiteral<"LKR">, z.ZodLiteral<"LRD">, z.ZodLiteral<"LSL">, z.ZodLiteral<"LYD">, z.ZodLiteral<"MAD">, z.ZodLiteral<"MDL">, z.ZodLiteral<"MGA">, z.ZodLiteral<"MKD">, z.ZodLiteral<"MMK">, z.ZodLiteral<"MNT">, z.ZodLiteral<"MOP">, z.ZodLiteral<"MRU">, z.ZodLiteral<"MUR">, z.ZodLiteral<"MVR">, z.ZodLiteral<"MWK">, z.ZodLiteral<"MXN">, z.ZodLiteral<"MXV">, z.ZodLiteral<"MYR">, z.ZodLiteral<"MZN">, z.ZodLiteral<"NAD">, z.ZodLiteral<"NGN">, z.ZodLiteral<"NIO">, z.ZodLiteral<"NOK">, z.ZodLiteral<"NPR">, z.ZodLiteral<"NZD">, z.ZodLiteral<"OMR">, z.ZodLiteral<"PAB">, z.ZodLiteral<"PEN">, z.ZodLiteral<"PGK">, z.ZodLiteral<"PHP">, z.ZodLiteral<"PKR">, z.ZodLiteral<"PLN">, z.ZodLiteral<"PYG">, z.ZodLiteral<"QAR">, z.ZodLiteral<"RON">, z.ZodLiteral<"RSD">, z.ZodLiteral<"RUB">, z.ZodLiteral<"RWF">, z.ZodLiteral<"SAR">, z.ZodLiteral<"SBD">, z.ZodLiteral<"SCR">, z.ZodLiteral<"SDG">, z.ZodLiteral<"SEK">, z.ZodLiteral<"SGD">, z.ZodLiteral<"SHP">, z.ZodLiteral<"SLL">, z.ZodLiteral<"SOS">, z.ZodLiteral<"SRD">, z.ZodLiteral<"SSP">, z.ZodLiteral<"STN">, z.ZodLiteral<"SVC">, z.ZodLiteral<"SYP">, z.ZodLiteral<"SZL">, z.ZodLiteral<"THB">, z.ZodLiteral<"TJS">, z.ZodLiteral<"TMT">, z.ZodLiteral<"TND">, z.ZodLiteral<"TOP">, z.ZodLiteral<"TRY">, z.ZodLiteral<"TTD">, z.ZodLiteral<"TWD">, z.ZodLiteral<"TZS">, z.ZodLiteral<"UAH">, z.ZodLiteral<"UGX">, z.ZodLiteral<"USD">, z.ZodLiteral<"USN">, z.ZodLiteral<"UYI">, z.ZodLiteral<"UYU">, z.ZodLiteral<"UYW">, z.ZodLiteral<"UZS">, z.ZodLiteral<"VES">, z.ZodLiteral<"VND">, z.ZodLiteral<"VUV">, z.ZodLiteral<"WST">, z.ZodLiteral<"XAF">, z.ZodLiteral<"XAG">, z.ZodLiteral<"XAU">, z.ZodLiteral<"XBA">, z.ZodLiteral<"XBB">, z.ZodLiteral<"XBC">, z.ZodLiteral<"XBD">, z.ZodLiteral<"XCD">, z.ZodLiteral<"XDR">, z.ZodLiteral<"XOF">, z.ZodLiteral<"XPD">, z.ZodLiteral<"XPF">, z.ZodLiteral<"XPT">, z.ZodLiteral<"XSU">, z.ZodLiteral<"XTS">, z.ZodLiteral<"XUA">, z.ZodLiteral<"XXX">, z.ZodLiteral<"YER">, z.ZodLiteral<"ZAR">, z.ZodLiteral<"ZMW">, z.ZodLiteral<"ZWL">]>>;
                    amount: z.ZodNumber;
                    precision: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                }, {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                minPurchase?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                freeAfterTotal?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                polygon: number[][];
                deliveryFee: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                };
            }, {
                minPurchase?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                freeAfterTotal?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                polygon: number[][];
                deliveryFee: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                };
            }>, "many">;
            term: z.ZodString;
            deliveryTime: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                day: z.ZodObject<{
                    min: z.ZodNumber;
                    max: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    max: number;
                    min: number;
                }, {
                    max: number;
                    min: number;
                }>;
                time: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
                custom: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                    0: z.ZodObject<{
                        enable: z.ZodBoolean;
                        hours: z.ZodArray<z.ZodObject<{
                            start: z.ZodString;
                            end: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            end: string;
                            start: string;
                        }, {
                            end: string;
                            start: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }>;
                    1: z.ZodObject<{
                        enable: z.ZodBoolean;
                        hours: z.ZodArray<z.ZodObject<{
                            start: z.ZodString;
                            end: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            end: string;
                            start: string;
                        }, {
                            end: string;
                            start: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }>;
                    2: z.ZodObject<{
                        enable: z.ZodBoolean;
                        hours: z.ZodArray<z.ZodObject<{
                            start: z.ZodString;
                            end: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            end: string;
                            start: string;
                        }, {
                            end: string;
                            start: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }>;
                    3: z.ZodObject<{
                        enable: z.ZodBoolean;
                        hours: z.ZodArray<z.ZodObject<{
                            start: z.ZodString;
                            end: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            end: string;
                            start: string;
                        }, {
                            end: string;
                            start: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }>;
                    4: z.ZodObject<{
                        enable: z.ZodBoolean;
                        hours: z.ZodArray<z.ZodObject<{
                            start: z.ZodString;
                            end: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            end: string;
                            start: string;
                        }, {
                            end: string;
                            start: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }>;
                    5: z.ZodObject<{
                        enable: z.ZodBoolean;
                        hours: z.ZodArray<z.ZodObject<{
                            start: z.ZodString;
                            end: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            end: string;
                            start: string;
                        }, {
                            end: string;
                            start: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }>;
                    6: z.ZodObject<{
                        enable: z.ZodBoolean;
                        hours: z.ZodArray<z.ZodObject<{
                            start: z.ZodString;
                            end: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            end: string;
                            start: string;
                        }, {
                            end: string;
                            start: string;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }, {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    }>;
                }, "strip", z.ZodTypeAny, {
                    0: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    2: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    1: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    3: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    4: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    5: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    6: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                }, {
                    0: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    2: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    1: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    3: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    4: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    5: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    6: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                }>>>;
            }, "strip", z.ZodTypeAny, {
                time?: string[] | null | undefined;
                custom?: {
                    0: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    2: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    1: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    3: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    4: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    5: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    6: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                } | null | undefined;
                day: {
                    max: number;
                    min: number;
                };
            }, {
                time?: string[] | null | undefined;
                custom?: {
                    0: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    2: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    1: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    3: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    4: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    5: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    6: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                } | null | undefined;
                day: {
                    max: number;
                    min: number;
                };
            }>>>;
            catalogId: z.ZodNullable<z.ZodString>;
            paymentTypes: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodEnum<["cash", "ePayment", "credit", "ePaymentSandbox"]>, "many">>>;
            offlinePaymentTypes: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                name: z.ZodString;
                instruction: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                name: string;
                instruction: string;
            }, {
                name: string;
                instruction: string;
            }>, "many">>>;
            autoAccept: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            autoAcceptPaidOnly: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            ignoreStock: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            taxes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                systemCode: z.ZodString;
                taxCode: z.ZodString;
                inclusive: z.ZodBoolean;
            }, "strip", z.ZodTypeAny, {
                inclusive: boolean;
                taxCode: string;
                systemCode: string;
            }, {
                inclusive: boolean;
                taxCode: string;
                systemCode: string;
            }>>>>;
        }, "strip", z.ZodTypeAny, {
            taxes?: Record<string, {
                inclusive: boolean;
                taxCode: string;
                systemCode: string;
            }> | null | undefined;
            autoAccept?: boolean | null | undefined;
            deliveryTime?: {
                time?: string[] | null | undefined;
                custom?: {
                    0: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    2: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    1: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    3: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    4: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    5: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    6: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                } | null | undefined;
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            catalogId: string | null;
            enable: boolean;
            areas: {
                minPurchase?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                freeAfterTotal?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                polygon: number[][];
                deliveryFee: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                };
            }[];
            term: string;
        }, {
            taxes?: Record<string, {
                inclusive: boolean;
                taxCode: string;
                systemCode: string;
            }> | null | undefined;
            autoAccept?: boolean | null | undefined;
            deliveryTime?: {
                time?: string[] | null | undefined;
                custom?: {
                    0: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    2: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    1: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    3: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    4: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    5: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    6: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                } | null | undefined;
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            catalogId: string | null;
            enable: boolean;
            areas: {
                minPurchase?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                freeAfterTotal?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                polygon: number[][];
                deliveryFee: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                };
            }[];
            term: string;
        }>>>;
        feedmeDelivery: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            enable: z.ZodBoolean;
            catalogId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            term: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            instruction: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            autoAccept: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            ignoreStock: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            instruction?: string | null | undefined;
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            term?: string | null | undefined;
            ignoreStock?: boolean | null | undefined;
            enable: boolean;
        }, {
            instruction?: string | null | undefined;
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            term?: string | null | undefined;
            ignoreStock?: boolean | null | undefined;
            enable: boolean;
        }>>>;
        foodpandaDelivery: z.ZodNullable<z.ZodOptional<z.ZodObject<z.extendShape<{
            enable: z.ZodBoolean;
        }, {
            _id: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            remoteId: z.ZodString;
            catalogId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            lastSynchronize: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            commissionRate: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            autoCloseBill: z.ZodBoolean;
            showProductAddon: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            autoAccept: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            reportConfig: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                commissionRate: z.ZodNumber;
                discountCampaigns: z.ZodArray<z.ZodObject<{
                    name: z.ZodString;
                    vendorBearPercentage: z.ZodNumber;
                    date: z.ZodObject<{
                        start: z.ZodString;
                        end: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        end: string;
                        start: string;
                    }, {
                        end: string;
                        start: string;
                    }>;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }, {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            }, {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            }>>>;
            hasSst: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            ignoreDiscount: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        }>, "strip", z.ZodTypeAny, {
            _id?: string | undefined;
            ignoreDiscount?: boolean | null | undefined;
            catalogId?: string | null | undefined;
            commissionRate?: number | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            autoAccept?: boolean | null | undefined;
            reportConfig?: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            } | null | undefined;
            hasSst?: boolean | null | undefined;
            enable: boolean;
            remoteId: string;
            autoCloseBill: boolean;
        }, {
            _id?: string | undefined;
            ignoreDiscount?: boolean | null | undefined;
            catalogId?: string | null | undefined;
            commissionRate?: number | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            autoAccept?: boolean | null | undefined;
            reportConfig?: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            } | null | undefined;
            hasSst?: boolean | null | undefined;
            enable: boolean;
            remoteId: string;
            autoCloseBill: boolean;
        }>>>;
        grabfoodDelivery: z.ZodNullable<z.ZodOptional<z.ZodObject<z.extendShape<{
            enable: z.ZodBoolean;
        }, {
            _id: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            merchantID: z.ZodString;
            catalogId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            lastSynchronize: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            commissionRate: z.ZodNumber;
            autoCloseBill: z.ZodBoolean;
            showProductAddon: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        }>, "strip", z.ZodTypeAny, {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            commissionRate: number;
            autoCloseBill: boolean;
            merchantID: string;
        }, {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            commissionRate: number;
            autoCloseBill: boolean;
            merchantID: string;
        }>>>;
        shopeefoodDelivery: z.ZodNullable<z.ZodOptional<z.ZodObject<z.extendShape<{
            enable: z.ZodBoolean;
        }, {
            _id: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            storeID: z.ZodString;
            catalogId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            lastSynchronize: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            autoCloseBill: z.ZodBoolean;
            reportConfig: z.ZodObject<{
                commissionRate: z.ZodNumber;
                discountCampaigns: z.ZodArray<z.ZodObject<{
                    name: z.ZodString;
                    vendorBearPercentage: z.ZodNumber;
                    date: z.ZodObject<{
                        start: z.ZodString;
                        end: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        end: string;
                        start: string;
                    }, {
                        end: string;
                        start: string;
                    }>;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }, {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            }, {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            }>;
            showProductAddon: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        }>, "strip", z.ZodTypeAny, {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            autoCloseBill: boolean;
            reportConfig: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            };
            storeID: string;
        }, {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            autoCloseBill: boolean;
            reportConfig: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            };
            storeID: string;
        }>>>;
        pickup: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            pickupTime: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                day: z.ZodObject<{
                    min: z.ZodNumber;
                    max: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    max: number;
                    min: number;
                }, {
                    max: number;
                    min: number;
                }>;
            }, "strip", z.ZodTypeAny, {
                day: {
                    max: number;
                    min: number;
                };
            }, {
                day: {
                    max: number;
                    min: number;
                };
            }>>>;
            pickupPointConfig: z.ZodNullable<z.ZodOptional<z.ZodObject<{
                restaurantEnable: z.ZodBoolean;
                points: z.ZodArray<z.ZodObject<{
                    name: z.ZodString;
                    address: z.ZodString;
                    coordinates: z.ZodArray<z.ZodNumber, "many">;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    address: string;
                    coordinates: number[];
                }, {
                    name: string;
                    address: string;
                    coordinates: number[];
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                restaurantEnable: boolean;
                points: {
                    name: string;
                    address: string;
                    coordinates: number[];
                }[];
            }, {
                restaurantEnable: boolean;
                points: {
                    name: string;
                    address: string;
                    coordinates: number[];
                }[];
            }>>>;
            paymentTypes: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodEnum<["cash", "ePayment", "credit", "ePaymentSandbox"]>, "many">>>;
            offlinePaymentTypes: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                name: z.ZodString;
                instruction: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                name: string;
                instruction: string;
            }, {
                name: string;
                instruction: string;
            }>, "many">>>;
            catalogId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            autoAccept: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            autoAcceptPaidOnly: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            ignoreStock: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            pickupTime?: {
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            pickupPointConfig?: {
                restaurantEnable: boolean;
                points: {
                    name: string;
                    address: string;
                    coordinates: number[];
                }[];
            } | null | undefined;
        }, {
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            pickupTime?: {
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            pickupPointConfig?: {
                restaurantEnable: boolean;
                points: {
                    name: string;
                    address: string;
                    coordinates: number[];
                }[];
            } | null | undefined;
        }>>>;
        dineIn: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            anonymousOrder: z.ZodBoolean;
            staticQr: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            paymentTypes: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodEnum<["cash", "ePayment", "credit", "ePaymentSandbox"]>, "many">>>;
            offlinePaymentTypes: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                name: z.ZodString;
                instruction: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                name: string;
                instruction: string;
            }, {
                name: string;
                instruction: string;
            }>, "many">>>;
            ignoreStock: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            disableItemRemark: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            acceptQueue: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            ignoreStock?: boolean | null | undefined;
            staticQr?: boolean | null | undefined;
            disableItemRemark?: boolean | null | undefined;
            acceptQueue?: boolean | null | undefined;
            anonymousOrder: boolean;
        }, {
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            ignoreStock?: boolean | null | undefined;
            staticQr?: boolean | null | undefined;
            disableItemRemark?: boolean | null | undefined;
            acceptQueue?: boolean | null | undefined;
            anonymousOrder: boolean;
        }>>>;
        takeaway: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            catalogId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            catalogId?: string | null | undefined;
        }, {
            catalogId?: string | null | undefined;
        }>>>;
        couchDbPassword: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        apiToken: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        remoteSupports: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
            deviceName: z.ZodString;
            anydeskId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            anydeskPassword: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            anydeskId?: string | null | undefined;
            anydeskPassword?: string | null | undefined;
            deviceName: string;
        }, {
            anydeskId?: string | null | undefined;
            anydeskPassword?: string | null | undefined;
            deviceName: string;
        }>, "many">>>;
        payoutAccount: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
        clearCount: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        queueSetting: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            enableOrder: z.ZodBoolean;
            initialNumber: z.ZodNumber;
            endNumber: z.ZodNumber;
            currentNumber: z.ZodNumber;
            autoCalledLimit: z.ZodNumber;
            duration: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            duration?: number | null | undefined;
            enableOrder: boolean;
            initialNumber: number;
            endNumber: number;
            currentNumber: number;
            autoCalledLimit: number;
        }, {
            duration?: number | null | undefined;
            enableOrder: boolean;
            initialNumber: number;
            endNumber: number;
            currentNumber: number;
            autoCalledLimit: number;
        }>>>;
        tableMappingSetting: z.ZodNullable<z.ZodOptional<z.ZodObject<{
            enable: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            showSeat: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            mapBorderColor: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
            mapLineColor: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            enable?: boolean | null | undefined;
            showSeat?: boolean | null | undefined;
            mapBorderColor?: number | null | undefined;
            mapLineColor?: number | null | undefined;
        }, {
            enable?: boolean | null | undefined;
            showSeat?: boolean | null | undefined;
            mapBorderColor?: number | null | undefined;
            mapLineColor?: number | null | undefined;
        }>>>;
        customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    }, "strip", z.ZodTypeAny, {
        pickup?: {
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            pickupTime?: {
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            pickupPointConfig?: {
                restaurantEnable: boolean;
                points: {
                    name: string;
                    address: string;
                    coordinates: number[];
                }[];
            } | null | undefined;
        } | null | undefined;
        channel?: string | null | undefined;
        machineId?: string | null | undefined;
        catalogId?: string | null | undefined;
        customAttributes?: Record<string, any> | null | undefined;
        takeaway?: {
            catalogId?: string | null | undefined;
        } | null | undefined;
        inHouseDelivery?: {
            taxes?: Record<string, {
                inclusive: boolean;
                taxCode: string;
                systemCode: string;
            }> | null | undefined;
            autoAccept?: boolean | null | undefined;
            deliveryTime?: {
                time?: string[] | null | undefined;
                custom?: {
                    0: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    2: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    1: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    3: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    4: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    5: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    6: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                } | null | undefined;
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            catalogId: string | null;
            enable: boolean;
            areas: {
                minPurchase?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                freeAfterTotal?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                polygon: number[][];
                deliveryFee: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                };
            }[];
            term: string;
        } | null | undefined;
        dineIn?: {
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            ignoreStock?: boolean | null | undefined;
            staticQr?: boolean | null | undefined;
            disableItemRemark?: boolean | null | undefined;
            acceptQueue?: boolean | null | undefined;
            anonymousOrder: boolean;
        } | null | undefined;
        pf_business?: {
            internal?: boolean | null | undefined;
            url?: string | null | undefined;
            expiredAt?: string | null | undefined;
            agentId?: string | null | undefined;
            attributeSettings?: {
                options?: any[] | null | undefined;
                type: "string" | "number" | "boolean" | "date";
                key: string;
                entity: "restaurant" | "item" | "group" | "inventorySku" | "inventoryRecipe" | "warehouse";
            }[] | null | undefined;
            pf_agent?: {
                clickupId?: string | null | undefined;
                members?: {
                    pf_user?: {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    } | null | undefined;
                    role: "ADMIN";
                    userId: string;
                }[] | null | undefined;
                code: string;
                name: string;
                _id: string;
                isReseller: boolean;
            } | null | undefined;
            thumbnail?: string | null | undefined;
            billingInfos?: {
                _id?: string | null | undefined;
                name: string;
                address: {
                    coordinates?: number[] | null | undefined;
                    line2?: string | null | undefined;
                    state: string;
                    country: string;
                    line1: string;
                    city: string;
                    postcode: string;
                };
                email: string;
                companyName: string;
                contact: string;
            }[] | null | undefined;
            customerDisplayImages?: {
                url: string;
                restaurantIds: string[];
            }[] | null | undefined;
            name: string;
            _id: string;
            ownerId: string;
            restaurantQuota: number;
            warehouseQuota: number;
            menuVersion: string;
        } | null | undefined;
        features?: string[] | null | undefined;
        machineOtp?: string | null | undefined;
        machineOtpExpiredAt?: string | null | undefined;
        posVersion?: string | null | undefined;
        posHeartbeat?: string | null | undefined;
        posVersionHistory?: Record<string, string> | null | undefined;
        additionalCatalogs?: string[] | null | undefined;
        feedmeDelivery?: {
            instruction?: string | null | undefined;
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            term?: string | null | undefined;
            ignoreStock?: boolean | null | undefined;
            enable: boolean;
        } | null | undefined;
        foodpandaDelivery?: {
            _id?: string | undefined;
            ignoreDiscount?: boolean | null | undefined;
            catalogId?: string | null | undefined;
            commissionRate?: number | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            autoAccept?: boolean | null | undefined;
            reportConfig?: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            } | null | undefined;
            hasSst?: boolean | null | undefined;
            enable: boolean;
            remoteId: string;
            autoCloseBill: boolean;
        } | null | undefined;
        grabfoodDelivery?: {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            commissionRate: number;
            autoCloseBill: boolean;
            merchantID: string;
        } | null | undefined;
        shopeefoodDelivery?: {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            autoCloseBill: boolean;
            reportConfig: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            };
            storeID: string;
        } | null | undefined;
        couchDbPassword?: string | null | undefined;
        apiToken?: string | null | undefined;
        remoteSupports?: {
            anydeskId?: string | null | undefined;
            anydeskPassword?: string | null | undefined;
            deviceName: string;
        }[] | null | undefined;
        payoutAccount?: Record<string, any> | null | undefined;
        clearCount?: number | null | undefined;
        queueSetting?: {
            duration?: number | null | undefined;
            enableOrder: boolean;
            initialNumber: number;
            endNumber: number;
            currentNumber: number;
            autoCalledLimit: number;
        } | null | undefined;
        tableMappingSetting?: {
            enable?: boolean | null | undefined;
            showSeat?: boolean | null | undefined;
            mapBorderColor?: number | null | undefined;
            mapLineColor?: number | null | undefined;
        } | null | undefined;
        _id: string;
        expiredAt: string;
        businessId: string;
        profile: {
            code?: string | null | undefined;
            url?: string | null | undefined;
            description?: string | null | undefined;
            _id?: string | null | undefined;
            legalName?: string | null | undefined;
            sstRegNo?: string | null | undefined;
            discovery?: boolean | null | undefined;
            coverPhoto?: string | null | undefined;
            thumbnailPhoto?: string | null | undefined;
            photos?: string[] | null | undefined;
            operatingHours?: {
                0: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                2: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                1: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                3: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                4: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                5: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                6: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
            } | null | undefined;
            tags?: string[] | null | undefined;
            name: string;
            address: {
                coordinates?: number[] | null | undefined;
                line2?: string | null | undefined;
                state: string;
                country: string;
                line1: string;
                city: string;
                postcode: string;
            };
            email: string;
            phoneNo: string;
            regNo: string;
        };
    }, {
        pickup?: {
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            pickupTime?: {
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            pickupPointConfig?: {
                restaurantEnable: boolean;
                points: {
                    name: string;
                    address: string;
                    coordinates: number[];
                }[];
            } | null | undefined;
        } | null | undefined;
        channel?: string | null | undefined;
        machineId?: string | null | undefined;
        catalogId?: string | null | undefined;
        customAttributes?: Record<string, any> | null | undefined;
        takeaway?: {
            catalogId?: string | null | undefined;
        } | null | undefined;
        inHouseDelivery?: {
            taxes?: Record<string, {
                inclusive: boolean;
                taxCode: string;
                systemCode: string;
            }> | null | undefined;
            autoAccept?: boolean | null | undefined;
            deliveryTime?: {
                time?: string[] | null | undefined;
                custom?: {
                    0: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    2: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    1: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    3: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    4: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    5: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    6: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                } | null | undefined;
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            catalogId: string | null;
            enable: boolean;
            areas: {
                minPurchase?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                freeAfterTotal?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                polygon: number[][];
                deliveryFee: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                };
            }[];
            term: string;
        } | null | undefined;
        dineIn?: {
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            ignoreStock?: boolean | null | undefined;
            staticQr?: boolean | null | undefined;
            disableItemRemark?: boolean | null | undefined;
            acceptQueue?: boolean | null | undefined;
            anonymousOrder: boolean;
        } | null | undefined;
        pf_business?: {
            internal?: boolean | null | undefined;
            url?: string | null | undefined;
            expiredAt?: string | null | undefined;
            agentId?: string | null | undefined;
            attributeSettings?: {
                options?: any[] | null | undefined;
                type: "string" | "number" | "boolean" | "date";
                key: string;
                entity: "restaurant" | "item" | "group" | "inventorySku" | "inventoryRecipe" | "warehouse";
            }[] | null | undefined;
            pf_agent?: {
                clickupId?: string | null | undefined;
                members?: {
                    pf_user?: {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    } | null | undefined;
                    role: "ADMIN";
                    userId: string;
                }[] | null | undefined;
                code: string;
                name: string;
                _id: string;
                isReseller: boolean;
            } | null | undefined;
            thumbnail?: string | null | undefined;
            billingInfos?: {
                _id?: string | null | undefined;
                name: string;
                address: {
                    coordinates?: number[] | null | undefined;
                    line2?: string | null | undefined;
                    state: string;
                    country: string;
                    line1: string;
                    city: string;
                    postcode: string;
                };
                email: string;
                companyName: string;
                contact: string;
            }[] | null | undefined;
            customerDisplayImages?: {
                url: string;
                restaurantIds: string[];
            }[] | null | undefined;
            name: string;
            _id: string;
            ownerId: string;
            restaurantQuota: number;
            warehouseQuota: number;
            menuVersion: string;
        } | null | undefined;
        features?: string[] | null | undefined;
        machineOtp?: string | null | undefined;
        machineOtpExpiredAt?: string | null | undefined;
        posVersion?: string | null | undefined;
        posHeartbeat?: string | null | undefined;
        posVersionHistory?: Record<string, string> | null | undefined;
        additionalCatalogs?: string[] | null | undefined;
        feedmeDelivery?: {
            instruction?: string | null | undefined;
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            term?: string | null | undefined;
            ignoreStock?: boolean | null | undefined;
            enable: boolean;
        } | null | undefined;
        foodpandaDelivery?: {
            _id?: string | undefined;
            ignoreDiscount?: boolean | null | undefined;
            catalogId?: string | null | undefined;
            commissionRate?: number | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            autoAccept?: boolean | null | undefined;
            reportConfig?: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            } | null | undefined;
            hasSst?: boolean | null | undefined;
            enable: boolean;
            remoteId: string;
            autoCloseBill: boolean;
        } | null | undefined;
        grabfoodDelivery?: {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            commissionRate: number;
            autoCloseBill: boolean;
            merchantID: string;
        } | null | undefined;
        shopeefoodDelivery?: {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            autoCloseBill: boolean;
            reportConfig: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            };
            storeID: string;
        } | null | undefined;
        couchDbPassword?: string | null | undefined;
        apiToken?: string | null | undefined;
        remoteSupports?: {
            anydeskId?: string | null | undefined;
            anydeskPassword?: string | null | undefined;
            deviceName: string;
        }[] | null | undefined;
        payoutAccount?: Record<string, any> | null | undefined;
        clearCount?: number | null | undefined;
        queueSetting?: {
            duration?: number | null | undefined;
            enableOrder: boolean;
            initialNumber: number;
            endNumber: number;
            currentNumber: number;
            autoCalledLimit: number;
        } | null | undefined;
        tableMappingSetting?: {
            enable?: boolean | null | undefined;
            showSeat?: boolean | null | undefined;
            mapBorderColor?: number | null | undefined;
            mapLineColor?: number | null | undefined;
        } | null | undefined;
        _id: string;
        expiredAt: string;
        businessId: string;
        profile: {
            code?: string | null | undefined;
            url?: string | null | undefined;
            description?: string | null | undefined;
            _id?: string | null | undefined;
            legalName?: string | null | undefined;
            sstRegNo?: string | null | undefined;
            discovery?: boolean | null | undefined;
            coverPhoto?: string | null | undefined;
            thumbnailPhoto?: string | null | undefined;
            photos?: string[] | null | undefined;
            operatingHours?: {
                0: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                2: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                1: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                3: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                4: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                5: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                6: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
            } | null | undefined;
            tags?: string[] | null | undefined;
            name: string;
            address: {
                coordinates?: number[] | null | undefined;
                line2?: string | null | undefined;
                state: string;
                country: string;
                line1: string;
                city: string;
                postcode: string;
            };
            email: string;
            phoneNo: string;
            regNo: string;
        };
    }>>>;
}>, "strip", z.ZodTypeAny, {
    pf_restaurant?: {
        pickup?: {
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            pickupTime?: {
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            pickupPointConfig?: {
                restaurantEnable: boolean;
                points: {
                    name: string;
                    address: string;
                    coordinates: number[];
                }[];
            } | null | undefined;
        } | null | undefined;
        channel?: string | null | undefined;
        machineId?: string | null | undefined;
        catalogId?: string | null | undefined;
        customAttributes?: Record<string, any> | null | undefined;
        takeaway?: {
            catalogId?: string | null | undefined;
        } | null | undefined;
        inHouseDelivery?: {
            taxes?: Record<string, {
                inclusive: boolean;
                taxCode: string;
                systemCode: string;
            }> | null | undefined;
            autoAccept?: boolean | null | undefined;
            deliveryTime?: {
                time?: string[] | null | undefined;
                custom?: {
                    0: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    2: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    1: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    3: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    4: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    5: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    6: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                } | null | undefined;
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            catalogId: string | null;
            enable: boolean;
            areas: {
                minPurchase?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                freeAfterTotal?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                polygon: number[][];
                deliveryFee: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                };
            }[];
            term: string;
        } | null | undefined;
        dineIn?: {
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            ignoreStock?: boolean | null | undefined;
            staticQr?: boolean | null | undefined;
            disableItemRemark?: boolean | null | undefined;
            acceptQueue?: boolean | null | undefined;
            anonymousOrder: boolean;
        } | null | undefined;
        pf_business?: {
            internal?: boolean | null | undefined;
            url?: string | null | undefined;
            expiredAt?: string | null | undefined;
            agentId?: string | null | undefined;
            attributeSettings?: {
                options?: any[] | null | undefined;
                type: "string" | "number" | "boolean" | "date";
                key: string;
                entity: "restaurant" | "item" | "group" | "inventorySku" | "inventoryRecipe" | "warehouse";
            }[] | null | undefined;
            pf_agent?: {
                clickupId?: string | null | undefined;
                members?: {
                    pf_user?: {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    } | null | undefined;
                    role: "ADMIN";
                    userId: string;
                }[] | null | undefined;
                code: string;
                name: string;
                _id: string;
                isReseller: boolean;
            } | null | undefined;
            thumbnail?: string | null | undefined;
            billingInfos?: {
                _id?: string | null | undefined;
                name: string;
                address: {
                    coordinates?: number[] | null | undefined;
                    line2?: string | null | undefined;
                    state: string;
                    country: string;
                    line1: string;
                    city: string;
                    postcode: string;
                };
                email: string;
                companyName: string;
                contact: string;
            }[] | null | undefined;
            customerDisplayImages?: {
                url: string;
                restaurantIds: string[];
            }[] | null | undefined;
            name: string;
            _id: string;
            ownerId: string;
            restaurantQuota: number;
            warehouseQuota: number;
            menuVersion: string;
        } | null | undefined;
        features?: string[] | null | undefined;
        machineOtp?: string | null | undefined;
        machineOtpExpiredAt?: string | null | undefined;
        posVersion?: string | null | undefined;
        posHeartbeat?: string | null | undefined;
        posVersionHistory?: Record<string, string> | null | undefined;
        additionalCatalogs?: string[] | null | undefined;
        feedmeDelivery?: {
            instruction?: string | null | undefined;
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            term?: string | null | undefined;
            ignoreStock?: boolean | null | undefined;
            enable: boolean;
        } | null | undefined;
        foodpandaDelivery?: {
            _id?: string | undefined;
            ignoreDiscount?: boolean | null | undefined;
            catalogId?: string | null | undefined;
            commissionRate?: number | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            autoAccept?: boolean | null | undefined;
            reportConfig?: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            } | null | undefined;
            hasSst?: boolean | null | undefined;
            enable: boolean;
            remoteId: string;
            autoCloseBill: boolean;
        } | null | undefined;
        grabfoodDelivery?: {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            commissionRate: number;
            autoCloseBill: boolean;
            merchantID: string;
        } | null | undefined;
        shopeefoodDelivery?: {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            autoCloseBill: boolean;
            reportConfig: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            };
            storeID: string;
        } | null | undefined;
        couchDbPassword?: string | null | undefined;
        apiToken?: string | null | undefined;
        remoteSupports?: {
            anydeskId?: string | null | undefined;
            anydeskPassword?: string | null | undefined;
            deviceName: string;
        }[] | null | undefined;
        payoutAccount?: Record<string, any> | null | undefined;
        clearCount?: number | null | undefined;
        queueSetting?: {
            duration?: number | null | undefined;
            enableOrder: boolean;
            initialNumber: number;
            endNumber: number;
            currentNumber: number;
            autoCalledLimit: number;
        } | null | undefined;
        tableMappingSetting?: {
            enable?: boolean | null | undefined;
            showSeat?: boolean | null | undefined;
            mapBorderColor?: number | null | undefined;
            mapLineColor?: number | null | undefined;
        } | null | undefined;
        _id: string;
        expiredAt: string;
        businessId: string;
        profile: {
            code?: string | null | undefined;
            url?: string | null | undefined;
            description?: string | null | undefined;
            _id?: string | null | undefined;
            legalName?: string | null | undefined;
            sstRegNo?: string | null | undefined;
            discovery?: boolean | null | undefined;
            coverPhoto?: string | null | undefined;
            thumbnailPhoto?: string | null | undefined;
            photos?: string[] | null | undefined;
            operatingHours?: {
                0: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                2: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                1: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                3: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                4: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                5: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                6: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
            } | null | undefined;
            tags?: string[] | null | undefined;
            name: string;
            address: {
                coordinates?: number[] | null | undefined;
                line2?: string | null | undefined;
                state: string;
                country: string;
                line1: string;
                city: string;
                postcode: string;
            };
            email: string;
            phoneNo: string;
            regNo: string;
        };
    } | null | undefined;
    _id: string;
    orderStatus: {
        message: string;
        status: "pending" | "accepted" | "rejected";
    };
    raw: {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    };
}, {
    pf_restaurant?: {
        pickup?: {
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            pickupTime?: {
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            pickupPointConfig?: {
                restaurantEnable: boolean;
                points: {
                    name: string;
                    address: string;
                    coordinates: number[];
                }[];
            } | null | undefined;
        } | null | undefined;
        channel?: string | null | undefined;
        machineId?: string | null | undefined;
        catalogId?: string | null | undefined;
        customAttributes?: Record<string, any> | null | undefined;
        takeaway?: {
            catalogId?: string | null | undefined;
        } | null | undefined;
        inHouseDelivery?: {
            taxes?: Record<string, {
                inclusive: boolean;
                taxCode: string;
                systemCode: string;
            }> | null | undefined;
            autoAccept?: boolean | null | undefined;
            deliveryTime?: {
                time?: string[] | null | undefined;
                custom?: {
                    0: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    2: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    1: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    3: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    4: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    5: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                    6: {
                        hours: {
                            end: string;
                            start: string;
                        }[];
                        enable: boolean;
                    };
                } | null | undefined;
                day: {
                    max: number;
                    min: number;
                };
            } | null | undefined;
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            autoAcceptPaidOnly?: boolean | null | undefined;
            ignoreStock?: boolean | null | undefined;
            catalogId: string | null;
            enable: boolean;
            areas: {
                minPurchase?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                freeAfterTotal?: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                } | null | undefined;
                polygon: number[][];
                deliveryFee: {
                    currency: "ALL" | "MYR" | "AED" | "AFN" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BIF" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CLP" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DJF" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "EUR" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GNF" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "HUF" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "JPY" | "KES" | "KGS" | "KHR" | "KMF" | "KPW" | "KRW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MGA" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "PYG" | "QAR" | "RON" | "RSD" | "RUB" | "RWF" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TWD" | "TZS" | "UAH" | "UGX" | "USD" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "VND" | "VUV" | "WST" | "XAF" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XOF" | "XPD" | "XPF" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
                    amount: number;
                    precision: number;
                };
            }[];
            term: string;
        } | null | undefined;
        dineIn?: {
            paymentTypes?: ("cash" | "ePayment" | "credit" | "ePaymentSandbox")[] | null | undefined;
            offlinePaymentTypes?: {
                name: string;
                instruction: string;
            }[] | null | undefined;
            ignoreStock?: boolean | null | undefined;
            staticQr?: boolean | null | undefined;
            disableItemRemark?: boolean | null | undefined;
            acceptQueue?: boolean | null | undefined;
            anonymousOrder: boolean;
        } | null | undefined;
        pf_business?: {
            internal?: boolean | null | undefined;
            url?: string | null | undefined;
            expiredAt?: string | null | undefined;
            agentId?: string | null | undefined;
            attributeSettings?: {
                options?: any[] | null | undefined;
                type: "string" | "number" | "boolean" | "date";
                key: string;
                entity: "restaurant" | "item" | "group" | "inventorySku" | "inventoryRecipe" | "warehouse";
            }[] | null | undefined;
            pf_agent?: {
                clickupId?: string | null | undefined;
                members?: {
                    pf_user?: {
                        email?: string | null | undefined;
                        phoneNumber?: string | null | undefined;
                        birthday?: string | null | undefined;
                        gender?: "MALE" | "FEMALE" | null | undefined;
                        addresses?: {
                            name: string;
                            address: string;
                            coordinates: number[];
                        }[] | null | undefined;
                        photoURL?: string | null | undefined;
                        displayName?: string | null | undefined;
                        imported?: {
                            raw: Record<string, any>;
                            source: "FEEDME" | "CITY_POS" | "STOREHUB" | "KERUYUn" | "QISOFT" | "WECHAT" | "TEABAR" | "NULL_MEMBER" | "UMAI_POS" | "QASHIER" | "XILNET" | "GENIUSPOS" | "YHOFOODIE";
                        } | null | undefined;
                        _id: string;
                    } | null | undefined;
                    role: "ADMIN";
                    userId: string;
                }[] | null | undefined;
                code: string;
                name: string;
                _id: string;
                isReseller: boolean;
            } | null | undefined;
            thumbnail?: string | null | undefined;
            billingInfos?: {
                _id?: string | null | undefined;
                name: string;
                address: {
                    coordinates?: number[] | null | undefined;
                    line2?: string | null | undefined;
                    state: string;
                    country: string;
                    line1: string;
                    city: string;
                    postcode: string;
                };
                email: string;
                companyName: string;
                contact: string;
            }[] | null | undefined;
            customerDisplayImages?: {
                url: string;
                restaurantIds: string[];
            }[] | null | undefined;
            name: string;
            _id: string;
            ownerId: string;
            restaurantQuota: number;
            warehouseQuota: number;
            menuVersion: string;
        } | null | undefined;
        features?: string[] | null | undefined;
        machineOtp?: string | null | undefined;
        machineOtpExpiredAt?: string | null | undefined;
        posVersion?: string | null | undefined;
        posHeartbeat?: string | null | undefined;
        posVersionHistory?: Record<string, string> | null | undefined;
        additionalCatalogs?: string[] | null | undefined;
        feedmeDelivery?: {
            instruction?: string | null | undefined;
            catalogId?: string | null | undefined;
            autoAccept?: boolean | null | undefined;
            term?: string | null | undefined;
            ignoreStock?: boolean | null | undefined;
            enable: boolean;
        } | null | undefined;
        foodpandaDelivery?: {
            _id?: string | undefined;
            ignoreDiscount?: boolean | null | undefined;
            catalogId?: string | null | undefined;
            commissionRate?: number | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            autoAccept?: boolean | null | undefined;
            reportConfig?: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            } | null | undefined;
            hasSst?: boolean | null | undefined;
            enable: boolean;
            remoteId: string;
            autoCloseBill: boolean;
        } | null | undefined;
        grabfoodDelivery?: {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            commissionRate: number;
            autoCloseBill: boolean;
            merchantID: string;
        } | null | undefined;
        shopeefoodDelivery?: {
            _id?: string | undefined;
            catalogId?: string | null | undefined;
            lastSynchronize?: string | null | undefined;
            showProductAddon?: boolean | null | undefined;
            enable: boolean;
            autoCloseBill: boolean;
            reportConfig: {
                commissionRate: number;
                discountCampaigns: {
                    name: string;
                    date: {
                        end: string;
                        start: string;
                    };
                    vendorBearPercentage: number;
                }[];
            };
            storeID: string;
        } | null | undefined;
        couchDbPassword?: string | null | undefined;
        apiToken?: string | null | undefined;
        remoteSupports?: {
            anydeskId?: string | null | undefined;
            anydeskPassword?: string | null | undefined;
            deviceName: string;
        }[] | null | undefined;
        payoutAccount?: Record<string, any> | null | undefined;
        clearCount?: number | null | undefined;
        queueSetting?: {
            duration?: number | null | undefined;
            enableOrder: boolean;
            initialNumber: number;
            endNumber: number;
            currentNumber: number;
            autoCalledLimit: number;
        } | null | undefined;
        tableMappingSetting?: {
            enable?: boolean | null | undefined;
            showSeat?: boolean | null | undefined;
            mapBorderColor?: number | null | undefined;
            mapLineColor?: number | null | undefined;
        } | null | undefined;
        _id: string;
        expiredAt: string;
        businessId: string;
        profile: {
            code?: string | null | undefined;
            url?: string | null | undefined;
            description?: string | null | undefined;
            _id?: string | null | undefined;
            legalName?: string | null | undefined;
            sstRegNo?: string | null | undefined;
            discovery?: boolean | null | undefined;
            coverPhoto?: string | null | undefined;
            thumbnailPhoto?: string | null | undefined;
            photos?: string[] | null | undefined;
            operatingHours?: {
                0: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                2: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                1: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                3: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                4: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                5: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
                6: {
                    hours: {
                        end: string;
                        start: string;
                    }[];
                    enable: boolean;
                };
            } | null | undefined;
            tags?: string[] | null | undefined;
            name: string;
            address: {
                coordinates?: number[] | null | undefined;
                line2?: string | null | undefined;
                state: string;
                country: string;
                line1: string;
                city: string;
                postcode: string;
            };
            email: string;
            phoneNo: string;
            regNo: string;
        };
    } | null | undefined;
    _id: string;
    orderStatus: {
        message: string;
        status: "pending" | "accepted" | "rejected";
    };
    raw: {
        cancel?: {
            cancel_reason?: string | null | undefined;
            cancel_source?: string | null | undefined;
            cencel_proposer?: string | null | undefined;
            cancel_remark?: string | null | undefined;
            cancel_time?: number | null | undefined;
        } | null | undefined;
        remark?: string | null | undefined;
        delivery_mode?: number | null | undefined;
        buyer?: {
            buyer_name: string;
            buyer_phone: string;
            buyer_address: string;
            buyer_latitude: number;
            buyer_longitude: number;
        } | null | undefined;
        id: string;
        status: "CANCELED" | "COMPLETED" | "DELIVERED" | "DELIVERY_ACCEPTED" | "DELIVERY_ARRIVED_STORE" | "DELIVERY_PICKED_UP" | "CANCELING";
        amount: {
            subtotal: number;
            merchant_service_fee: number;
            platform_service_fee: number;
            shipping_fee: number;
            shipping_basic_fee: number;
            shipping_surge_fee: number;
            small_order_fee: number;
            promotion: {
                shipping_discount_amount: number;
                shipping_voucher_amount: number;
                item_discount_amount: number;
                item_voucher_amount: number;
                merchant_voucher_subsidy_amount: number;
            };
            tax_amount: number;
            total_amount: number;
            merchant_surcharge_fee: number;
        };
        currency: "MYR";
        payment_method: "CASH_ON_DELIVERY" | "ONLINE_PAYMENT";
        items: {
            remark?: string | null | undefined;
            quantity: number;
            subtotal: number;
            unit_list_price: number;
            unit_price: number;
            detail: {
                option_groups?: {
                    name: string;
                    id: string;
                    options: {
                        name: string;
                        id: string;
                        price: number;
                        external_id: string;
                    }[];
                    external_id: string;
                }[] | null | undefined;
                dish: {
                    merchant_item_subsidy_amount?: number | null | undefined;
                    name: string;
                    id: string;
                    external_id: string;
                    unit_list_price: number;
                    unit_price: number;
                };
            };
        }[];
        store_id: string;
        region: "MY";
        order_short_code: string;
        create_time: number;
        update_time: number;
    };
}>;
export declare const SFMenuOption: z.ZodObject<{
    available: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    id: z.ZodString;
    name: z.ZodString;
    price: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    available?: boolean | null | undefined;
    name: string;
    id: string;
    price: number;
}, {
    available?: boolean | null | undefined;
    name: string;
    id: string;
    price: number;
}>;
export declare const SFMenuOptionGroup: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
    select_max: z.ZodNumber;
    select_min: z.ZodNumber;
    options: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        available: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        id: z.ZodString;
        name: z.ZodString;
        price: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        available?: boolean | null | undefined;
        name: string;
        id: string;
        price: number;
    }, {
        available?: boolean | null | undefined;
        name: string;
        id: string;
        price: number;
    }>, "many">>>;
}, "strip", z.ZodTypeAny, {
    options?: {
        available?: boolean | null | undefined;
        name: string;
        id: string;
        price: number;
    }[] | null | undefined;
    name: string;
    id: string;
    select_max: number;
    select_min: number;
}, {
    options?: {
        available?: boolean | null | undefined;
        name: string;
        id: string;
        price: number;
    }[] | null | undefined;
    name: string;
    id: string;
    select_max: number;
    select_min: number;
}>;
export declare const SFMenuSalesPeriod: z.ZodObject<{
    start_time: z.ZodString;
    end_time: z.ZodString;
}, "strip", z.ZodTypeAny, {
    start_time: string;
    end_time: string;
}, {
    start_time: string;
    end_time: string;
}>;
export declare const SFMenuSalesTime: z.ZodObject<{
    monday: z.ZodArray<z.ZodObject<{
        start_time: z.ZodString;
        end_time: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        start_time: string;
        end_time: string;
    }, {
        start_time: string;
        end_time: string;
    }>, "many">;
    tuesday: z.ZodArray<z.ZodObject<{
        start_time: z.ZodString;
        end_time: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        start_time: string;
        end_time: string;
    }, {
        start_time: string;
        end_time: string;
    }>, "many">;
    wednesday: z.ZodArray<z.ZodObject<{
        start_time: z.ZodString;
        end_time: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        start_time: string;
        end_time: string;
    }, {
        start_time: string;
        end_time: string;
    }>, "many">;
    thursday: z.ZodArray<z.ZodObject<{
        start_time: z.ZodString;
        end_time: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        start_time: string;
        end_time: string;
    }, {
        start_time: string;
        end_time: string;
    }>, "many">;
    friday: z.ZodArray<z.ZodObject<{
        start_time: z.ZodString;
        end_time: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        start_time: string;
        end_time: string;
    }, {
        start_time: string;
        end_time: string;
    }>, "many">;
    saturday: z.ZodArray<z.ZodObject<{
        start_time: z.ZodString;
        end_time: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        start_time: string;
        end_time: string;
    }, {
        start_time: string;
        end_time: string;
    }>, "many">;
    sunday: z.ZodArray<z.ZodObject<{
        start_time: z.ZodString;
        end_time: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        start_time: string;
        end_time: string;
    }, {
        start_time: string;
        end_time: string;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    monday: {
        start_time: string;
        end_time: string;
    }[];
    tuesday: {
        start_time: string;
        end_time: string;
    }[];
    wednesday: {
        start_time: string;
        end_time: string;
    }[];
    thursday: {
        start_time: string;
        end_time: string;
    }[];
    friday: {
        start_time: string;
        end_time: string;
    }[];
    saturday: {
        start_time: string;
        end_time: string;
    }[];
    sunday: {
        start_time: string;
        end_time: string;
    }[];
}, {
    monday: {
        start_time: string;
        end_time: string;
    }[];
    tuesday: {
        start_time: string;
        end_time: string;
    }[];
    wednesday: {
        start_time: string;
        end_time: string;
    }[];
    thursday: {
        start_time: string;
        end_time: string;
    }[];
    friday: {
        start_time: string;
        end_time: string;
    }[];
    saturday: {
        start_time: string;
        end_time: string;
    }[];
    sunday: {
        start_time: string;
        end_time: string;
    }[];
}>;
export declare const SFMenuDish: z.ZodObject<{
    available: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    id: z.ZodString;
    name: z.ZodString;
    picture: z.ZodString;
    price: z.ZodNumber;
    sales_time: z.ZodObject<{
        monday: z.ZodArray<z.ZodObject<{
            start_time: z.ZodString;
            end_time: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            start_time: string;
            end_time: string;
        }, {
            start_time: string;
            end_time: string;
        }>, "many">;
        tuesday: z.ZodArray<z.ZodObject<{
            start_time: z.ZodString;
            end_time: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            start_time: string;
            end_time: string;
        }, {
            start_time: string;
            end_time: string;
        }>, "many">;
        wednesday: z.ZodArray<z.ZodObject<{
            start_time: z.ZodString;
            end_time: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            start_time: string;
            end_time: string;
        }, {
            start_time: string;
            end_time: string;
        }>, "many">;
        thursday: z.ZodArray<z.ZodObject<{
            start_time: z.ZodString;
            end_time: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            start_time: string;
            end_time: string;
        }, {
            start_time: string;
            end_time: string;
        }>, "many">;
        friday: z.ZodArray<z.ZodObject<{
            start_time: z.ZodString;
            end_time: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            start_time: string;
            end_time: string;
        }, {
            start_time: string;
            end_time: string;
        }>, "many">;
        saturday: z.ZodArray<z.ZodObject<{
            start_time: z.ZodString;
            end_time: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            start_time: string;
            end_time: string;
        }, {
            start_time: string;
            end_time: string;
        }>, "many">;
        sunday: z.ZodArray<z.ZodObject<{
            start_time: z.ZodString;
            end_time: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            start_time: string;
            end_time: string;
        }, {
            start_time: string;
            end_time: string;
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        monday: {
            start_time: string;
            end_time: string;
        }[];
        tuesday: {
            start_time: string;
            end_time: string;
        }[];
        wednesday: {
            start_time: string;
            end_time: string;
        }[];
        thursday: {
            start_time: string;
            end_time: string;
        }[];
        friday: {
            start_time: string;
            end_time: string;
        }[];
        saturday: {
            start_time: string;
            end_time: string;
        }[];
        sunday: {
            start_time: string;
            end_time: string;
        }[];
    }, {
        monday: {
            start_time: string;
            end_time: string;
        }[];
        tuesday: {
            start_time: string;
            end_time: string;
        }[];
        wednesday: {
            start_time: string;
            end_time: string;
        }[];
        thursday: {
            start_time: string;
            end_time: string;
        }[];
        friday: {
            start_time: string;
            end_time: string;
        }[];
        saturday: {
            start_time: string;
            end_time: string;
        }[];
        sunday: {
            start_time: string;
            end_time: string;
        }[];
    }>;
    option_groups: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        select_max: z.ZodNumber;
        select_min: z.ZodNumber;
        options: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
            available: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            id: z.ZodString;
            name: z.ZodString;
            price: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            available?: boolean | null | undefined;
            name: string;
            id: string;
            price: number;
        }, {
            available?: boolean | null | undefined;
            name: string;
            id: string;
            price: number;
        }>, "many">>>;
    }, "strip", z.ZodTypeAny, {
        options?: {
            available?: boolean | null | undefined;
            name: string;
            id: string;
            price: number;
        }[] | null | undefined;
        name: string;
        id: string;
        select_max: number;
        select_min: number;
    }, {
        options?: {
            available?: boolean | null | undefined;
            name: string;
            id: string;
            price: number;
        }[] | null | undefined;
        name: string;
        id: string;
        select_max: number;
        select_min: number;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    description?: string | null | undefined;
    available?: boolean | null | undefined;
    name: string;
    picture: string;
    id: string;
    price: number;
    option_groups: {
        options?: {
            available?: boolean | null | undefined;
            name: string;
            id: string;
            price: number;
        }[] | null | undefined;
        name: string;
        id: string;
        select_max: number;
        select_min: number;
    }[];
    sales_time: {
        monday: {
            start_time: string;
            end_time: string;
        }[];
        tuesday: {
            start_time: string;
            end_time: string;
        }[];
        wednesday: {
            start_time: string;
            end_time: string;
        }[];
        thursday: {
            start_time: string;
            end_time: string;
        }[];
        friday: {
            start_time: string;
            end_time: string;
        }[];
        saturday: {
            start_time: string;
            end_time: string;
        }[];
        sunday: {
            start_time: string;
            end_time: string;
        }[];
    };
}, {
    description?: string | null | undefined;
    available?: boolean | null | undefined;
    name: string;
    picture: string;
    id: string;
    price: number;
    option_groups: {
        options?: {
            available?: boolean | null | undefined;
            name: string;
            id: string;
            price: number;
        }[] | null | undefined;
        name: string;
        id: string;
        select_max: number;
        select_min: number;
    }[];
    sales_time: {
        monday: {
            start_time: string;
            end_time: string;
        }[];
        tuesday: {
            start_time: string;
            end_time: string;
        }[];
        wednesday: {
            start_time: string;
            end_time: string;
        }[];
        thursday: {
            start_time: string;
            end_time: string;
        }[];
        friday: {
            start_time: string;
            end_time: string;
        }[];
        saturday: {
            start_time: string;
            end_time: string;
        }[];
        sunday: {
            start_time: string;
            end_time: string;
        }[];
    };
}>;
export declare const SFMenuCatalog: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
    dishes: z.ZodArray<z.ZodObject<{
        available: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
        description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        id: z.ZodString;
        name: z.ZodString;
        picture: z.ZodString;
        price: z.ZodNumber;
        sales_time: z.ZodObject<{
            monday: z.ZodArray<z.ZodObject<{
                start_time: z.ZodString;
                end_time: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                start_time: string;
                end_time: string;
            }, {
                start_time: string;
                end_time: string;
            }>, "many">;
            tuesday: z.ZodArray<z.ZodObject<{
                start_time: z.ZodString;
                end_time: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                start_time: string;
                end_time: string;
            }, {
                start_time: string;
                end_time: string;
            }>, "many">;
            wednesday: z.ZodArray<z.ZodObject<{
                start_time: z.ZodString;
                end_time: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                start_time: string;
                end_time: string;
            }, {
                start_time: string;
                end_time: string;
            }>, "many">;
            thursday: z.ZodArray<z.ZodObject<{
                start_time: z.ZodString;
                end_time: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                start_time: string;
                end_time: string;
            }, {
                start_time: string;
                end_time: string;
            }>, "many">;
            friday: z.ZodArray<z.ZodObject<{
                start_time: z.ZodString;
                end_time: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                start_time: string;
                end_time: string;
            }, {
                start_time: string;
                end_time: string;
            }>, "many">;
            saturday: z.ZodArray<z.ZodObject<{
                start_time: z.ZodString;
                end_time: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                start_time: string;
                end_time: string;
            }, {
                start_time: string;
                end_time: string;
            }>, "many">;
            sunday: z.ZodArray<z.ZodObject<{
                start_time: z.ZodString;
                end_time: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                start_time: string;
                end_time: string;
            }, {
                start_time: string;
                end_time: string;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            monday: {
                start_time: string;
                end_time: string;
            }[];
            tuesday: {
                start_time: string;
                end_time: string;
            }[];
            wednesday: {
                start_time: string;
                end_time: string;
            }[];
            thursday: {
                start_time: string;
                end_time: string;
            }[];
            friday: {
                start_time: string;
                end_time: string;
            }[];
            saturday: {
                start_time: string;
                end_time: string;
            }[];
            sunday: {
                start_time: string;
                end_time: string;
            }[];
        }, {
            monday: {
                start_time: string;
                end_time: string;
            }[];
            tuesday: {
                start_time: string;
                end_time: string;
            }[];
            wednesday: {
                start_time: string;
                end_time: string;
            }[];
            thursday: {
                start_time: string;
                end_time: string;
            }[];
            friday: {
                start_time: string;
                end_time: string;
            }[];
            saturday: {
                start_time: string;
                end_time: string;
            }[];
            sunday: {
                start_time: string;
                end_time: string;
            }[];
        }>;
        option_groups: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            name: z.ZodString;
            select_max: z.ZodNumber;
            select_min: z.ZodNumber;
            options: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                available: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                id: z.ZodString;
                name: z.ZodString;
                price: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                available?: boolean | null | undefined;
                name: string;
                id: string;
                price: number;
            }, {
                available?: boolean | null | undefined;
                name: string;
                id: string;
                price: number;
            }>, "many">>>;
        }, "strip", z.ZodTypeAny, {
            options?: {
                available?: boolean | null | undefined;
                name: string;
                id: string;
                price: number;
            }[] | null | undefined;
            name: string;
            id: string;
            select_max: number;
            select_min: number;
        }, {
            options?: {
                available?: boolean | null | undefined;
                name: string;
                id: string;
                price: number;
            }[] | null | undefined;
            name: string;
            id: string;
            select_max: number;
            select_min: number;
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        description?: string | null | undefined;
        available?: boolean | null | undefined;
        name: string;
        picture: string;
        id: string;
        price: number;
        option_groups: {
            options?: {
                available?: boolean | null | undefined;
                name: string;
                id: string;
                price: number;
            }[] | null | undefined;
            name: string;
            id: string;
            select_max: number;
            select_min: number;
        }[];
        sales_time: {
            monday: {
                start_time: string;
                end_time: string;
            }[];
            tuesday: {
                start_time: string;
                end_time: string;
            }[];
            wednesday: {
                start_time: string;
                end_time: string;
            }[];
            thursday: {
                start_time: string;
                end_time: string;
            }[];
            friday: {
                start_time: string;
                end_time: string;
            }[];
            saturday: {
                start_time: string;
                end_time: string;
            }[];
            sunday: {
                start_time: string;
                end_time: string;
            }[];
        };
    }, {
        description?: string | null | undefined;
        available?: boolean | null | undefined;
        name: string;
        picture: string;
        id: string;
        price: number;
        option_groups: {
            options?: {
                available?: boolean | null | undefined;
                name: string;
                id: string;
                price: number;
            }[] | null | undefined;
            name: string;
            id: string;
            select_max: number;
            select_min: number;
        }[];
        sales_time: {
            monday: {
                start_time: string;
                end_time: string;
            }[];
            tuesday: {
                start_time: string;
                end_time: string;
            }[];
            wednesday: {
                start_time: string;
                end_time: string;
            }[];
            thursday: {
                start_time: string;
                end_time: string;
            }[];
            friday: {
                start_time: string;
                end_time: string;
            }[];
            saturday: {
                start_time: string;
                end_time: string;
            }[];
            sunday: {
                start_time: string;
                end_time: string;
            }[];
        };
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    name: string;
    id: string;
    dishes: {
        description?: string | null | undefined;
        available?: boolean | null | undefined;
        name: string;
        picture: string;
        id: string;
        price: number;
        option_groups: {
            options?: {
                available?: boolean | null | undefined;
                name: string;
                id: string;
                price: number;
            }[] | null | undefined;
            name: string;
            id: string;
            select_max: number;
            select_min: number;
        }[];
        sales_time: {
            monday: {
                start_time: string;
                end_time: string;
            }[];
            tuesday: {
                start_time: string;
                end_time: string;
            }[];
            wednesday: {
                start_time: string;
                end_time: string;
            }[];
            thursday: {
                start_time: string;
                end_time: string;
            }[];
            friday: {
                start_time: string;
                end_time: string;
            }[];
            saturday: {
                start_time: string;
                end_time: string;
            }[];
            sunday: {
                start_time: string;
                end_time: string;
            }[];
        };
    }[];
}, {
    name: string;
    id: string;
    dishes: {
        description?: string | null | undefined;
        available?: boolean | null | undefined;
        name: string;
        picture: string;
        id: string;
        price: number;
        option_groups: {
            options?: {
                available?: boolean | null | undefined;
                name: string;
                id: string;
                price: number;
            }[] | null | undefined;
            name: string;
            id: string;
            select_max: number;
            select_min: number;
        }[];
        sales_time: {
            monday: {
                start_time: string;
                end_time: string;
            }[];
            tuesday: {
                start_time: string;
                end_time: string;
            }[];
            wednesday: {
                start_time: string;
                end_time: string;
            }[];
            thursday: {
                start_time: string;
                end_time: string;
            }[];
            friday: {
                start_time: string;
                end_time: string;
            }[];
            saturday: {
                start_time: string;
                end_time: string;
            }[];
            sunday: {
                start_time: string;
                end_time: string;
            }[];
        };
    }[];
}>;
export declare const SFMenuResData: z.ZodObject<{
    catalogs: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        dishes: z.ZodArray<z.ZodObject<{
            available: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
            description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            id: z.ZodString;
            name: z.ZodString;
            picture: z.ZodString;
            price: z.ZodNumber;
            sales_time: z.ZodObject<{
                monday: z.ZodArray<z.ZodObject<{
                    start_time: z.ZodString;
                    end_time: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    start_time: string;
                    end_time: string;
                }, {
                    start_time: string;
                    end_time: string;
                }>, "many">;
                tuesday: z.ZodArray<z.ZodObject<{
                    start_time: z.ZodString;
                    end_time: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    start_time: string;
                    end_time: string;
                }, {
                    start_time: string;
                    end_time: string;
                }>, "many">;
                wednesday: z.ZodArray<z.ZodObject<{
                    start_time: z.ZodString;
                    end_time: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    start_time: string;
                    end_time: string;
                }, {
                    start_time: string;
                    end_time: string;
                }>, "many">;
                thursday: z.ZodArray<z.ZodObject<{
                    start_time: z.ZodString;
                    end_time: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    start_time: string;
                    end_time: string;
                }, {
                    start_time: string;
                    end_time: string;
                }>, "many">;
                friday: z.ZodArray<z.ZodObject<{
                    start_time: z.ZodString;
                    end_time: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    start_time: string;
                    end_time: string;
                }, {
                    start_time: string;
                    end_time: string;
                }>, "many">;
                saturday: z.ZodArray<z.ZodObject<{
                    start_time: z.ZodString;
                    end_time: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    start_time: string;
                    end_time: string;
                }, {
                    start_time: string;
                    end_time: string;
                }>, "many">;
                sunday: z.ZodArray<z.ZodObject<{
                    start_time: z.ZodString;
                    end_time: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    start_time: string;
                    end_time: string;
                }, {
                    start_time: string;
                    end_time: string;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                monday: {
                    start_time: string;
                    end_time: string;
                }[];
                tuesday: {
                    start_time: string;
                    end_time: string;
                }[];
                wednesday: {
                    start_time: string;
                    end_time: string;
                }[];
                thursday: {
                    start_time: string;
                    end_time: string;
                }[];
                friday: {
                    start_time: string;
                    end_time: string;
                }[];
                saturday: {
                    start_time: string;
                    end_time: string;
                }[];
                sunday: {
                    start_time: string;
                    end_time: string;
                }[];
            }, {
                monday: {
                    start_time: string;
                    end_time: string;
                }[];
                tuesday: {
                    start_time: string;
                    end_time: string;
                }[];
                wednesday: {
                    start_time: string;
                    end_time: string;
                }[];
                thursday: {
                    start_time: string;
                    end_time: string;
                }[];
                friday: {
                    start_time: string;
                    end_time: string;
                }[];
                saturday: {
                    start_time: string;
                    end_time: string;
                }[];
                sunday: {
                    start_time: string;
                    end_time: string;
                }[];
            }>;
            option_groups: z.ZodArray<z.ZodObject<{
                id: z.ZodString;
                name: z.ZodString;
                select_max: z.ZodNumber;
                select_min: z.ZodNumber;
                options: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                    available: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                    id: z.ZodString;
                    name: z.ZodString;
                    price: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    available?: boolean | null | undefined;
                    name: string;
                    id: string;
                    price: number;
                }, {
                    available?: boolean | null | undefined;
                    name: string;
                    id: string;
                    price: number;
                }>, "many">>>;
            }, "strip", z.ZodTypeAny, {
                options?: {
                    available?: boolean | null | undefined;
                    name: string;
                    id: string;
                    price: number;
                }[] | null | undefined;
                name: string;
                id: string;
                select_max: number;
                select_min: number;
            }, {
                options?: {
                    available?: boolean | null | undefined;
                    name: string;
                    id: string;
                    price: number;
                }[] | null | undefined;
                name: string;
                id: string;
                select_max: number;
                select_min: number;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            description?: string | null | undefined;
            available?: boolean | null | undefined;
            name: string;
            picture: string;
            id: string;
            price: number;
            option_groups: {
                options?: {
                    available?: boolean | null | undefined;
                    name: string;
                    id: string;
                    price: number;
                }[] | null | undefined;
                name: string;
                id: string;
                select_max: number;
                select_min: number;
            }[];
            sales_time: {
                monday: {
                    start_time: string;
                    end_time: string;
                }[];
                tuesday: {
                    start_time: string;
                    end_time: string;
                }[];
                wednesday: {
                    start_time: string;
                    end_time: string;
                }[];
                thursday: {
                    start_time: string;
                    end_time: string;
                }[];
                friday: {
                    start_time: string;
                    end_time: string;
                }[];
                saturday: {
                    start_time: string;
                    end_time: string;
                }[];
                sunday: {
                    start_time: string;
                    end_time: string;
                }[];
            };
        }, {
            description?: string | null | undefined;
            available?: boolean | null | undefined;
            name: string;
            picture: string;
            id: string;
            price: number;
            option_groups: {
                options?: {
                    available?: boolean | null | undefined;
                    name: string;
                    id: string;
                    price: number;
                }[] | null | undefined;
                name: string;
                id: string;
                select_max: number;
                select_min: number;
            }[];
            sales_time: {
                monday: {
                    start_time: string;
                    end_time: string;
                }[];
                tuesday: {
                    start_time: string;
                    end_time: string;
                }[];
                wednesday: {
                    start_time: string;
                    end_time: string;
                }[];
                thursday: {
                    start_time: string;
                    end_time: string;
                }[];
                friday: {
                    start_time: string;
                    end_time: string;
                }[];
                saturday: {
                    start_time: string;
                    end_time: string;
                }[];
                sunday: {
                    start_time: string;
                    end_time: string;
                }[];
            };
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        name: string;
        id: string;
        dishes: {
            description?: string | null | undefined;
            available?: boolean | null | undefined;
            name: string;
            picture: string;
            id: string;
            price: number;
            option_groups: {
                options?: {
                    available?: boolean | null | undefined;
                    name: string;
                    id: string;
                    price: number;
                }[] | null | undefined;
                name: string;
                id: string;
                select_max: number;
                select_min: number;
            }[];
            sales_time: {
                monday: {
                    start_time: string;
                    end_time: string;
                }[];
                tuesday: {
                    start_time: string;
                    end_time: string;
                }[];
                wednesday: {
                    start_time: string;
                    end_time: string;
                }[];
                thursday: {
                    start_time: string;
                    end_time: string;
                }[];
                friday: {
                    start_time: string;
                    end_time: string;
                }[];
                saturday: {
                    start_time: string;
                    end_time: string;
                }[];
                sunday: {
                    start_time: string;
                    end_time: string;
                }[];
            };
        }[];
    }, {
        name: string;
        id: string;
        dishes: {
            description?: string | null | undefined;
            available?: boolean | null | undefined;
            name: string;
            picture: string;
            id: string;
            price: number;
            option_groups: {
                options?: {
                    available?: boolean | null | undefined;
                    name: string;
                    id: string;
                    price: number;
                }[] | null | undefined;
                name: string;
                id: string;
                select_max: number;
                select_min: number;
            }[];
            sales_time: {
                monday: {
                    start_time: string;
                    end_time: string;
                }[];
                tuesday: {
                    start_time: string;
                    end_time: string;
                }[];
                wednesday: {
                    start_time: string;
                    end_time: string;
                }[];
                thursday: {
                    start_time: string;
                    end_time: string;
                }[];
                friday: {
                    start_time: string;
                    end_time: string;
                }[];
                saturday: {
                    start_time: string;
                    end_time: string;
                }[];
                sunday: {
                    start_time: string;
                    end_time: string;
                }[];
            };
        }[];
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    catalogs: {
        name: string;
        id: string;
        dishes: {
            description?: string | null | undefined;
            available?: boolean | null | undefined;
            name: string;
            picture: string;
            id: string;
            price: number;
            option_groups: {
                options?: {
                    available?: boolean | null | undefined;
                    name: string;
                    id: string;
                    price: number;
                }[] | null | undefined;
                name: string;
                id: string;
                select_max: number;
                select_min: number;
            }[];
            sales_time: {
                monday: {
                    start_time: string;
                    end_time: string;
                }[];
                tuesday: {
                    start_time: string;
                    end_time: string;
                }[];
                wednesday: {
                    start_time: string;
                    end_time: string;
                }[];
                thursday: {
                    start_time: string;
                    end_time: string;
                }[];
                friday: {
                    start_time: string;
                    end_time: string;
                }[];
                saturday: {
                    start_time: string;
                    end_time: string;
                }[];
                sunday: {
                    start_time: string;
                    end_time: string;
                }[];
            };
        }[];
    }[];
}, {
    catalogs: {
        name: string;
        id: string;
        dishes: {
            description?: string | null | undefined;
            available?: boolean | null | undefined;
            name: string;
            picture: string;
            id: string;
            price: number;
            option_groups: {
                options?: {
                    available?: boolean | null | undefined;
                    name: string;
                    id: string;
                    price: number;
                }[] | null | undefined;
                name: string;
                id: string;
                select_max: number;
                select_min: number;
            }[];
            sales_time: {
                monday: {
                    start_time: string;
                    end_time: string;
                }[];
                tuesday: {
                    start_time: string;
                    end_time: string;
                }[];
                wednesday: {
                    start_time: string;
                    end_time: string;
                }[];
                thursday: {
                    start_time: string;
                    end_time: string;
                }[];
                friday: {
                    start_time: string;
                    end_time: string;
                }[];
                saturday: {
                    start_time: string;
                    end_time: string;
                }[];
                sunday: {
                    start_time: string;
                    end_time: string;
                }[];
            };
        }[];
    }[];
}>;
export declare const SFMenuRes: z.ZodObject<{
    code: z.ZodNumber;
    msg: z.ZodString;
    data: z.ZodObject<{
        catalogs: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            name: z.ZodString;
            dishes: z.ZodArray<z.ZodObject<{
                available: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                id: z.ZodString;
                name: z.ZodString;
                picture: z.ZodString;
                price: z.ZodNumber;
                sales_time: z.ZodObject<{
                    monday: z.ZodArray<z.ZodObject<{
                        start_time: z.ZodString;
                        end_time: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        start_time: string;
                        end_time: string;
                    }, {
                        start_time: string;
                        end_time: string;
                    }>, "many">;
                    tuesday: z.ZodArray<z.ZodObject<{
                        start_time: z.ZodString;
                        end_time: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        start_time: string;
                        end_time: string;
                    }, {
                        start_time: string;
                        end_time: string;
                    }>, "many">;
                    wednesday: z.ZodArray<z.ZodObject<{
                        start_time: z.ZodString;
                        end_time: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        start_time: string;
                        end_time: string;
                    }, {
                        start_time: string;
                        end_time: string;
                    }>, "many">;
                    thursday: z.ZodArray<z.ZodObject<{
                        start_time: z.ZodString;
                        end_time: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        start_time: string;
                        end_time: string;
                    }, {
                        start_time: string;
                        end_time: string;
                    }>, "many">;
                    friday: z.ZodArray<z.ZodObject<{
                        start_time: z.ZodString;
                        end_time: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        start_time: string;
                        end_time: string;
                    }, {
                        start_time: string;
                        end_time: string;
                    }>, "many">;
                    saturday: z.ZodArray<z.ZodObject<{
                        start_time: z.ZodString;
                        end_time: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        start_time: string;
                        end_time: string;
                    }, {
                        start_time: string;
                        end_time: string;
                    }>, "many">;
                    sunday: z.ZodArray<z.ZodObject<{
                        start_time: z.ZodString;
                        end_time: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        start_time: string;
                        end_time: string;
                    }, {
                        start_time: string;
                        end_time: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    monday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    tuesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    wednesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    thursday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    friday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    saturday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    sunday: {
                        start_time: string;
                        end_time: string;
                    }[];
                }, {
                    monday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    tuesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    wednesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    thursday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    friday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    saturday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    sunday: {
                        start_time: string;
                        end_time: string;
                    }[];
                }>;
                option_groups: z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    name: z.ZodString;
                    select_max: z.ZodNumber;
                    select_min: z.ZodNumber;
                    options: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
                        available: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
                        id: z.ZodString;
                        name: z.ZodString;
                        price: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }, {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }>, "many">>>;
                }, "strip", z.ZodTypeAny, {
                    options?: {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }[] | null | undefined;
                    name: string;
                    id: string;
                    select_max: number;
                    select_min: number;
                }, {
                    options?: {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }[] | null | undefined;
                    name: string;
                    id: string;
                    select_max: number;
                    select_min: number;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                description?: string | null | undefined;
                available?: boolean | null | undefined;
                name: string;
                picture: string;
                id: string;
                price: number;
                option_groups: {
                    options?: {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }[] | null | undefined;
                    name: string;
                    id: string;
                    select_max: number;
                    select_min: number;
                }[];
                sales_time: {
                    monday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    tuesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    wednesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    thursday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    friday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    saturday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    sunday: {
                        start_time: string;
                        end_time: string;
                    }[];
                };
            }, {
                description?: string | null | undefined;
                available?: boolean | null | undefined;
                name: string;
                picture: string;
                id: string;
                price: number;
                option_groups: {
                    options?: {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }[] | null | undefined;
                    name: string;
                    id: string;
                    select_max: number;
                    select_min: number;
                }[];
                sales_time: {
                    monday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    tuesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    wednesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    thursday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    friday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    saturday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    sunday: {
                        start_time: string;
                        end_time: string;
                    }[];
                };
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            name: string;
            id: string;
            dishes: {
                description?: string | null | undefined;
                available?: boolean | null | undefined;
                name: string;
                picture: string;
                id: string;
                price: number;
                option_groups: {
                    options?: {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }[] | null | undefined;
                    name: string;
                    id: string;
                    select_max: number;
                    select_min: number;
                }[];
                sales_time: {
                    monday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    tuesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    wednesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    thursday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    friday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    saturday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    sunday: {
                        start_time: string;
                        end_time: string;
                    }[];
                };
            }[];
        }, {
            name: string;
            id: string;
            dishes: {
                description?: string | null | undefined;
                available?: boolean | null | undefined;
                name: string;
                picture: string;
                id: string;
                price: number;
                option_groups: {
                    options?: {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }[] | null | undefined;
                    name: string;
                    id: string;
                    select_max: number;
                    select_min: number;
                }[];
                sales_time: {
                    monday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    tuesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    wednesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    thursday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    friday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    saturday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    sunday: {
                        start_time: string;
                        end_time: string;
                    }[];
                };
            }[];
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        catalogs: {
            name: string;
            id: string;
            dishes: {
                description?: string | null | undefined;
                available?: boolean | null | undefined;
                name: string;
                picture: string;
                id: string;
                price: number;
                option_groups: {
                    options?: {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }[] | null | undefined;
                    name: string;
                    id: string;
                    select_max: number;
                    select_min: number;
                }[];
                sales_time: {
                    monday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    tuesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    wednesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    thursday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    friday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    saturday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    sunday: {
                        start_time: string;
                        end_time: string;
                    }[];
                };
            }[];
        }[];
    }, {
        catalogs: {
            name: string;
            id: string;
            dishes: {
                description?: string | null | undefined;
                available?: boolean | null | undefined;
                name: string;
                picture: string;
                id: string;
                price: number;
                option_groups: {
                    options?: {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }[] | null | undefined;
                    name: string;
                    id: string;
                    select_max: number;
                    select_min: number;
                }[];
                sales_time: {
                    monday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    tuesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    wednesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    thursday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    friday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    saturday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    sunday: {
                        start_time: string;
                        end_time: string;
                    }[];
                };
            }[];
        }[];
    }>;
}, "strip", z.ZodTypeAny, {
    data: {
        catalogs: {
            name: string;
            id: string;
            dishes: {
                description?: string | null | undefined;
                available?: boolean | null | undefined;
                name: string;
                picture: string;
                id: string;
                price: number;
                option_groups: {
                    options?: {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }[] | null | undefined;
                    name: string;
                    id: string;
                    select_max: number;
                    select_min: number;
                }[];
                sales_time: {
                    monday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    tuesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    wednesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    thursday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    friday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    saturday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    sunday: {
                        start_time: string;
                        end_time: string;
                    }[];
                };
            }[];
        }[];
    };
    code: number;
    msg: string;
}, {
    data: {
        catalogs: {
            name: string;
            id: string;
            dishes: {
                description?: string | null | undefined;
                available?: boolean | null | undefined;
                name: string;
                picture: string;
                id: string;
                price: number;
                option_groups: {
                    options?: {
                        available?: boolean | null | undefined;
                        name: string;
                        id: string;
                        price: number;
                    }[] | null | undefined;
                    name: string;
                    id: string;
                    select_max: number;
                    select_min: number;
                }[];
                sales_time: {
                    monday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    tuesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    wednesday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    thursday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    friday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    saturday: {
                        start_time: string;
                        end_time: string;
                    }[];
                    sunday: {
                        start_time: string;
                        end_time: string;
                    }[];
                };
            }[];
        }[];
    };
    code: number;
    msg: string;
}>;
export declare const SFStatus: z.ZodObject<{
    status: z.ZodEnum<["pending", "accepted", "rejected"]>;
    message: z.ZodString;
}, "strip", z.ZodTypeAny, {
    message: string;
    status: "pending" | "accepted" | "rejected";
}, {
    message: string;
    status: "pending" | "accepted" | "rejected";
}>;
export type SFStatus = z.infer<typeof SFStatus>;
export type SFMenuCatalog = z.infer<typeof SFMenuCatalog>;
export type SFMenuDish = z.infer<typeof SFMenuDish>;
export type SFMenuSalesTime = z.infer<typeof SFMenuSalesTime>;
export type SFMenuOptionGroup = z.infer<typeof SFMenuOptionGroup>;
export type SFMenuOption = z.infer<typeof SFMenuOption>;
export type SFMenuRes = z.infer<typeof SFMenuRes>;
export type FdoShopeeFoodOrderOutput = z.infer<typeof FdoShopeeFoodOrderOutput>;
export type FdoShopeeFoodOrderStatus = z.infer<typeof FdoShopeeFoodOrderStatus>;
export type SFPromotion = z.infer<typeof SFPromotion>;
export type SFOrderAmount = z.infer<typeof SFOrderAmount>;
export type SFOrderDish = z.infer<typeof SFOrderDish>;
export type SFItemOption = z.infer<typeof SFItemOption>;
export type SFItemOptionGroup = z.infer<typeof SFItemOptionGroup>;
export type SFItemDetail = z.infer<typeof SFItemDetail>;
export type SFOrderItem = z.infer<typeof SFOrderItem>;
export type SFOrderCancelInfo = z.infer<typeof SFOrderCancelInfo>;
export type SFBuyer = z.infer<typeof SFBuyer>;
export type SFOrder = z.infer<typeof SFOrder>;
export type FdoShopeeFoodOrder = z.infer<typeof FdoShopeeFoodOrder>;
